/**
 * 声明命名空间
 * @type
 */
var DGC = {};

/**
 * 全局枚举命名空间
 * @type
 */
DGC.ATTRS = {};

/**
 * 应用程序
 * @param {} config
 */
DGC.App = function(config){
    //指定入口
    $.extend(this.config, window.sdk.init_view);
    this.preload();
};


DGC.App = $.inherits(DGC.App, {

    config: {
        id : 'me' //默认加载导航
    },

    /**
     * 初始化时需要请求的API
     */
    apiURL: {
        GET_TIPS:{
            url:"/tips?player_id={0}&t={1}&cid={2}",
            pattern:/\/tips\?player_id=\d+&t=\d+&cid=.{0,}/
        }
    },

    /**
     * 加载页面预加载处理
     */
    preload : function(){
        if(DEBUG.isWebModel()){
           //模拟开启触控事件
           $.getScript('common/phantomLimb.js',function(){
                $.mockTouch.init({
                    src: 'https://github.com/brian-c/phantom-limb/raw/master/limb-white.png',
                    lefty: false
                });
           });
        }

        //禁止enter键提交页面
        $("input").live("keyup", function(event){
            if(event.keyCode && ( event.keyCode === 13/*Enter*/)){
                $(this)[0].blur();
                event.preventDefault();
            }
        });


        $("form").live("submit", function(event){
            console.log("submit:" + event.keyCode);
            event.preventDefault();
        });

        this.bindOrientation();

        //初始化APP服务模块
        this.service = new DGC.Service();

    },

    /**
     * 请求应用信息
     */
    getAppInfo: function(){
        DGC.ActionUtil.requestAppInit("DGC.Application.initialize");
    },

    /**
     * 不请求Tips的视图
     */
    diableTipsView:[
        "DeveloperPay", //开发者购买道具
        "LeDouShop",    //乐逗商城
        "BindSina"      //开发者发微博
    ],

    /**
     * 请求应用tips信息
     */
    requestTips : function(){
        var DAU = DGC.ActionUtil,
            DC = DGC.Common,
            lastTime = DC.getAppConfig(DC.localKey("activitytime"))|| 1 /*默认参数*/;

        //订阅TIP消息
        this.service.on(DGC.Service.Messages.QUERY_LOAD_TIPS, this.setLoadInfo, this);
        //用户最新邀请信息/是否支持乐币
        var requestBody = {
            msgID : DGC.Service.Messages.QUERY_LOAD_TIPS,
            params : {
                "GET" : [
                    {
                        url : $.format(this.apiURL.GET_TIPS.url,
                            [ window.sdk.player.id, lastTime, window.sdk.channel_id ])
                    }
                ]
            }
        }

        //Web Debug
        if(DEBUG.isWebModel()){
           $.extend(requestBody, {
               version: '1.2.0',
               mockUrl: "tips.json"
           });
        }

        //查询TIP信息
        DAU.requestAPI(requestBody);
    },

    /**
     * 监听当前屏幕的旋转操作
     */
    bindOrientation: function(){
        var L_CLASS ="landscape",
            P_CLASS = "portrait";

        /**
         * 垂直/水平状态监听
         */
        function orientStatus() {
          var orientation = window.orientation,
              body = $(document.body);
          switch(orientation) {
            case 0:
            case 180:
                body.removeClass(L_CLASS).addClass(P_CLASS);
                break;
            case 90:
            case -90:
                body.removeClass(P_CLASS).addClass(L_CLASS);
                break;
          }
       }

        //判断旋转对象在window对象中是否存在
        if("orientation" in window){
           //监听横/竖屏旋转
           $(window).bind('orientationchange',orientStatus);
        }

        //初始化设置
        switch(window.sdk.orientation){
            case 1/*竖屏*/:
                $(document.body).addClass(P_CLASS);
                break;
            case 2/*横屏*/:
                $(document.body).addClass(L_CLASS);
                break;
        }
    },

    /**
     * 初始化执行过程
     * @param {} config
     */
    setLoadInfo : function(msg){
        //解析请求结果设置TIPS
        var response;
        if(msg.success){
            response = msg.data["result"].GET;
            for(var url in response){
                if(this.apiURL.GET_TIPS.pattern.test(url)){
                    var tips = response[url].data;
                    //如果返回结果业务异常，则提示消息
                    if(tips.err_detail){
                        DGC.ActionUtil.showTipMsg(tips.err_detail);
                    }else{
                        //缓存TIPS数目
                        window.sdk.tips = tips;

                        //不支持活动
                        if(!DH.isSupportActivities()){
                            window.sdk.tips.new_activity = 0; //不提示活动数,始终置为0
                        }

                        //更新我业务显示消息数(活动+好友)
                        DGC.ActionUtil.updateTabTip(DGC.Module.ATTRS.ME,
                             tips.new_follwers + tips.new_activity);

                        //通知界面TIPS已经获得
                        this.actionCallback({
                            success : true,
                            msgInfo : {
                                msgID: DGC.Service.Messages.QUERY_TIPS_SUCCESS
                            },
                            data: {}
                        });
                    }
                }
            }
        }else{
            //提示数据获取失败
            DGC.ActionUtil.showTipMsg(msg.data.error);
            return false;
        }
    },

    /**
     * 业务初始化函数
     */
    initialize : function(initInfo){
        //将请求响应结果赋值给sdk
        $.extend(window.sdk, initInfo.result);
        window.sdk.config_params = {};
        //Web调试模式或离线模式
        if(DEBUG.isWebModel() || window.sdk.isOffline){
            this.initload();
        }else{
            this.loadCfgFields();
        }
    },

    /**
     * 读取配置信息
     */
    loadCfgFields : function(){
        //读取本地配置信息
        var DC = DGC.Common,
            DAS = DGC.App.StorageField,
            fields = [];

        //获得需要获取的字段
        for(var key in DAS){
            if(DAS[key]){
                fields.push(DC.localKey(key));
            }
        }
        //加载全局
        DGC.ActionUtil.getConfigParams(fields);
    },

    /**
     * 加载配置项方法的回调
     */
    getConfigParamsLoad : function(msg){
        for(var k in msg){
            //写入到sdk
            window.sdk.config_params[k] = msg[k];
        }

        //加载全局配置
        DGC.ActionUtil.getGConfigParams();
    },

     /**
     * 加载全局配置项的回调
     */
    getGConfigParamsLoad : function(msg){
        var config = !$.isEmpty(msg.storage) ? $.parseJSON(msg.storage) : {};
        $.extend(window.sdk, { global_config_params :config });
        this.initload();
    },

    initload : function(){
        //普通入口
        if(!window.sdk.init_view){
            //设置默认显示模板
            this.config.id = window.sdk.isOffline ? 'highscore': 'me';
        }

        //在线模式请求TIPS,且非黑名单View
        if(!window.sdk.isOffline){
            var viewName = this.config.viewName || DGC.Module.Utils.getDefaultView(this.config.id);
            if(viewName && $.inArray(viewName, this.diableTipsView) == -1 ){
                 this.requestTips();
            }
        }

        //页面导航
        this.navigateTo(this.config);
        //高亮按钮
        DGC.ActionUtil.hightLightTab(this.config.id);
    },

    /**
     * Android Tab导航切换交互接口
     * @param {Number} id 具体模块id key值
     * @param {String} viewName 视图名称 可选参数
     * @param {String} params 视图初始化需要的参数
     */
    navigateTo : function(viewObj){
        var defaultView = {
            id : 'highscore', //默认模块排行榜
            viewName : false,  //不指定View,取模块默认视图
            params: {}, //传递视图初始化需要的参数
            reset: false //退栈，恢复视图
        };

        this.service.navigateToView($.extend(defaultView, viewObj));
    },

    /**
     * Android 消息通知接口
     * @param {String} msg json格式消息对象
     */
    actionCallback : function(msg){
        //消息处理函数
        var request = msg.msgInfo;
        DGC.ActionUtil.log($.format('WebUI Reveice Id:{0}',[request.msgID]));
        DGC.Common.unlock(request.msgID);

        //请求存在viewID属性
        if(request.plugData && request.plugData.viewId){
            //请求viewId与当前显示view不一致
            if(request.plugData.viewId != DGC.Application.service.currentModule.currentView.id){
                return false;
            }
        }

        this.service.messageHandler(msg);
    },

    /**
     * 通用select组件用户点击结果
     */
    selectCallback: function(selectResult){
        this.actionCallback({
            success : true,
            msgInfo : {
                msgID: selectResult.msgID
            },
            data: selectResult.selectItem
        });
    },

    /**
     * 上传头像状态消息通知接口
     * @param {String} msg json格式消息对象
     **/
    updateAvatarCallBack : function(msg){

        //构造普通消息
        var fireMsg = {
            success : msg.success,
            msgInfo : {
                msgID: DGC.Service.Messages.UPDATE_PLAYER_AVATAR
            },
            data:{}
        }

        //如果上传失败，则显示对应的消息
        if(!msg.success){
            fireMsg.data['error'] = msg.errorDetail;
        }

        this.actionCallback(fireMsg);
    },

    /**
     * 账号切换结果通知
     */
    notifyAccountReLogin: function(msg){
        if(msg.success){
            DGC.ActionUtil.showTipMsg(resName.TIP_SWITCHUSER_COMMON_SUCCESS);
        }else{
            DGC.ActionUtil.showTipMsg(msg.errorDetail);
            DGC.Common.unlock('switchlock');
        }
    },

    /**
     * Android 返回当前游戏的安装状态
     * @param {String} msg json格式
     */
    gameStateCallBack : function(msg){
        var datajson = {
            success: true,
            msgInfo:{
                msgID:DGC.Service.Messages.QUERY_LOCAL_GAME_STATE
            },
            data:msg
        };
        this.actionCallback(datajson);
    },

    /**
     * 本地充值(GFAN)操作成功/失败
     */
    payCallback : function(msg){
        //构造普通消息
        var fireMsg = {
            success : msg.success,
            msgInfo : {
                msgID: DGC.Service.Messages.UPDATE_CHARGE_GFAN
            },
            data: {
                type: msg.type,
                errorDetail: msg.errorDetail
            }
        }

        this.actionCallback(fireMsg);
    },

    /**
     * 查询乐逗商城道具列表信息
     */
    productListCallback: function(msg){
        //构造普通消息
        var fireMsg = {
            success : msg.success,
            msgInfo : {
                msgID: DGC.Service.Messages.QUERY_SHOP_ITEMS
            },
            data: msg.data
        }

        this.actionCallback(fireMsg);
    },

    /*
     * 获得需要支付道具信息Callback
     */
    productInfoCallback : function(msg){
        //构造普通消息
        var fireMsg = {
            success : true,
            msgInfo : {
                msgID: DGC.Service.Messages.QUERY_PAY_PRODUCTINFO
            },
            data: msg
        }

        this.actionCallback(fireMsg);
    },

    /**
     * 本地支付(短代和机锋)账户
     */
    purchaseCallback : function(msg){
        //构造普通消息
        var fireMsg = {
            success : msg.success,
            msgInfo : {
                msgID: DGC.Service.Messages.UPDATE_PAY_BY_LOCAL
            },
            data:{
                recharge: msg.recharge,
                item: msg.item,
                quantity: msg.quantity,
                type : msg.type
            }
        }

        if(!msg.success){
            $.extend(fireMsg.data, {errorDetail: msg.errorDetail });
        }

        this.actionCallback(fireMsg);
    },

    /**
     * Android 离线成就信息
     * @param {Object} feed API对象
     */
    offlineAchieveCallback : function(msg){
        this.actionCallback({
            success: true,
            msgInfo:{
                msgID: DGC.Service.Messages.QUERY_OFFLINE_ACHIEVE
            },
            data:msg
        });
    },

    /**
     * Android 离线排行榜模式
     * @param {Object} feed API对象
     */

    offlineBoardCallback : function(msg){
        this.actionCallback({
            success: true,
            msgInfo:{
                msgID: DGC.Service.Messages.QUERY_OFFLINE_LEADERBOARD_LIST
            },
            data:msg
        });
    },

    /**
     * Android 离线高分榜
     * @param {Object} feed API对象
     */
    offlineHighScoreCallback : function(msg){
        this.actionCallback({
            success: true,
            msgInfo:{
                msgID: DGC.Service.Messages.QUERY_OFFLINE_HIGHSCORES
            },
            data:msg
        });
    },

    /**
     * 图片加载成功
     */
    viewImageReady : function(imgObj){
        var currentView = DGC.Application.service.currentModule.currentView;
        //请求viewId与当前显示view不一致
        if(imgObj.viewName != currentView.id){
            return false;
        }

        currentView.asycImgReady(imgObj);
    },

    /**
     * 通知sdcard状态变化
     */
    sdcardState : function(msg){
        //更新SDCard状态
        window.sdk.sdcardState = msg.state;
    },

    /**
     * 通知当前积分类型和余额
     */
    notifyIntegral : function(msg){
        var fireMsg = {
            success : true,
            msgInfo : {
                msgID: DGC.Service.Messages.QUERY_INTEGRAL_INFO
            },
            data: msg
        };

        this.actionCallback(fireMsg);
    },

    /**
     * 获取活动页面内容
     */
    getDetailContent: function(){
        var cView = DGC.Application.service.currentModule.currentView;
        return (cView.name == 'ActivityDetail' ? cView.contextHtml  : "");
    },

    /**
     * 用户点击Android的关闭按钮返回游戏
     */
    returnGame : function(){
        DGC.ActionUtil.returnToGame();
    },

    /**
     * 当前视图回退操作
     * @params {Number} views 回退层级数
     */
    goBack : function(views){
        this.service.viewStatusBack(views);
    }

});

/**
 * 本地记录字段
 */
DGC.App.StorageField = {
    "payway" : true ,     //最近支付方式
    "chargeway" : true,   //最近充值方式
    "activitytime": true, //最近查看活动时间
    'shareway':true       //最近分享的方式
}

/**
 * 入口函数
 */
DGC.App.loadReady = function(){
    DGC.Application = new DGC.App();
    DGC.Application.getAppInfo();
}
