/**
 * DGC Web项目公共方法
 */

DGC.Common = {

    /**
     * 模拟tap按下事件
     */
    E_TAP_DOWN: "tapdown",

    /**
     * 模拟tap释放事件
     */
    E_TAP_UP: "tapup tapcancel",

    /**
     * scroll延迟加载时间
     */
    DELAY_SCROLL_LOADER: 100,

    /**
     * 列表项Tap按下样式
     */
    listTapDownHandler: function(){
        var me  = $(this);
        me.addClass('list-item-active');
    },

    /**
     *	列表项Tap释放样式
     */
    listTapEndHandler:  function () {
        var me  = $(this);
        me.removeClass('list-item-active');
    },

    /**
     * 按钮Tap按下样式
     */
    buttonTapDownHandler: function(event){
        var me = $(this);
        me.addClass('active');
        event.stopPropagation();
    },

    /**
     * 按钮Tap释放样式
     */
    buttonTapEndHandler: function(event){
        var me  = $(this);
        me.removeClass('active');
        event.stopPropagation();
    },

    /**
     * 阻止组件冒泡
     */
    stopPropagation: function(event){
        event.stopPropagation();
    },

    /**
     * 获得应用的配置值
     * @param {String} key 键值
     * @param {Boolean} isGlobal 是否为全局配置(系统级别)
     */
    getAppConfig: function(key, isGlobal){
         var config = isGlobal ? window.sdk.global_config_params : window.sdk.config_params;
         return config[key];
    },

    /**
     * 设置全局应用配置值
     * @param {String} key 键
     * @param {String} value 值
     * @param {String} isGlobal 是否为全局配置(系统级别)
     */
    setAppConfig: function(key, value, isGlobal){
        var DAU = DGC.ActionUtil,
            obj = {};
        obj[key] = value;
        if(isGlobal){
             $.extend(window.sdk.global_config_params, obj );
             DAU.setGConfigParams(window.sdk.global_config_params);
        }else{
             $.extend(window.sdk.config_params, obj );
             DAU.setConfigParams(obj);
        }
    },

    /**
     * 移除全局应用配置值
     * @param {String} key 键值
     * @param {Boolean} isGlobal 是否为全局配置(系统级别)
     */
    removeAppConfig: function(key, isGlobal ){
        var DAU = DGC.ActionUtil;
        if(isGlobal){
            if(window.sdk.global_config_params[key]){
                delete window.sdk.global_config_params[key];
                DAU.setGConfigParams(window.sdk.global_config_params);
            }
        }else{
            if(window.sdk.config_params[key]){
                delete window.sdk.config_params[key];
                //缺少普通配置移除接口
                //DAU.setConfigParams(window.sdk.global_config_params);
            }
        }

    },

    /**
     * 只允许输入数字
     */
    onlyAllowNumber : function(event){
          var key = event.keyCode || event.which;
          key = String.fromCharCode( key );
          var regex = /[0-9]/;
          if( !regex.test(key) ) {
              event.preventDefault();
          }
    },

    /**
     * 获得道具单位字符串
     */
    getUnit:function(){
        return window.sdk.channel.enable_coin_payment ?
            resName.TEXT_LEDOUSHOP_CURRENCY : resName.TEXT_LEDOUSHOP_CURRENCY_RMB;
    },

    /**
     * 生成commonSelect需要的数据结构
     * @param {String} textTpl 选项卡模板
     * @param {Array} values 值数组
     */
    commonOptions: function(textTpl, values){
        var options = [];
        for (var i = 0; i < values.length; i++) {
            var optionValue = values[i];
            options.push({
                text: $.format(textTpl, [optionValue]),
                value: optionValue.toString()
            });
        };
        return options;
    },

    /**
     * 根据时间戳获取对应的Date对象
     * @param {Number} timestamp php返回的时间戳(精确到秒)
     */
    getDateFromTime : function(timestamp){
        return new Date(timestamp * 1000);
    },

    /**
     *  将日期对象转换为服务器时间戳(精确到秒)
     * @param {Date} js Date对象
     */
    formatSeverTime : function(date){
        return  Math.floor(date.getTime() / 1000);
    },


    /**
     * 获得固定格式的日期字符串
     */
    getFormatDate: function(date, onlyDate){
        var stringFormat = onlyDate ? "{0}-{1}-{2}" : "{0}-{1}-{2} {3}:{4}:{5}";
        return $.format(stringFormat ,[ date.getFullYear(), date.getMonth() + 1,
            date.getDate(), date.getHours() < 10 ? "0" + date.getHours() : date.getHours() ,
            date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes() ,
            date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds() ]);
    },

    /**
     * 获取列表为空时的Html结构
     */
    getEmptyListItemHtml: function(text){
        return $.format("<div class='list-item center-layout empty-item'><h1 class='empty-text'>{0}</h1></div>",[text]);
    },

    /**
     * 锁屏状态
     * @param {String} msgID 锁屏ID标示
     * @param {Number} tiemout 超时unlock时间  默认30s
     */
    lock : function(msgID, timeout) {
        $(".common-loading").remove();
        var mask;
        mask = $("<div class=\"common-loading\" data-msgID='"+msgID+"'><div class=\"common-mask-icon-big\"></div><div class=\"common-mask-icon-small\"></div></div>");
        var offsetTop = $(window).scrollTop();
        if(offsetTop){
            mask.css({"top":offsetTop});
        }
        $(document.body).append(mask);
        if($(".common-dialog").size() > 0 ){
            var a = parseInt($(".common-dialog").css("z-index"));
            $(".common-loading").css("z-index",a+100);
        }
        //30秒后，自动取消loading
        setTimeout( $.bindFn(this.unlock,this, [msgID] ) , timeout || 30000 );
    },

    /**
     * 结束锁屏状态
     */
    unlock : function(msgID){
        $(".common-loading[data-msgID='"+msgID+"']").remove();
    },

    /**
     * 获得实际货币数(舍去小数点后金额，不进行四舍五入)
     * @param {Number} number 金额
     * @param {Number} fractionDigits 小数点位数
     */
    currencyFormat: function(number, fractionDigits){
        return Math.floor( number * Math.pow( 10, fractionDigits) ) / Math.pow(10, fractionDigits);
    },



    /**
     * 显示确认提示框
     * @param {String} title 标题
     * @param {String||Object} text 内容 或 {content:内容 ,ok_text:确认按钮内容 ,cancel_text:取消按钮内容}
     * @param {Function} 用户行为回调函数  function(result)
     */
    confirm : function(title, text, callback){
        //仅创建一个实例
        if(document.getElementById("confirm-win")) return false;

        var confirm = new DGC.Confirm({
            title: title,
            text: text,
            callback: callback

        });
        confirm.show();
    },

    /**
     * 生成要保存或获取的本地储存KEY值
     * @param {String} userkey 自定义key值
     */
    localKey: function(userkey){
        return userkey + "_" +window.sdk.player.id;
    },

    /**
     * 延迟加载图标
     * @param {Array<Object>} icons 延迟加载图标
     * @param {Function} replaceCls 替换方法
     * @param {Number} delay 默认250毫秒
     */
    loadDelayIcons: function(icons, replaceFn, delay){
        var delay = delay || 250;
        setTimeout(function(){
            var queen = icons;
            for (var i = 0; i < queen.length; i++) {
               var iconObj = queen[i];
               //加载完成后，替换图标
               $.loadImg(iconObj.url,(function(){
                       return function(data){
                           var img = this;
                           DGC.ActionUtil.log("loaded image:"+ img.src);
                           replaceFn.call(this, img, data);
                       }
               })(), iconObj);
            };
        },delay);
    },

    /**
      * 灰色滤镜(HTML5)
      * @param {String} src 图片SRC地址
      */
    grayscale : function(src){
        var canvas = document.createElement('canvas');
        var ctx = canvas.getContext('2d');
        var imgObj = new Image();
        imgObj.src = src;
        canvas.width = imgObj.width;
        canvas.height = imgObj.height;
        ctx.drawImage(imgObj, 0, 0);
        var imgPixels = ctx.getImageData(0, 0, canvas.width, canvas.height);
        for(var y = 0; y < imgPixels.height; y++){
            for(var x = 0; x < imgPixels.width; x++){
                var i = (y * 4) * imgPixels.width + x * 4;
                var avg = (imgPixels.data[i] + imgPixels.data[i + 1] + imgPixels.data[i + 2]) / 3;
                imgPixels.data[i] = avg;
                imgPixels.data[i + 1] = avg;
                imgPixels.data[i + 2] = avg;
            }
        }
        ctx.putImageData(imgPixels, 0, 0, 0, 0, imgPixels.width, imgPixels.height);
        return canvas.toDataURL();
    }

};


