/**
 * 自定义窗口父类
 */
DGC.Dialog = $.inherits(DGC.UIBase,{

    /**
     * 不自动显示
     */
    autoShow: false,

    /**
     * 默认渲染位置
     * @type
     */
    renderTo : 'body',


    isDeferRender: true,

    isScrollable: false,

    maskTransparent: false,

    /**
     * 渲染模板
     * @type String url加载
     */
    renderTpl : "<div class='common-dialog' style='display:none;'><div class='header'></div><div class='body'></div></div>",

    viewReady: function(){},

    addMask: function(){
        this.mask = $($.format("<div class='common-mask common-dialog-mask' style='display:none;' id='{0}'></div>", [this.baseId+"-mask"]));
        if(this.maskTransparent){
            this.mask.removeClass("common-dialog-mask");
        }
        this.mask.insertBefore(this.el);
        this.resetMask();

         //监听旋屏，自动设置高度
        $(window).bind('orientationchange resize', {context: this}, this.resetMaskProxy);
    },


    //
    resetMaskProxy : function(event){
        var context =  event.data.context;
        context.resetMask();
    },

    /**
     * 监听滚动
     */
    listenOnScroll: function(event){
        var context = event.data.context;
        if(!context.isScrollable){
            event.preventDefault();
        }
    },

    /**
     * 重设Mask高度
     */
    resetMask: function(){
        var context = this;
        //延时设置Mask
        setTimeout(function(){
            if(document.body){
                context.mask.css({
                    "height": document.body.scrollHeight
                });
                if($(window).height() <= $(context.el).height()){
                    context.isScrollable = true;
                }else{
                    context.isScrollable = false;
                    //回退初始位置
                    DGC.ActionUtil.log("current Top:" + $(window).scrollTop());
                    DGC.ActionUtil.log("cache Top:"+ context.scrollPostion);
                    $(window).scrollTop(context.scrollPostion);
                }
            }
        },100);
    },

    setzIndex: function(){
        //获取当前最大z-index
        var maxZ = Math.max.apply(null,$.map($('body > *'), function(e,n){
           if($(e).css('position')=='absolute')
                return parseInt($(e).css('z-index'))||1 ;
           })
    	);
        //设置z-index
        this.mask.css("z-index", maxZ +1000 );
        this.el.css("z-index", maxZ + 1200);
    },

    onHide : function(){
        this.mask.hide();
    },

    onShow: function(){
        var zMasks = DGC.Dialog.ManagerUtil.zMasks;
        this.mask.show();

        //清除当前页面焦点
        $("input").each(function(index, dom) {
            dom.blur();
        });

        DGC.ActionUtil.clearFocus();

        //当前没有窗口，则调用Mask显示
        if(zMasks.length == 0 ){
            DGC.ActionUtil.setShade(false);
        }

        //存储当前Dialog表示存在
        zMasks.push(this.mask.attr('id'));
    },

    onRender : function(){

        this.setLocalString();

        DGC.Dialog.superclass.onRender.call(this);

        this.addMask();

        this.viewReady();

        this.setzIndex();

        //阻止用户scroll
        $(document).bind("touchmove", { context: this } , this.listenOnScroll);

        //缓存第一次显示的
        this.scrollPostion = $(window).scrollTop();

        //设置垂直居中
        if($(window).height() > this.el.height()){
            this.el.css({
                "top": $(window).scrollTop() + ($(window).height() - this.el.height()) / 2
            });
        }
    },

    onDestory: function(){
        var zMasks = DGC.Dialog.ManagerUtil.zMasks;

        //监听用户滚动
        $(document).unbind("touchmove", this.listenOnScroll);

        $(window).unbind('orientationchange resize',this.resetMaskProxy);

        this.mask.remove();
        this.mask = null;
        zMasks.pop();

        //当前没有Mask层则，隐藏Shade
        if(zMasks.length == 0 ){
            DGC.ActionUtil.setShade(true);
        }
    }
});


/**
 * 窗口管理类
 */
DGC.Dialog.ManagerUtil = {

    /**
     * 当前viewsMask层叠
     */
    zMasks: []

}


/**
 * 消息提示框
 */
DGC.Alert = $.inherits(DGC.Dialog,{

    baseId: "alert-win",

    text: undefined,

    /**
     * 提示框模板
     */
    renderTpl : "1.2.0/js/template/dialog/alert.html",

    callback: undefined,


    viewReady: function(){

        this.callback = this.callback || $.emptyFn;

        //设置内容
        var contentEl = this.el.find(".content"),
            okEl = this.el.find(".btn-ok");

        contentEl.text(this.text);
        okEl.text(resName.BUTTON_OK);
        //绑定事件
        okEl.bind(DGC.Common.E_TAP_DOWN,function(){
            $(this).addClass('active');
        });
        okEl.bind(DGC.Common.E_TAP_UP,function(){
            $(this).removeClass('active');
        });

        //确认按钮
        okEl.bind("tap", { context: this }, function(event){
            var context = event.data.context;
            setTimeout( $.bindFn(context.destory,context) , 500 );
        });

        //设置显示位置
        this.el.css( {"top": document.body.scrollTop} );
    },

    onInitialize :function(){
        DGC.Alert.ManagerUtil.add(this.id , this);
        DGC.Alert.superclass.onInitialize.call(this);
    },

    onDestory : function(){
        DGC.Alert.superclass.onDestory.call(this);
        this.callback.call(this);

        DGC.Alert.ManagerUtil.remove(this.id);
    }

});

/**
 * 弹出框工具类
 */
DGC.Alert.ManagerUtil = {

    /**
     * 缓存的弹出窗口对象
     */
    caches: {},

    /**
     * 缓存对象
     * @param {String} index alertID
     * @param {Object} instance 实例对象
     */
    add: function(id, instance){
        this.caches[id] = instance;
    },

    /**
     * 移除对象
     * @param {String} index alertID
     */
    remove: function(id){
        this.caches[id] = null;
        delete this.caches[id];
    },

    /**
     * 判断相同字符串提示是否存在
     * @param {String} error 提示字符串
     */
    isSameMsgShow: function(error){
        for(var key in this.caches){
            var instance = this.caches[key];
            DGC.ActionUtil.log("text:" + instance.text);
            if(instance.text == error){
                return true;
            }
        }
        return false;
    }
}

/**
 * 确认对话框
 */
DGC.Confirm = $.inherits(DGC.Dialog,{

    baseId: "confirm-win",

    title: undefined,

    text: undefined,

    callback: $.emptyFn,

    /**
     * 确认框模板
     */
    renderTpl : "1.2.0/js/template/dialog/confirm.html",

    viewReady: function(){

        //设置内容
        this.el.find(".header h1").text(this.title);

        var contentEl = this.el.find(".content"),
            okEl = this.el.find(".btn-ok"),
            cancelEl = this.el.find(".btn-cancel");


        if($.isString(this.text)){
            contentEl.text(this.text);
            okEl.text(resName.BUTTON_OK);
            cancelEl.text(resName.BUTTON_CANCEL);
        }else{
            contentEl.text(this.text.content);
            okEl.text(this.text.ok_text || resName.BUTTON_OK);
            cancelEl.text(this.text.cancel_text ||resName.BUTTON_CANCEL);
        }

        //绑定事件
        var btns = this.el.find(".btn");
        btns.bind(DGC.Common.E_TAP_DOWN,function(){
            $(this).addClass('active');
        });
        btns.bind(DGC.Common.E_TAP_UP,function(){
            $(this).removeClass('active');
        });

        //确认按钮
        this.el.find(".btn-ok").bind("tap", { context: this }, function(event){
            var context = event.data.context;
            setTimeout( $.bindFn(context.destory,context) , 500 );
            context.callback(true);
        });

        //取消按钮
        this.el.find(".btn-cancel").bind("tap",{ context: this }, function(event){
            var context = event.data.context;
            setTimeout( $.bindFn(context.destory,context) , 500 );
            context.callback(false);
        });
    }

});

/**
 * 输入对话框
 */
DGC.Prompt = $.inherits(DGC.Dialog, {

    /**
     * 对话框
     */
    title: undefined,

    /**
     * 回调
     */
    callback: undefined,

    /**
     * 确认框模板
     */
    renderTpl : "1.2.0/js/template/dialog/prompt.html",

    viewReady : function(){

        //设置内容
        this.el.find(".header h1").text(this.title);

        //确认按钮
        this.el.find(".btn-ok").bind("tap", { context: this }, function(event){
            var context = event.data.context;
            setTimeout( $.bindFn(context.destory,context) , 500 );
            context.callback(true);
        });

        //取消按钮
        this.el.find(".btn-cancel").bind("tap",{ context: this }, function(event){
            var context = event.data.context;
            setTimeout( $.bindFn(context.destory,context) , 500 );
            context.callback(false);
        });
    }
});
