/**
 * DGC业务逻辑公共方法以及公共枚举
 * @since SDK1.2
 */
DGC.Helper = {

    /**
     * 公共枚举声明
     */
    ATTR:{

        /*FeedAPI枚举*/
        /*性别*/
        GENDER:{
            SECRET: 0,
            MALE :  1,
            FEMALE : 2
        },
        /*SNS绑定过的字段值*/
        BIND_KEY:{
            SINA:'sina',
            RENREN: 'renren'
        },
        /*绑定SNS*/
        BIND_SNS:{
            SINA : 1,
            RENREN : 2,
            QQ: 4
        },
        /*同步SNS枚举*/
        SYNC_SNS:{
            SINA: 1,
            RENREN: 2,
            QQ: 4
        },
        /*同步操作类型*/
        SYNC_TYPE:{
            ALL: 1,
            AVATAR: 2,
            NAME: 3,
        },
        /*SDK枚举*/
        UPDATE_AVATAR : {
            CAMERA : "1",
            LOCAL : "2",
            FAKE_SINA : "3",
            FAKE_RENREN : "4"
        },
        /**
         * 登录窗口模式枚举(客户端)
         */
        USER_LOGIN_DIALOG : {
            LOGIN : 0, /*登录窗口*/
            SWITCH : 1 /*切换账号窗口*/
        }

    },

    /**
     * 公共业务方法声明
     */

    /**
     * 判断是否为自己
     * @param {String} id
     */
    isMe: function(id){
        return (id == window.sdk.player.id);
    },

    /**
     * 是否支持积分墙
     */
    isSupportIntegral : function(){
        return window.sdk.integralState;
    },

    /**
     * 是否支持活动
     */
    isSupportActivities:function(){
        return window.sdk.activitiesState;
    },

    /**
     * 是否支持兑换码
     */
    isSupportPromotion: function(){
        return window.sdk.promotionState;
    },

    /**
     * 判断玩家是否绑定过任意SNS
     */
    isAnySNSBound : function(){
        var KEY = this.ATTR.BIND_KEY;
        return this.isSNSBound(KEY.SINA) || this.isSNSBound(KEY.RENREN);
    },

    /**
     * 判断玩家是否绑定指定SNS
     * @param {String} snsKey 绑定后字段标识  ATTR.BIND_KEY
     */
    isSNSBound : function(snsKey){
        return  window.sdk[snsKey] != null;
    },

    /**
     * 判断玩家已绑定指定SNS是否过期
     * @param {String} snsKey 绑定后字段标识 ATTR.BIND_KEY
     */
    isSNSExpried : function(snsKey){
        return  window.sdk[snsKey].expired;
    },

    /**
     * 判断当前是否绑定手机
     */
    isPhoneBound : function(){
        return !$.isEmpty(window.sdk.security.phone);
    },

    /**
     * 获得上传头像用数据源
     */
    getUploadAvatarComboxData : function(){
        var ATTR = DH.ATTR,
            defaultWays = [
             { text: resName.OPTION_SETTING_CHANGE_AVATAR_CAMER , value: ATTR.UPDATE_AVATAR.CAMERA } ,
             { text: resName.OPTION_SETTING_CHANGE_AVATAR_LOCAL , value: ATTR.UPDATE_AVATAR.LOCAL },
        ];

        //新浪头像
        if(this.isSNSBound(ATTR.BIND_KEY.SINA)){
            defaultWays.push({
                text: resName.OPTION_SETTING_CHANGE_AVATAR_SINA,
                value: ATTR.UPDATE_AVATAR.FAKE_SINA
            });
        }

        //人人头像
        if(this.isSNSBound(ATTR.BIND_KEY.RENREN)){
            defaultWays.push({
                text: resName.OPTION_SETTING_CHANGE_AVATAR_RENREN,
                value: ATTR.UPDATE_AVATAR.FAKE_RENREN
            });
        }

        return defaultWays;
    }

}

/**
 * 全局命名空间
 */
window.DH = DGC.Helper;