/**
 * UI Base类模块
 */
DGC.UIBase = $.inherits(jQuery.Observer , {

    /**
     * 组件ID
     * @type String
     */
    id : undefined,

    /**
     * 模板ID
     * @type String
     */
    baseId: undefined,

    /**
     * 是否异步从模板加载HTML
     * @type Boolean
     */
    isDeferRender:false,

    /**
     * 渲染模块模板
     * @type String url 或 HTML片段
     */
    renderTpl : '<div></div>',

    /**
     * 子模板表达式符号
     * 如：<*= *>
     */
    viewTplSign: "*",

    /**
     * View需要的数据渲染模板
     * @type
     */
    viewTpl : {},

    /**
     * 判断模板是否加载完成
     * @type Boolean
     */
    isTplReady : false,

    /**
     * 是否该组件已经渲染完成
     * @type Boolean
     */
    rendered : false,

    /**
     * 默认渲染位置
     * @type {String || HTML ELEMENT} 元素id 或 DOM元素
     */
    renderTo: undefined,

    /**
     * 默认是否渲染后显示
     * @type Boolean
     */
    autoShow: false,

    /**
     * 是否已经销毁
     * @type Boolean
     */
    destoryed: false,

    /**
     * 图标回调方法
     */
    loadImgCallback : undefined,

    /**
     * 图标请求数据
     */
    loadImgData : undefined,


    /**
     * 构造函数
     */
    constructor : function(config){
        $.extend(this, config || {});
        //声明模块自定义事件
        this.defineEvents(
            'beforerender',
            'render',
            'destory',
            'show',
            'hide'
        );

        this.id = this.getId();

        //加载图片相关数据
        this.loadImgCallback = {};
        this.loadImgData = {};

        this.initialize();
    },

    onInitialize : $.emptyFn,

    onDestory : $.emptyFn,

    onShow : $.emptyFn,

    onHide : $.emptyFn,

    /**
     * 获得组件默认ID
     * @return {}
     */
    getId : function(){
        return this.id || 'dgc-ui-' + ( ++DGC.UIBase.INCREASE_ID );
    },

    initialize : function(){
        this.onInitialize();

        //设置模板内容加载状态
        this.isTplReady = !this.isDeferRender;

        //从其他模块加载HTML静态模板
        if(this.isDeferRender){
            this.renderTpl = Loader.isBaseFile(this.renderTpl) ? this.renderTpl : (window.sdk.rootpath + this.renderTpl);
            //加载TPL
            $.ajax({
                url: this.renderTpl,
                context: this,
                success: this._loadTplReady
            });
        }else{
            //非异步模板直接渲染
            this.render();
        }
    },

    /**
     * 加载模板内容成功
     */
    _loadTplReady : function(text, status, xhr){
        this.renderTpl = xhr.responseText;

        //置标识位
        this.isTplReady = true;

        this.render();
    },

    render : function(){
        //获取当前渲染对象
        if(!this.rendered && this.isTplReady && !this.destoryed){
            this.fire('beforerender', this);

            this.onRender();

            //判断是否渲染后直接显示
            if(this.autoShow){
                this.show();
            }

            this.fire('render', this);
        }
    },

    onRender : function(){
        var el = $(this.renderTpl),
            container = $(this.renderTo);

        //设置模板ID
        if(this.baseId){
            el.attr('id', this.baseId);
        }

        container.append(el);
        this.el = el;
        this.rendered = true;
    },

    show : function(){
        //ref self Fn
        var selfFn = arguments.callee;

        //已经销毁，不再显示
        if(this.destoryed){
            return false;
        }

        //立即显示
        if(this.rendered ){
            this.el.show();
            this.onShow();
            this.fire('show', this);
        //异步加载需要等待
        }else{
            //显示前需要等待渲染完成
           setTimeout($.bindFn(selfFn, this),100);
        }
    },

    hide : function(){
        if(this.rendered){
            this.el.hide();
            this.onHide();
            this.fire('hide', this);
        }
    },

    destory : function(){

        if(this.destoryed) return false;
        if (this.rendered) {
            this.el.remove();
            this.el = null;
        }

        this.onDestory();
        this.destoryed = true;
        this.fire('destory', this);
    },

    /**
     * 设置视图静态字符串
     */
    setLocalString : function(){
        this.renderTpl = $.jqote(this.renderTpl, resName);
    },

    /**
     * 根据模板和数据生成HTML结构
     * @param {Mix} el template : jQuery object | jQuery selector | DOM element | template string
     * @param {Object} data 模板数据
     */
    renderByTpl: function(el, data){
        var tpl = $.jqotec(el, this.viewTplSign);
        return $.jqote(tpl, data, this.viewTplSign);
    },

    /**
     * 加载缓存图标方法
     * @param 图标对象  {url : callback}
     */
    loadImages : function(images, fn, delay){
        var urls ,
            imgObj,
            images = $.isArray(images) ? images : [images];

        //无图片需要加载
        if(images.length == 0){
            return false;
        }

        //SDCard已插入，则使用本地方法加载
        if(window.sdk.sdcardState){
             urls = [];
             for(var i = 0; i < images.length ; i++){
                imgObj = images[i];
                //缓存请求对象
                var callbacks = this.loadImgCallback[imgObj.url] || [],
                    datas = this.loadImgData[imgObj.url] || [];

                callbacks.push(fn);
                datas.push(imgObj);

                this.loadImgCallback[imgObj.url] = callbacks;
                this.loadImgData[imgObj.url] = datas;

                //仅请求
                if(datas.length == 1){
                    urls.push(imgObj.url);
                }

             }
             DGC.ActionUtil.loadImages(this.id, urls);
        //无SDCard，则直接通过网络访问
        }else{
            DGC.Common.loadDelayIcons(images, fn, delay);
        }
    },

    /**
     * 本地异步请求图片结果Ready
     */
    asycImgReady : function(image){
        //获得图片地址后，加载当前图片
        var callbacks = this.loadImgCallback[image.url],
            datas = this.loadImgData[image.url];

        if(callbacks && callbacks.length > 0 ){
            DGC.ActionUtil.log("begin image load:"+ image.local);

            //需要替换的图片URL
            for(var i = 0 ; i < datas.length; i++ ){
                $.extend(datas[i], { url: image.local });
            }

            DGC.Common.loadDelayIcons( datas , callbacks[0] /*暂只支持一个Callback*/);

            //释放缓存
            this.loadImgCallback[image.url] = null;
            this.loadImgData[image.url] = null;
        }
    }

});

//自增默认ID
DGC.UIBase.INCREASE_ID = 10000;

/**
 * 延时显示时间(毫秒)
 */
DGC.DELAY_SHOW_TIME = 300;

/**
 * 命名空间
 * @type
 */
DGC.Module = $.inherits(DGC.UIBase, {

    /**
     * 默认渲染位置
     * @type
     */
    renderTo : 'body',

    /**
     * 渲染模板
     * @type String url加载
     */
    renderTpl : "<div data-role='nav-page' class='dgc-page'></div>",

    /**
     * 视图堆栈(用于保存记录页面)
     * @type
     */
    viewStack: null,

    /**
     * 默认加载视图(类名)
     * @type String 位于DGC.View命名空间下
     */
    deafultView: undefined,

    /**
     * 当前显示视图
     * @type String
     */
    currentView : undefined,

    initialize: function(){
        DGC.Module.superclass.initialize.call(this);
        this.viewStack = [];
    },

    /**
     * 判断是否根页面
     * 具体模块override
     */
    isRootPage: function(){
        return false;
    },

    /**
     * 加载模块内视图
     * @param {String} viewName 模块名称
     * @param {Object} params   视图初始化参数
     * @param {Boolean} reset   是否要重置模块
     * @param {Boolean} nosave 是否保存当前视图
     */
    setView : function(viewName, params, reset, nosave){
        var args = Array.prototype.slice.call(arguments);
        //hack延迟跳转页面,规避在touch events没发送完前，渲染html,导致渲染后的HTML获得焦点
        setTimeout($.bindFn(this._setView, this, args), DGC.DELAY_SHOW_TIME);
    },

    /**
     * 私有方法
     */
    _setView: function(viewName, params , reset, nosave){

        DGC.ActionUtil.log("viewName:"+ viewName);

        //清空视图栈
        if(reset){
           //已经是根页面无须重新返回
           if(this.isRootPage()) return false;

           //当期处于属于默认视图
           this.clearViews();
        }
        //存在模块内当前显示视图
        else if(this.currentView){
           //当前视图记录入栈
           this.pushView(nosave);
        }

        //设置视图名称/视图初始化参数
        var name  = viewName || this.deafultView,
            initParams = params || {};

        var defaultParams = {
            action : this,      //Controller
            renderTo: this.el,  //渲染节点
            name : name,        //视图名称
            initConfig : initParams //初始化配置参数
        };

        //判断View是否存在，如果不存在，动态加载读取配置JS和CSS
        var viewClass = DGC.View[name],
            viewConfig  = QueenConfig.viewConfig[name];
        if(viewClass == null){
            var delayReady  =  $.bindFn( this._createView, this, [name, defaultParams]);
            DGC.ActionUtil.log("loader js:"+ viewConfig.js);
            $LAB.script(viewConfig.js).wait(delayReady);
            //CSS可选
            if(!$.isEmpty(viewConfig.css)) window.loadCss(viewConfig.css);
        }else{
            this._createView( name, defaultParams);
        }
    },

    /**
     * private
     * 创建视图
     * @param {String} viewName 视图名
     * @param {Object} params 初始化参数
     */
    _createView : function(viewName, params){

        DGC.ActionUtil.log("create View:"+ viewName);

         //加载指定视图并显示
        this.currentView = new DGC.View[viewName](params);

        this.currentView.show();
    },

    /**
     * 显示弹出窗口
     */
    showDialog: function(name,  params, callback, scope){
        var args = Array.prototype.slice.call(arguments);
        //hack延迟跳转页面,规避在touch events没发送完前，渲染html,导致渲染后的HTML获得焦点
        setTimeout($.bindFn(this._createDialog, this, args), DGC.DELAY_SHOW_TIME);
    },

    /**
     * private
     * 创建窗口
     */
    _createDialog: function(name, params, callback, scope){
         //判断Dialog是否存在，如果不存在，动态加载读取配置JS和CSS
        var dialogClass = DGC.Dialog[name],
            config  = QueenConfig.dialogConfig[name];
        if(dialogClass == null){
            var delayReady  =  $.bindFn( callback, scope, [name, params]);
            $LAB.script(config.js).wait(delayReady);
            window.loadCss(config.css);
        }else{
            callback.call(scope, name, params);
        }
    },

    /**
     * 清理历史视图
     */
    clearViews: function(){
        this.viewStack = [];
        this.currentView.destory();
        this.currentView = null;
    },

    /**
     * 当前视图入栈历史记录(模块)堆栈
     * @param {Boolean} nosave 不保存当前视图
     */
    pushView : function(nosave){
        if(!nosave){
            this.viewStack.push({
                name : this.currentView.name,
                config: this.currentView.initConfig
            });
        }

        this.currentView.destory();
        this.currentView = null;
    },

    /**
     * 当前视图出栈历史记录(模块)堆栈
     * @param {Number} views 回退视图数
     */
    popView : function(views){
        if(views != undefined && views > 1){
            //多层退栈
            var removes = views - 1;
            while(removes--){
                this.viewStack.pop();
            }
        }

        var viewConfig = this.viewStack.pop();

        //移除当前view,出栈，渲染
        if(this.currentView){
            this.currentView.destory();
            this.currentView = null;
        }

        //回退视图参数
        var params = {
            renderTo: this.el,             //渲染节点
            action : this,                 //Controller
            name : viewConfig.name,        //视图名称
            initConfig: viewConfig.config  //初始化参数
        };

        //判断View是否存在，如果不存在，动态加载读取配置JS和CSS
        var viewClass = DGC.View[viewConfig.name],
            config  = QueenConfig.viewConfig[viewConfig.name];
        if(viewClass == null){
            var delayReady  =  $.bindFn( this._createView, this, [viewConfig.name, params]);
            $LAB.script(config.js).wait(delayReady);
            //CSS可选
            if(!$.isEmpty(config.css)) window.loadCss(config.css);
        }else{
            this._createView(viewConfig.name, params);
        }
    },

    /**
     * 自动注册相关事件
     * @param {Object} eventsInfo 事件对象 如：DGC.Module.XXXXXX.EventProxy
     */
    autoRegsiterEvents:function(eventsInfo){
        for(var modelName in eventsInfo){
            var events = eventsInfo[modelName];
            for(var eventName in events){
                this.model[modelName].on(eventName, this.eventProxy(eventName, events[eventName]), this);
            }
        }
    },

    /**
     * 事件代理触发
     */
    eventProxy: function(eventName, proxyObj){
        var en = eventName, me = this;
        return function(){
            if(proxyObj == null) return false;
            var ec = $.isArray(proxyObj) ? proxyObj : [ proxyObj ],
                args = arguments;
            /**
             * 向各个配置视图分发数据
             */
            for (var i = 0; i  < ec.length; i ++) {
                var view = ec[i];
                 //如果当前界面正处于显示状态,则执行视图回调函数
                if(me.isViewShow(view.viewName)){
                    me.currentView[view.fnName].apply(me.currentView, args);
                }
                //如果存在callback函数，无论是否显示都将执行
                if(view.callback){
                    view.callback();
                }
            };
        }
    },

    /**
     * 判断是否存在历史视图
     * @param {views} 视图数
     */
    hasHistoryView : function(views){
        return ( this.viewStack.length != 0 && this.viewStack.length >= (views || 0 ) );
    },

    /**
     * 判断当前是否为指定视图显示
     * @param {String} viewName 视图名称
     */
    isViewShow : function(viewName){
        return DGC.View[viewName] && this.currentView instanceof DGC.View[viewName];
    },

    /**
     * 切入显示
     */
    onShow : function(){

    },

    /**
     * 切出隐藏
     */
    onHide : function(){
        //切出当前Tab时,将当前视图入栈
        this.pushView();
    }

});

/**
 * 缓存已经创建的导航模块
 * @type
 */
DGC.Module.CacheModules = {};

/**
 * 模块标示KEY
 */
DGC.Module.ATTRS = {
    //ACTIVITY   : 0, //活动
    ACHIEVEMENT: 'achivement', //成就
    HIGHSCORES : 'highscore', //排行榜
    ME: 'me',        //我
    GAME: 'game',      //游戏
    PAYMENT: 'payment', //支付
    PROMOTIONBANNER: 'promotionbanner'//交叉推广广告
};

/**
 * 模块Utils
 */
DGC.Module.Utils = {

    classMap:{
        'me': "Me",
        'achivement':"Achievement",
        'highscore': "HighScores",
        'game': "Game",
        'payment': "Payment",
        'promotionbanner': "PromotionBanner"
    },

    /**
     * 获得模块默认viewName
     */
    getDefaultView: function(id){
        return DGC.Module[this.classMap[id]].prototype.deafultView;
    }
}

/**
 * View视图模块
 */
DGC.View = $.inherits(DGC.UIBase, {

    /**
     * 标识是否为子视图
     * @type Boolean
     */
    isSub: true,

    /**
     * 异步加载模板 为URL时为true
     * @type Boolean
     */
    isDeferRender : true,

    /**
     * 标题内容
     * @type String
     */
    title: false,

    /*视图扩展渲染完成后*/
    viewReady: $.emptyFn,

    //初始化
    onInitialize: function(){
        $.extend(this, this.initConfig);
    },

    /**
     * 视图按后退键
     * @return {Boolean} 返回true/false,决定是否继续调用通用后退方法
     */
    backAction: function(){
        return true;
    },

    /**
     * 设置视图标题
     */
    setTitle : function(text){
        DGC.ActionUtil.setTitle(text);
    },

    /**
     * 设置返回键是否显示
     * @param {Boolean} 是否显示返回按钮
     */
    setBackEnable: function(state){
        DGC.ActionUtil.enableSubNav(state);
    },


    onRender : function(){

        //判断是否设置标题栏字体,优先使用配置title,然后使用title属性
        if(this.initConfig.title){
            this.setTitle(this.title);
        }else if(this.title){
            this.title = resName[this.title];
            this.setTitle(this.title);
        }

        //设置标题栏返回键
        this.setBackEnable(this.isSub);

        //替换模板中的本地字符串
        this.setLocalString();

        DGC.View.superclass.onRender.call(this);

        //渲染完成
        this.viewReady();
    }

});