/**
 * DGC公共服务类(单例)
 */
DGC.Service = $.inherits(jQuery.Observer, {

    /**
     * 子模块初始化标志
     * @type
     */
    models:{
        HighScores : false,
        Achievement : false,
        Game : false,
        Me: false,
        Payment: false,
        PromotionBanner:false
    },

    /**
     * 当前显示的模块
     * @type
     */
    currentModule: undefined,

    constructor : function(){
        //注册自定义事件
        var messages = DGC.Service.Messages;
        for(var key in messages ){
            this.defineEvents(messages[key]);
        }
    },

    /**
     * 切换当前显示的页面
     * @param {id}
     */
    navigateToView : function(viewConfig){
        //判断当前导航模块是否声明
        var moduleDefined = false;
        for(var key in DGC.Module.ATTRS){
            if(DGC.Module.ATTRS[key] === viewConfig.id){
                moduleDefined = true;
                break;
            }
        }

        //存在导航模块
        if(moduleDefined){
            //判断当前显示的Module,第一次加载则创建
            var module = DGC.Module.CacheModules[viewConfig.id] || this._createModule(viewConfig.id);
            this._loadModule( module, viewConfig);
        }else{
            DGC.ActionUtil.log('加载非法导航模块:' + id);
        }
    },

    /**
     * 视图回退/退出游戏方法
     * @param views {Number} 自定义回退
     */
    viewStatusBack : function(views){
        //当前模块已经初始化
        if(!this.currentModule) return false;

        //获得当前显示视图
        var currentView = this.currentModule.currentView;

        //返回层次数
        var backViews = views || Number(currentView.backAction());

        //执行完自定义Back方法后，是否继续执行View Back
        if(backViews){
            //如果存在历史视图，显示上一次查看视图
            if(this.currentModule.hasHistoryView(backViews) ){
                this.currentModule.popView(backViews);
            //位于顶层视图，则显示退出游戏提示框
            }else{
                DGC.ActionUtil.returnToGame();
            }
        }
    },

    /**
     * private
     * 创建UI模块
     * @param {Number} id 要创建的模块key值
     */
    _createModule : function(id){
        var ATTRS = DGC.Module.ATTRS,
            module;
        switch(id){
            //成就
            case ATTRS.ACHIEVEMENT:
                module = this.getAchievementModule();
                break;
            //高分榜
            case ATTRS.HIGHSCORES:
                module = this.getHighScoreModule();
                break;
            //我
            case ATTRS.ME:
                module = this.getMeModule();
                break;
            //游戏
            case ATTRS.GAME:
                module = this.getGameModule();
                break;
            case ATTRS.PAYMENT:
                module = this.getPaymentModule();
                break;
            case ATTRS.PROMOTIONBANNER:
                module = this.getPromotionBannerModule();
                break;
            default:
                break;
        }

        //缓存模块
        DGC.Module.CacheModules[id] = module;

        return module;
    },

    /**
     * private
     * 切换当前显示模块
     * @param {Object} module 要显示的模块
     * @param {String} viewName
     */
    _loadModule : function(module , config){
        //初次加载
        if(!this.currentModule){
            //切换当前指向新模块
            this.currentModule = module;
            //直接跳转，使用私有方法(不延迟)
            this.currentModule._setView( config.viewName, config.params);
            this.currentModule.show();
        //加载切换属于不同模块，隐藏原模块
        }else if(module != this.currentModule){
            //如果原模块视图入栈
            this.currentModule.hide();

            //切换当前指向新模块
            this.currentModule = module;

            //如果新显示的模块有历史视图，直接显示当前视图
            if(this.currentModule.hasHistoryView()){
               this.currentModule.popView();
            }else{
                //直接跳转，使用私有方法(不延迟)
                this.currentModule._setView( config.viewName, config.params);
            }

            this.currentModule.show();
        //同一模块内切换，直接切换视图
        }else {
            //直接跳转，使用私有方法(不延迟)
            this.currentModule._setView( config.viewName, config.params , config.reset);
        }

    },

    /**
     * 响应消息结果
     * @param {Object} msg 消息结果
     */
    messageHandler: function(msg){
        this.fire(msg.msgInfo.msgID, msg);
    },

    /**
     * 获得成就数据模型
     */
    getAchievementModel: function(){
        if(!this.models.Achievement){
            this.models.Achievement = new DGC.Model.Achievement({
                service: this
            });
        }

        return this.models.Achievement;
    },

    /**
     * 获得排行榜数据模型
     */
    getHighScoresModel: function(){
        if(!this.models.HighScores){
            this.models.HighScores = new DGC.Model.HighScores({
                service: this
            });
        }

        return this.models.HighScores;
    },

    /**
     * 获取"我"数据模型
     */
    getMeModel : function(){
        if(!this.models.Me){
            this.models.Me = new DGC.Model.Me({
                service: this
            });
        }

        return this.models.Me;
    },

    /**
     * 获取游戏数据模型
     */
    getGameModel : function(){
        if(!this.models.Game){
            this.models.Game = new DGC.Model.Game({
                service: this
            });
        }

        return this.models.Game;
    },

    /**
     * 获取支付/充值模型
     */
    getPaymentModel : function(){
        if(!this.models.Payment){
            this.models.Payment = new DGC.Model.Payment({
                service: this
            });
        }

        return this.models.Payment;
    },

    /**
     * 获取交叉推广广告模型
     */
    getPromotionBannerModule : function(){
        if(!this.models.PromotionBanner){
            this.models.PromotionBanner = new DGC.Model.PromotionBanner({
                service: this
            });
        }
        return this.models.PromotionBanner;
    },

    /**
     * 创建成就业务模型
     */
    getAchievementModule : function(){
        return new DGC.Module.Achievement({
            model: {
                'achi' : this.getAchievementModel(), //成就数据模型
                'prombanner' : this.getPromotionBannerModule()//交叉推广数据模型
            }
        });
    },

    /**
     * 创建排行榜业务模型
     */
    getHighScoreModule : function(){
        //引用多个数据模型
        return new DGC.Module.HighScores({
            model: {
                'hs' : this.getHighScoresModel(), //HighScore数据模型
                'me' : this.getMeModel(),          //Me数据模型
                'achi' : this.getAchievementModel(), //成就数据模型
                'pay': this.getPaymentModel(),     //支付数据模型
                'prombanner' : this.getPromotionBannerModule()//交叉推广数据模型
            }
        });
    },

    /**
     * 创建"我"业务模型
     */
    getMeModule : function(){
        //引用多个数据模型
        return new DGC.Module.Me({
            model: {
                'hs' : this.getHighScoresModel(), //HighScore数据模型
                'me' : this.getMeModel(),          //Me数据模型
                'achi' : this.getAchievementModel(), //成就数据模型
                'pay': this.getPaymentModel(),     //支付数据模型
                'game': this.getGameModel(), //游戏模块
                'prombanner' : this.getPromotionBannerModule()//交叉推广数据模型
            }
        });
    },

    /**
     * 创建"游戏"业务模型
     */
    getGameModule : function(){
        return new DGC.Module.Game({
            model: {
                'game' : this.getGameModel(),          //游戏数据模型
                'prombanner' : this.getPromotionBannerModule()//交叉推广数据模型
            }
        });
    },

    /**
     * 创建"支付"业务模型
     */
    getPaymentModule : function(){
        return new DGC.Module.Payment({
            model: {
                'pay': this.getPaymentModel()
            }
        });
    }

});

/**
 * 前后台交互接口声明
 * @type
 */
DGC.Service.Messages = {
    //正常模式
    QUERY_LOAD_TIPS  : 0, //查询初始化应用参数请求
    QUERY_AREA_RANK  : 1, //查询区域排行榜
    QUERY_WORLD_RANK : 2, //查询全球排行榜
    QUERY_FRIEND_RANK: 3, //查询好友排行榜
    QUERY_LEADERBOARD_LIST: 4,  //查询排行模式
    QUERY_PLAYER_ACHIEVE_LIST: 5, //查询游戏的成就列表
    QUERY_PLAYER_PLAYED_GAMES: 6, //查询玩家玩过的游戏
    QUERY_PLAYER_FRIENDS: 7, //查询玩家的好友(互相关注和主动关注的人)
    QUERY_PLAYER_FANS: 8,    //查询玩家的fans(被其他人关注)
    QUERY_PLAYER_DETAIL: 9,  //玩家详细信息
    QUERY_PLAYER_RECORDS: 10, //查询玩家某个游戏中的信息
    UPDATE_PLAYER_AVATAR: 11,  //上传头像通知消息
    QUERY_REFRESH_PLAYER_DETAIL: 12, //更新用户信息
    UPDATE_PLAYER_NAME: 13, //更新用户昵称
    QUERY_FRIENDS: 14,  //搜索好友
    QUERY_LOCAL_GAME: 15, //查询游戏的列表
    QUERY_LOCAL_GAME_STATE : 16, //查询游戏在Android客户端是否安装
    UPDATE_CREATE_FRIENDSSHIP: 17, //创建好友关系
    UPDATE_DESTORY_FRIENDSSHIP :18, //取消好友关系
    UPDATE_SET_PASS : 19, //设置密码
    UPDATE_MODIFY_PASS : 20, //修改密码
    QUERY_FEED_BACK : 21, //体验反馈
    UPDATE_CREATE_ACCOUNT : 22, //切换新账号
    UPDATE_CHECK_SNS_ACCOUNT:23, //验证SNS账户密码
    UPDATE_INVITE_FRIENDS: 24, //邀请好友
    QUERY_CAPTCHA : 25, //获取验证码
    UPDATE_SINA_REG_ONE : 26, //新浪注册1
    UPDATE_SINA_REG_TWO : 27, //新浪注册2
    UPDATE_SNS_BIND : 28, //第三方绑定(人人，新浪)
    QUERY_PLAYER_COINS: 29, //查询玩家余额信息(我的钱包)
    QUERY_CHARGE_HISTORY:30 , //查询充值记录
    UPDATE_UNBIND: 31, //取消绑定
    UPDATE_INVITE_FRIENDS_ALREADY : 32, //邀请好友（已经绑定了）
    QUERY_CHARGE_LIST: 33, //查询支付方式
    UPDATE_SEND_WEIBO : 34, //获得成就发微博
    UPDATE_PAYMENT_CHARGE: 35, //Feed API充值消息
    QUERY_SHOP_ITEMS: 36, //获得道具列表
    QUERY_PAY_PRODUCTINFO: 37, //获取需要支付的道具信息
    UPDATE_PAY_BY_LEDOU: 38, //乐币支付消息
    UPDATE_CHARGE_GFAN: 39,  //机锋充值
    UPDATE_PAY_BY_FEED: 40,  //FEED API支付
    UPDATE_PAY_BY_LOCAL: 41, //本地支付
    QUERY_PLAYER_COINS_SHOP:42, //查询玩家余额信息(商城)
    QUERY_INVITE_MSG:43,    //查询邀请好友模板消息
    UPDATE_SINA_WEIBO:44,   //发送新浪微博
    QUERY_ME_PREV_DETAIL:45,      //预加载我的游戏成就和排行模式信息
    UPDATE_SNS_SYNC: 46, //同步用户数据
    QUERY_TIPS_SUCCESS:47,  //查询TIPS成功
    UPDATE_NEW_PLAYER_INFO: 48 , //新用户修改昵称/性别
    UPDATE_PLAYER_GENDER:49, //用户性别修改
    QUERY_INTEGRAL_INFO: 50, //查询支持的积分类型
    QUERY_PAYMENT_DETAIL: 51, //查询指定支付方式详情
    UPDATE_PAY_BY_INTEGRAL: 52, //积分支付
    QUERY_LATEST_ACTIVITY:53,//最新活动
    QUERY_CIRCUSEE_ACTIVITY:54,//已围观的活动
    UPDATE_CIRCUSEE_ACTIVITY:55,//围观活动
    UPDATE_PROMOTIONCODE:56,//提交兑换码
    QUERY_SNS_SHARE_CONTENT: 57, //查询SNS分享内容
    UPDATE_SNS_MSG_SEND: 58,	//分享SNS内容
    QUERY_PROMOTION_BANNER:59,//取指定广告位的所有广告(轮询式)
    PROMOTION_BANNER_COUNT:60,//收集广告的展示数
    PROMOTION_BANNER_CLICK: 61,//广告点击

    //离线模式
    QUERY_OFFLINE_ACHIEVE: 1000, //离线成就信息
    QUERY_OFFLINE_LEADERBOARD_LIST: 1001, // 离线排行模式
    QUERY_OFFLINE_HIGHSCORES: 1002, //离线高分榜

    //指定Combox业务方法
    SHOW_BUY_ITEM_NUMS: 2000, //商城购买选择买多少个
    SHOW_UPDATE_PLAYER_ICON_WAYS: 2001 //显示头像上传方法
}
