/**
 * 相关公共方法封装
 * @type
 */
DGC.ActionUtil = {

    /**
     * 默认请求信息
     * @type
     */
    actionObj : {
        msgID : undefined,
        actionName : 'apiRequest',
        needAuth : true,
        needSessionId : true,
        needEncode: true,
        method : 'POST',
        url : 'batch',
        params : {},
        plugData: {}
    },

    /**
     * private
     * 调用Android的通用接口,调用失败则抛出异常
     */
    callAction : function(obj){
        //序列化请求
        var serialize  = $.toJSON(obj);
        if("NativeInterface" in window){
            DGC.ActionUtil.log(serialize);
            NativeInterface.action(serialize);
        }else{
            //否则抛出异常
            throw new Error(serialize);
        }
    },

    /**
     * 请求获取/下发API相关参数
     * @param {Object} actionObj 参数对象
     */
    requestAPI : function(actionObj, hideMask){
        //当前显示模块
        var currentModule = DGC.Application.service.currentModule;

        //获得请求参数
        //默认显示loader
        if(!hideMask){
            DGC.Common.lock(actionObj.msgID);
        }
        var params = $.extend(DGC.ActionUtil.actionObj,  actionObj || {});
        if(currentModule && currentModule.currentView ){
             //缓存请求所属页面ID
            params.plugData.viewId = currentModule.currentView.id;
        }

        DGC.ActionUtil.callAction(params);
    },

    /**
     * 加载图片
     * @param {String} viewId 视图ID
     * @param {Array} images 图片地址
     */
    loadImages : function(viewId, images){
        DGC.ActionUtil.callAction({
            actionName : 'loadImages',
            viewName: viewId,
            imgs: images
        });
    },

    /**
     * 请求Android端打印LOG信息
     * @param {String||Object} message 信息内容
     */
    log : function(message){
        //联调模式
        if(DEBUG.isDeviceModel()){
           if ('NativeInterface' in window) {
               NativeInterface.action($.toJSON({
                   actionName : 'log',
                   message : message
               }));
           }
        }
    },


    /**
     * 遍历对象自己,并打印成员变量的值
     * @param {Object} obj JS对象
     */
    print : function(obj){
        if(!DEBUG.isProductModel()){
            for(var key in obj){
                console.log($.format("key:{0};value:{1}", [ key , obj[key]] ));
            }
        }
    },

    /**
     * Web Client log(部署模式不记录)
     * @param {String} log 需要答应的log字符串
     */
    log: function(log){
        if(!DEBUG.isProductModel()){
            console.log(log);
        }
    },

    /**
     * 显示Tip提示
     */
    showTipMsg : function(text, fn){
        // DGC.ActionUtil.callAction({
            // actionName: "showTipMsg",
            // text: text
        // });
        // //Web Debug
        // if(DEBUG.isWebModel()){
            // alert(text);
        // }
        setTimeout(function(){
            if(!DGC.Alert.ManagerUtil.isSameMsgShow(text)){
                //判断当前Alert是否内容相同
                new DGC.Alert({ text: text, callback : fn }).show();
            }
        },300);

    },

    /**
     * 移除Webview中的焦点
     */
    clearFocus: function(){
        DGC.ActionUtil.callAction({
            actionName: "removeFocus"
        });
    },

    /**
     * 通知 Android WebView 页面APP加载成功
     */
    requestAppInit : function(callback){
        if ("NativeInterface" in window) {
            //异步请求设备/版本信息
            NativeInterface.action(JSON.stringify({
                actionName: 'getInitInfo',
                callback: callback
            }));
        }
    },

    /**
     * 重新刷新初始化对象
     */
    refreshAppInfo : function(){
        DGC.ActionUtil.callAction({
            actionName: "retrieveAccountInfo"
        });
    },

    /**
     * 将SDK某个Tab置为高亮状态
     * @param {Number} key Tab枚举值
     */
    hightLightTab: function(key){
        DGC.ActionUtil.callAction({
            actionName: "tabSwitch",
            tag: key
        });
    },

    /**
     * 设置Android标题文本
     * @param {String} text DGC标题文字
     */
    setTitle : function(title){
        DGC.ActionUtil.callAction({
            actionName : "changeTitle",
            text : title
        });
    },

    /**
     * 是否显示子界面视图中的返回按钮
     * @param {Boolean} enable
     */
    enableSubNav : function(enable){
        DGC.ActionUtil.callAction({
            actionName : "enableSubPageBack",
            status : enable
        });
    },

    /**
     * 全屏显示WebView
     */
    fullScreen : function(show){
        DGC.ActionUtil.callAction({
            actionName : "fullScreen",
            isFullScreen : show
        });
    },

    /**
     * 隐藏底部Bottom Bar
     */
    hideBottomBar : function(hide){
        DGC.ActionUtil.callAction({
            actionName : "hiddenBottom",
            isVisible : hide
        });
    },

    /**
     * 背景透明
     */
    transparentBG : function(){
        DGC.ActionUtil.callAction({
            actionName : "transparent",
        });
    },

    /**
     * 调用Android SDK的Combox组件
     * @param {Number} msgID 业务ID
     * @param {Array<Object>} items  {text:"标签名",value: 内容值}
     */
    commonSelect: function(msgID, items){
        DGC.ActionUtil.callAction({
            actionName : "commonSelect",
            msgID: msgID,
            items : items
        });
    },

    /**
     * 打开新的Web窗口
     */
    openWebView: function(url, enableBack){
        DGC.ActionUtil.callAction({
           actionName : "webRedirect",
           url: url,
           status: enableBack
        });
    },

    /**
     * 更新指定Tab上的TIP值
     * @param {Number} key Tab导航key
     * @param {Number} value 显示的数字值,如果为0,则隐藏消息显示
     */
    updateTabTip : function(key, value){
        DGC.ActionUtil.callAction({
            actionName : 'updateTabTip',
            tag : key,
            msgNum : value
        });
    },

    /**
     * 调用Anroid上传头像模块
     * @param {Number} way 上传方式
     */
    updateAvatar : function(way){
        DGC.ActionUtil.callAction({
            actionName : 'updateAvatar',
            type: way
        });
    },

    /**
     * 邀请朋友
     */
    inviteFriends: function(way, msg, title){
        DGC.ActionUtil.callAction({
            actionName : 'inviteFriend',
            title: (title || ""),
            way : way,
            msg: ( msg || "")
        });
    },

    /**
     * 获取本地游戏状态
     * @param {Array} params 包名的数组
     */
    getGameState : function(params){
        DGC.ActionUtil.callAction({
            actionName : 'gameState',
            params : params
        });
    },


    /**
     * 启动某个已安装的游戏
     * @param {String} params 包名
     */
    startGame : function(packageName){
        DGC.ActionUtil.callAction({
            actionName : 'startGame',
            packageName : packageName
        });
    },

    /**
     * 切换SNS账号
     * @param {Number} snsID sns账号ID
     * @param {Number} snsType 第三方SNS类型 1:人人 2:新浪
     */
    switchSNSAccount: function(snsId,snsType){
        DGC.Common.lock('switchlock');
        DGC.ActionUtil.callAction({
            actionName : 'snsLogin',
            snsId : snsId,
            type: snsType
        });
    },

    /**
     * SDK切换乐逗账户
     */
    switchLeDouAccount: function(acountInfo){
        DGC.Common.lock('switchlock');
        DGC.ActionUtil.callAction($.extend(acountInfo, {
            actionName : "ledouAccountLogin",
            callback: "DGC.Application.notifyAccountReLogin"
        }));
    },


    /**
     * 请求Android切换账户
     */
    switchNewAccount : function(){
        DGC.Common.lock('switchlock');
        DGC.ActionUtil.callAction({
            actionName : "useNewAccount"
        });
    },

    /**
     * 获区乐逗商城列表
     */
    queryProductList: function(){
        DGC.ActionUtil.callAction({
            actionName : "retrieveProductList",
            callback:"DGC.Application.productListCallback"
        });
    },

    /**
     * 获得需要购买的道具信息
     */
    getProductInfo : function(identify){
        DGC.ActionUtil.callAction({
            actionName : "getProductInfo",
            identify : identify,
            callback:"DGC.Application.productInfoCallback"
        });
    },


   /**
    * 获取当前积分类型
    */
   getIntegral : function(){
        DGC.ActionUtil.callAction({
            actionName : "getIntegral",
            type: window.sdk.integral_type
        });
   },


   /**
    * 显示积分墙页面
    */
    showIntegralView: function(type, isFrom){
        //进入页面前记录行为
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_MALL_OFFERS);
        DGC.ActionUtil.callAction({
            actionName : "showOffers",
            type: type,
            from_purcharse: isFrom
        });
    },

    /**
     * order下单成功/失败后，购买道具后，响应结果通知Android
     */
    notifySDKBuyResult: function(type, result, item , err_code){
        var actionObj = {
            actionName: "purcharseProductCallback",
            success: result,
            type: type, //type：指 创建订单时候的类型
            item:  item
        };

        //支付失败，通知err_code
        if(!result){
            actionObj['error'] = err_code;
        }

        DGC.ActionUtil.callAction(actionObj);
    },

    /**
     * 本地充值接口
     */
    payAccount : function(payInfo){
        DGC.ActionUtil.callAction($.extend({
            actionName : "pay"
        }, payInfo));
    },

    /**
     * 本地支付(短代,机锋)道具接口
     */
    purchaseProduct : function(type, product){
        DGC.ActionUtil.callAction($.extend({
            actionName : "nativePurcharseProduct",
            type: type
        }, product));
    },

    /**
     * 查询离线成就信息
     */
    offlineAchievement : function(){
        DGC.ActionUtil.callAction({
            actionName : "offlineAchievement",
            callback: "DGC.Application.offlineAchieveCallback"
        });
    },

    /**
     * 查询离线排行模式
     */
    offlineBoardModel : function(){
        DGC.ActionUtil.callAction({
            actionName : "offlineLeaderboardMode",
            callback: "DGC.Application.offlineBoardCallback"
        });
    },

    /**
     * 查询离线高分榜
     */
    offlineHighScore : function(identifier){
        DGC.ActionUtil.callAction({
            actionName : "offlineLeaderboard",
            identify : identifier,
            callback: "DGC.Application.offlineHighScoreCallback"
        });
    },

    /**
     * 离线重新登录
     */
    offlineRelogin : function(){
        DGC.Common.lock('switchlock');
        DGC.ActionUtil.callAction({
            actionName : 'offlineRelogin'
        });
    },

    /**
     * 退出游戏菜单接口
     */
    returnToGame : function(){
        //返回游戏前清空缓存数据
        sessionStorage.clear();

        //SDK重新刷新Player数据
        DGC.ActionUtil.refreshAppInfo();

        DGC.ActionUtil.callAction({
            actionName : 'returnGame'
        });
    },

    /**
     * 遮罩Android的导航栏
     */
    setShade : function(isShade){
        DGC.ActionUtil.callAction({
            actionName : "shade",
            isShade : isShade
        });
    },

    /**
     * 设置配置项 obj {1:10,3:30}
     */
    setConfigParams : function(obj){
        for(var k in obj){
            DGC.ActionUtil.callAction({
                actionName : "put",
                key : k,
                value : obj[k].toString()
            });
        }
    },

    /**
     * 获取配置项 configArray [1,2,3,4,5,6]
     */
    getConfigParams : function(configArray){
        DGC.ActionUtil.callAction({
            actionName : "get",
            key : configArray,
            callback : "DGC.Application.getConfigParamsLoad"
        });
    },

    /**
     * 设置全局参数
     */
    setGConfigParams: function(obj){
        DGC.ActionUtil.callAction({
            actionName : "globalPut",
            storage : $.toJSON(obj)
        });
    },

    /**
     * 下载URL内容
     */
    download: function(url){
        DGC.ActionUtil.callAction({
            actionName : "download",
            url : url
        });
    },

    /**
     * 获取全局配置项
     */
    getGConfigParams : function(){
        DGC.ActionUtil.callAction({
            actionName : "globalGet",
            callback : "DGC.Application.getGConfigParamsLoad"
        });
    },

    /**
     * 记录用户点击行为
     * @param {String} eventId 事件名称
     * @param {Json} params 参数{key:value}
     */
    recordUserAction : function(eventId,params){
        DGC.ActionUtil.callAction({
            actionName : "logEvent",
            eventId : eventId,
            params : params
        });
    },

    /**
     * 记录用户查看页面的次数
     * @param {String} eventId 乐逗空间对应页面的ID
     */
    recordPageCount : function(eventId){
        DGC.ActionUtil.callAction({
            actionName : "onPageView",
            eventId : eventId
        });
    },

    /**
     * 调用系统默认浏览器打开新的url
     */
    openBrowser: function(url){
        DGC.ActionUtil.callAction({
            actionName : "openBrowser",
            url : url
        });
    }

};
