/**
 * Android touch触控事件支持
 */
(function($){
    var delayTapDown,
        /**
         * 起始点坐标
         */
        startX = 0,
        startY = 0,

        startEvent,

        lastX = 0,
        lastY = 0,

        lastTouch,

        isLock = false,

        /**
         * 是否处于滚动状态
         */
        isScroll = false,


        tapDownEvent,

        tapUpEvent;


    /**
     * 判断当期滑动距离是否大于Tap手势距离
     */
    function isCancel(touch) {
        var limit = isScroll ? 5 : 25 ;
        return (
            Math.abs(touch.pageX - startX) > limit ||
            Math.abs(touch.pageY - startY) > limit
        );
    }

    /**
     * 获得target目标
     */
    function parentIfText(node){
        return 'tagName' in node ? node : node.parentNode;
    }

    function reset(){
        isScroll = false;
        lastTouch = null;
        startEvent = null;
        startX = null;
        startY = null;
        lastX = null;
        lastY = null;
    }

    function getNativeEvent( event ) {
        while ( event && typeof event.originalEvent !== "undefined" ) {
            event = event.originalEvent;
        }
        return event;
    }

    /**
     * 开始touch动作监听
     */
    function onTouchStart(event){
        DGC.ActionUtil.log('touchstart time:' + new Date().getTime());

        var touches = getNativeEvent(event).touches,
            target, t;
        //清楚上次未结束的动作
        if(startEvent){
            onTouchEnd(startEvent);
        }

        if ( touches && touches.length === 1 ) {

            target = event.target, t = touches[0];

            isScroll = false;

            startEvent = event;
            lastTouch = target;

            startX = t.pageX;
            startY = t.pageY;

            tapDownEvent = setTimeout(function() {
                $(event.target).trigger('tapdown');
            }, 25);
        }
    }

    /**
     * 滚动事件监听
     */
    function onScroll(event){
        DGC.ActionUtil.log('scroll time:'+ new Date().getTime());
        //清除延时按下事件
        delayTapDown && clearTimeout(delayTapDown);
        delayTapDown = null;

        if ( !isScroll ) {
            if(lastTouch){
                DGC.ActionUtil.log('isScrolling: tapcancel');
                clearTimeout(tapDownEvent);
                $(lastTouch).trigger('tapcancel');
            }
        }
        isScroll = true;
    }

    /**
     * 移动touch动作监听
     */
    function onTouchMove(event){

        DGC.ActionUtil.log('touchmove time:'+ new Date().getTime());

        var touch = getNativeEvent(event).touches[0], isScrolled;

        lastX = touch.pageX;
        lastY = touch.pageY;

        isScrolled = isScroll;

        isScroll = isScroll || isCancel(touch);

        if ( isScroll && !isScrolled ) {
            DGC.ActionUtil.log("touchmove:cancel tap");
            clearTimeout(tapDownEvent);
            $(event.target).trigger("tapcancel");
        }
    }

    /**
     * 结束touch动作监听
     */
    function onTouchEnd(event){
        DGC.ActionUtil.log('touchend time:'+ new Date().getTime());

        if(isLock || isScroll)return false;

        isLock = true;

        tapUpEvent = setTimeout(function(){
            $(event.target).trigger('tapup');
        },25);

        //点未移动，则先调用move方法
        /*
        console.log($.format('StartX:{0},StartY:{1}'),[startX, startY]);
        console.log($.format('lastX:{0},lastY:{1}'),[lastX, lastY]);
        if((startX == lastX) && (startY == lastY) ){
            console.log('start == end: trigger touchmove');
            onTouchMove(event);
        }*/

        //触发虚拟事件
        //if(!isScroll && lastTouch){
        if(!isScroll && lastTouch){
            //$(event.target).trigger('tap');
            //reset();
            setTimeout(function(){
                //console.log('tapup:trigger tap');
                $(event.target).trigger('tap');
                reset();
                isLock = false;
            },150);
        }else{
            setTimeout(function(){
                reset();
                isLock = false;
            },150);
        }

        DGC.ActionUtil.log('touch end->scroll:'+ isScroll);
    }

    //jQuery Event touches extend
    $.event.props.push('touches','changedTouches');

    //extend Fn call
    ['tapdown','tapup', 'tapcancel' , 'tap'].forEach(function(m){
        $.fn[m] = function(callback){ return this.bind(m, callback)};
    });

    $(document).ready(function(){
        $(document).bind({
            'touchstart': onTouchStart,
            'touchmove': onTouchMove,
            'touchend': onTouchEnd,
            'scroll':  onScroll
        });
    });

})(jQuery);