/**
 * 成就模块数据模型
 */
DGC.Model.Achievement = $.inherits(DGC.Model,{

    id : 'model_achievement',

    constructor : function(config){

        //声明自定义事件
        this.defineEvents(
            'playerachieve'
        );

        //API接口声明
        this.apiURL = {
            GET_PLAYER_ACHIEVE: {
                url : "/playerachievements?game_id={0}&player_id={1}",
                pattern:/\/playerachievements\?game_id=\d+&player_id=\d+/
            }
        }

        DGC.Model.Achievement.superclass.constructor.call(this,config);
    },

    /**
     * 初始化监听数据流
     */
    registryMessages : function(){
       var MSG  = DGC.Service.Messages;
       this.service.on(MSG.QUERY_PLAYER_ACHIEVE_LIST, this.queryPlayerGameAchieveCallback, this);
       this.service.on(MSG.QUERY_OFFLINE_ACHIEVE, this.queryOfflineGameAchieveCallback, this);
    },

    /**
     * 查询指定游戏中的成就信息
     * @param {Number} gameId 游戏ID
     * @param {Number} playerId 玩家ID
     */
    queryPlayerGameAchieve : function(gameId, playerId){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            urlKey = $.format(API.GET_PLAYER_ACHIEVE.url, [gameId, playerId] );

        /**
         * 请求游戏成就列表
         */
        var requestBody = {
            msgID : MSG.QUERY_PLAYER_ACHIEVE_LIST,
            params: {
                "GET": [
                    {
                        url: urlKey
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'achievement/game_achieve.json'
            });
        }

        var cacheItem = this.getCache(urlKey);
        if(cacheItem){
            this.fire("playerachieve", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 游戏成就信息回调
     */
    queryPlayerGameAchieveCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_ACHIEVE.pattern.test(url)){
                    this.putCache(url, GET_RESPONSE[url].data);
                    this.fire("playerachieve", GET_RESPONSE[url].data);
                }
            }
        }
    },

    /**
     * 查询离线游戏成就信息
     */
    queryOfflineGameAchieve: function(){
        DGC.ActionUtil.offlineAchievement();
    },

    /**
     * 查询离线游戏成就回调
     */
    queryOfflineGameAchieveCallback: function(msg){
          //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            //在线/离线采用同一数据源渲染
            this.fire("playerachieve", result.data);
        }
    }

});