/**
 * 排行榜数据模型
 */
DGC.Model.HighScores = $.inherits(DGC.Model,{

    id : 'model_highscores',

    constructor : function(config){

        //声明自定义事件
        this.defineEvents(
            'leaderboards', //查询指定游戏的排行列表
            'friendrank',   //查询朋友排行数据成功
            'worldrank',    //查询全球排行数据成功
            'arearank',      //查询区域排行数据成功
            'offlineboards' //离线游戏排行模式
        );

        //Cache
        this.apiURL = {
            GET_LEADER_BOARDS:{
                url : "/leaderboards?game_id={0}",
                pattern : /\/leaderboards\?game_id=\d+/
            },
            GET_PLAYER_RANK:{
                url : "/highscores/show?leaderboard_id={0}&type={1}&player_id={2}",
                pattern : /\/highscores\/show\?leaderboard_id=\d+&type=(friend|area|all)&player_id=\d+/
            },
            GET_FRIENDS_RANK:{
                url : "/highscores/friends_all_ranklist?leaderboard_id={0}&player_id={1}",
                pattern: /\/highscores\/friends_all_ranklist\?leaderboard_id=\d+&player_id=\d+/
            },
            GET_AREA_RANK:{
                url: "/highscores/area_ranklist?leaderboard_id={0}&player_id={1}",
                pattern: /\/highscores\/area_ranklist\?leaderboard_id=\d+&player_id=\d+/
            },
            GET_ALL_RANK:{
                url: "/highscores/all_ranklist?leaderboard_id={0}",
                pattern: /\/highscores\/all_ranklist\?leaderboard_id=\d+/
            }
        }

        DGC.Model.HighScores.superclass.constructor.call(this,config);
    },

    /**
     * 初始化监听数据流
     */
    registryMessages : function(){
       var MSG  = DGC.Service.Messages;
       this.service.on(MSG.QUERY_FRIEND_RANK, this.queryFriendRankCallback, this);
       this.service.on(MSG.QUERY_AREA_RANK, this.queryAreaRankCallback, this);
       this.service.on(MSG.QUERY_WORLD_RANK, this.queryWorldRankCallback, this);
       this.service.on(MSG.QUERY_LEADERBOARD_LIST, this.queryLeaderBoradListCallback ,this);
       this.service.on(MSG.QUERY_OFFLINE_LEADERBOARD_LIST,this.queryOfflineBoardModelCallback, this);
       this.service.on(MSG.QUERY_OFFLINE_HIGHSCORES,this.queryOfflineRankListCallback, this);
    },

    /**
     * 查询好友排行(Player和他的好友)
     * @param {Number} leadboardId 排行榜Id
     * @param {Number} playerId    用户Id
     */
    queryFriendRank : function(leadboardId, playerId){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL;
        var requestBody  = {
            msgID : MSG.QUERY_FRIEND_RANK,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_RANK.url, [leadboardId, "friend", playerId] )
                    },
                    {
                        url: $.format(API.GET_FRIENDS_RANK.url, [leadboardId, playerId])
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'highscores/friends_rank.json'
            });
        }

        DAU.requestAPI(requestBody);

    },

    /**
     * 查询好友排行回调函数
     */
    queryFriendRankCallback: function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_RANK.pattern.test(url)){
                    obj.playerRank = GET_RESPONSE[url].data;
                }else if(API.GET_FRIENDS_RANK.pattern.test(url)){
                    obj.friendRank = GET_RESPONSE[url].data;
                }
            }

            this.fire("friendrank", obj.playerRank, obj.friendRank);
        }

    },

    /**
     * 查询区域排行(Player和他的好友)
     * @param {Number} leadboardId 排行榜Id
     * @param {Number} playerId    用户Id
     */
    queryAreaRank : function(leadboardId, playerId){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL;
        var requestBody  = {
            msgID : MSG.QUERY_AREA_RANK,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_RANK.url, [leadboardId, "area", playerId] )
                    },
                    {
                        url: $.format(API.GET_AREA_RANK.url, [leadboardId, playerId])
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'highscores/area_rank.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("arearank", cacheItem.playerRank, cacheItem.areaRank);
        }else{
            DAU.requestAPI(requestBody);
        }

    },

    /**
     * 查询区域排行回调函数
     */
    queryAreaRankCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_RANK.pattern.test(url)){
                    obj.playerRank = GET_RESPONSE[url].data;
                }else if(API.GET_AREA_RANK.pattern.test(url)){
                    obj.areaRank = GET_RESPONSE[url].data;
                }
            }

            this.putCacheByObj(this.getRequestKey(msg), obj);
            this.fire("arearank", obj.playerRank, obj.areaRank);
        }
    },

    /**
     * 查询全球排行
     * @param {Number} leadboardId 排行榜Id
     * @param {Number} playerId    用户Id
     */
    queryWorldRank : function(leadboardId, playerId){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL;
        var requestBody  = {
            msgID : MSG.QUERY_WORLD_RANK,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_RANK.url, [leadboardId, "all", playerId] )
                    },
                    {
                        url: $.format(API.GET_ALL_RANK.url, [leadboardId])
                    }
                ]
            }
        };

        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'highscores/all_rank.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("worldrank", cacheItem.playerRank, cacheItem.allRank);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询全球排行回调
     */
    queryWorldRankCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_RANK.pattern.test(url)){
                    obj.playerRank = GET_RESPONSE[url].data;
                }else if(API.GET_ALL_RANK.pattern.test(url)){
                    obj.allRank = GET_RESPONSE[url].data;
                }
            }
            this.putCacheByObj(this.getRequestKey(msg), obj);
            this.fire("worldrank", obj.playerRank, obj.allRank);
        }

    },

    /**
     *  查询指定游戏的排行列表信息
     *  @param {Number} gameId 游戏ID
     */
    queryLeaderBoradList: function(gameId){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            boardKey  = $.format(API.GET_LEADER_BOARDS.url, [gameId] );

        var requestBody  = {
            msgID : MSG.QUERY_LEADERBOARD_LIST,
            params: {
                "GET": [
                    {
                        url: boardKey
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'highscores/leaderboard.json'
            });
        }

        //判断请求KEY值是否一致，在缓存中是否存在，如存在则获取本地数据，通知UI更新
        var cacheItem = this.getCache(boardKey);
        if(cacheItem){
            this.fire("leaderboards", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询排行模式列表回调
     */
    queryLeaderBoradListCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg), API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_LEADER_BOARDS.pattern.test(url)){
                    this.putCache(url, GET_RESPONSE[url].data);
                    this.fire("leaderboards", GET_RESPONSE[url].data);
                }
            }
        }
    },

    /**
     * 查询离线排行模式
     */
    queryOfflineBoardModel : function(){
        DGC.ActionUtil.offlineBoardModel();
    },


    /**
     * 离线排行模式回调
     */
    queryOfflineBoardModelCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),
            API = this.apiURL;

        if(result && result.success){
            this.fire("leaderboards", result.data);
        }
    },


    /**
     * 查询离线高分排行
     */
    queryOfflineRankList: function(identifier){
        DGC.ActionUtil.offlineHighScore(identifier);
    },

    /**
     * 高分排行回调
     */
    queryOfflineRankListCallback: function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),
            API = this.apiURL;

        if(result && result.success){
            this.fire("offlinerank", result.data);
        }
    }

});
