/**
 * "我"信息数据模型
 */
DGC.Model.Me = $.inherits(DGC.Model,{

    id : 'model_me',

    constructor : function(config){

        //声明自定义事件
        this.defineEvents(
            'mydetail',
            'playedgame',
            'playerfriends',
            'playerfollows',
            'playerdetail',
            'playerrecord',
            'searchfriends',
            'updatefriendsship',
            'sendsinaachieve',
            'sendrenrenachieve',
            'bindsinasuccess',
            'bindrenrensuccess',
            'unbindsinasuccess',
            'unbindrenrensuccess',
            'sycsina',
            'sycrenren',
            'tipsready',
            'updatemydetail',
            'updateloginplayer',

            //SDK1.2
            'selectavatarway', /*选择更新头像方式*/
            'updateavatar',    /*头像更新成功,通知UI更新*/
            'updatenickname',  /*昵称更新成功，通知UI更新*/
            'updategender',    /*性别更新成功， 通知UI更新*/
            'feedback',		   /*反馈成功*/
            'clearaccountsuccess', /*清除账户信息*/
            'snssharecontent',  /*SNS分享内容*/
            'snssharesuccess'   /*发送SNS分享内容成功*/
        );

        //API接口声明
        this.apiURL = {
            GET_PLAYER_SEARCH:{
                url : "/players/search?q={0}",
                pattern: /\/players\/search\?q=.{1,}/,
            },
            GET_PLAYER_DETAIL:{
                url: "/players/show?player_id={0}",
                pattern : /\/players\/show\?player_id=\d+/
            },
            GET_FRIENDSSHIP:{
                url:"/friendships/show?source_id={0}&target_id={1}",
                pattern : /\/friendships\/show\?source_id=\d+&target_id=\d+/
            },
            POST_FRIENDSSHIP_CREATE:{
                url: "/friendships/create"
            },
            POST_FRIENDSHIPS_DESTROY:{
                url: "/friendships/destroy"
            },
            GET_PLAYED_GAMES:{
                url : "/players/games?player_id={0}",
                options : [
                    "next_cursor"
                ],
                pattern : /\/players\/games\?player_id=\d+(&next_cursor=\d+)?/
            },
            GET_PLAYER_FRIENDS:{
                url: "/players/friends?player_id={0}",
                options: [
                    "next_cursor"
                ],
                pattern : /\/players\/friends\?player_id=\d+(&next_cursor=\d+)?/
            },
            GET_PLAYER_FOLLOWERS:{
                url: "/players/followers?player_id={0}",
                options: [
                    "next_cursor"
                ],
                pattern : /\/players\/followers\?player_id=\d+(&next_cursor=\d+)?/
            },
            GET_PLAYER_RECORDS:{
                url: "/playrecords/show?player_id={0}&game_id={1}",
                pattern : /\/playrecords\/show\?player_id=\d+&game_id=\d+/
            },
            POST_UPDATE_PROFILE:{
                url: "/account/update_profile",
                pattern:/\/account\/update_profile/
            },
            POST_SET_PASS:{
                url: "/account/update_security",
                pattern:/\/account\/update_security/
            },
            POST_FEED_BACK:{
                url: "/feedback/create",
                pattern:/\/feedback\/create/
            },
            POST_ACCOUNT_CREATE:{
                url: "/account/create",
                pattern:/\/account\/create/
            },
            POST_SNS_SYNC:{
                url: "/sns/sync",
                pattern: /\/sns\/sync/
            },
            POST_SNS_ACTION:{
                url: "/sns/login",
                pattern:/\/sns\/login/
            },
            POST_UNBIND:{
                url: '/sns/unbind',
                pattern:/\/sns\/unbind/
            },
            POST_WEIBO:{
                url: '/weibo/invite',
                pattern:/\/weibo\/invite/
            },
            QUERY_INVITE_MSG:{
                url: '/sns/invite_msg?type={0}',
                pattern:/\/sns\/invite_msg\?type=\d+/
            },
            POST_SINA_WEIBO:{
                url: '/sina/send_msg',
                pattern:/\/sina\/send_msg/
            },
            //玩家信息数据
            GET_PLAYER_ACHIEVE: {
                url : "/playerachievements?game_id={0}&player_id={1}",
                pattern:/\/playerachievements\?game_id=\d+&player_id=\d+/
            },
            GET_LEADER_BOARDS:{
                url : "/leaderboards?game_id={0}",
                pattern : /\/leaderboards\?game_id=\d+/
            },
            //活动
            GET_PLAYER_ACTIVITY:{
                url: "/playeractivities?player_id={0}",
                options: [
                    "participance",
                    "next_cursor"
                ],
                pattern : /\/playeractivities\?player_id=\d+(&participance=\d+)?(&next_cursor=\d+)?/
            },
            POST_UPDATE_PLAYER_ACTIVITY:{
                url: "/playeractivities/update",
                pattern : /\/playeractivities\/update/
            },
            //兑换码
            POST_UPDATE_PROMOTIONCODE:{
                url: "/promotioncode/update",
                pattern : /\/promotioncode\/update/
            },
            //获取SNS分享好友模板
            GET_SNS_SHARE_TPL:{
                url: "/sns/message?sns_type={0}",
                pattern: /\/sns\/message\?sns_type=\d+/
            },
            //分享SNS内容
            POST_SNS_SEND:{
                url: "/sns/send",
                pattern: /\/sns\/send/
            }
        }

        DGC.Model.Me.superclass.constructor.call(this,config);
    },

    /**
     * 初始化监听数据流
     */
    registryMessages: function(){
        var MSG  = DGC.Service.Messages;
        this.service.on(MSG.QUERY_ME_PREV_DETAIL, this.queryMyGameDetailCallback , this);
        this.service.on(MSG.QUERY_PLAYER_DETAIL, this.queryPlayerDetailCallBack ,this);
        this.service.on(MSG.QUERY_PLAYER_PLAYED_GAMES, this.queryPlayedGamesCallback, this);
        this.service.on(MSG.QUERY_PLAYER_FRIENDS,this.queryPlayerFriendsCallback, this);
        this.service.on(MSG.QUERY_PLAYER_FANS, this.queryPlayerFollowersCallback, this);
        this.service.on(MSG.QUERY_PLAYER_RECORDS, this.queryPlayerRecordsCallback, this);
        this.service.on(MSG.UPDATE_PLAYER_AVATAR, this.updateAvatarCallback, this);
        this.service.on(MSG.QUERY_REFRESH_PLAYER_DETAIL, this.refreshPlayerDetailCallback,this);
        this.service.on(MSG.UPDATE_PLAYER_NAME, this.updatePlayerNameCallback, this);
        this.service.on(MSG.UPDATE_INVITE_FRIENDS,this.updateInviteFriendsCallback,this);
        this.service.on(MSG.QUERY_FRIENDS, this.queryMatchFriendsCallback,this);
        this.service.on(MSG.UPDATE_CREATE_FRIENDSSHIP, this.updateCreateFriendsShipCallback, this);
        this.service.on(MSG.UPDATE_DESTORY_FRIENDSSHIP, this.updateDestoryFriendsShipCallback, this);
        this.service.on(MSG.UPDATE_SET_PASS, this.updateSetPassCallback,this);
        this.service.on(MSG.UPDATE_MODIFY_PASS, this.updateModifyPassCallback,this);
        this.service.on(MSG.QUERY_FEED_BACK, this.queryFeedBackCallback,this);
        this.service.on(MSG.UPDATE_CREATE_ACCOUNT, this.updateCreateAccountCallback,this);
        this.service.on(MSG.UPDATE_CHECK_SNS_ACCOUNT, this.snsAccountCheckCallback, this);
        this.service.on(MSG.UPDATE_SNS_BIND, this.updateBindSNSCallback,this);
        this.service.on(MSG.UPDATE_UNBIND, this.updateUnbindCallback, this);
        this.service.on(MSG.UPDATE_INVITE_FRIENDS_ALREADY, this.updateInviteFriendsAlreadyCallback, this);
        this.service.on(MSG.UPDATE_SEND_WEIBO, this.achivementSendWeiboCallback, this);
        this.service.on(MSG.QUERY_INVITE_MSG,this.queryInviteFriendsMsgCallback, this);
        this.service.on(MSG.UPDATE_SINA_WEIBO, this.sendSinaweiboCallback, this);
        this.service.on(MSG.UPDATE_SNS_SYNC, this.snsSycPlayerCallback, this);
        this.service.on(MSG.QUERY_TIPS_SUCCESS, this.tipsReadyCallback, this);
        this.service.on(MSG.UPDATE_NEW_PLAYER_INFO, this.modifyNewPlayerInfoCallback, this);
        //SDK1.2新增
        this.service.on(MSG.SHOW_UPDATE_PLAYER_ICON_WAYS, this.showUpdateIconSelectCallback, this);
        this.service.on(MSG.UPDATE_PLAYER_GENDER,this.updatePlayerGenderCallback, this);
        this.service.on(MSG.QUERY_LATEST_ACTIVITY,this.queryLatestActivityCallback, this);
        this.service.on(MSG.QUERY_CIRCUSEE_ACTIVITY,this.queryCircuseeActivityCallback, this);
        this.service.on(MSG.UPDATE_CIRCUSEE_ACTIVITY,this.updateCircuseeActivityCallback, this);
        this.service.on(MSG.UPDATE_PROMOTIONCODE,this.updatePromotionCodeCallback, this);
        this.service.on(MSG.QUERY_LOCAL_GAME_STATE, this.queryLocalGameListStateCallback, this);
        this.service.on(MSG.QUERY_SNS_SHARE_CONTENT, this.querySNSShareContentCallback, this);
        this.service.on(MSG.UPDATE_SNS_MSG_SEND, this.updateShareContentToSNSCallback, this);
    },

    /**
     * 查询玩家的详细信息
     * @param {Number} playerId 玩家ID
     */
    queryPlayerDetail: function(playerId){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            playerDetailKey = $.format(API.GET_PLAYER_DETAIL.url, [playerId] ),
            friendsShipKey = $.format(API.GET_FRIENDSSHIP.url,[window.sdk.player.id, playerId]);


        var requestBody  = {
            msgID : MSG.QUERY_PLAYER_DETAIL,
            params: {
                "GET": [
                    {
                        url: playerDetailKey
                    },
                    {
                        url: friendsShipKey
                    }
                ]
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/player_detail.json'
            });
        }

        //用户详情/用户关注状态
        var cacheDetail = this.getCache(playerDetailKey),
            cacheFriendsShip = this.getCache(friendsShipKey);

        if(cacheDetail && cacheFriendsShip){
            this.fire("playerdetail", cacheDetail, cacheFriendsShip);
        }else{
            DAU.requestAPI(requestBody);
        }

    },

    /**
     * 预查询我的界面上游戏的成就和排行模式信息
     * @param {String} playerId 玩家ID
     * @param {String} gameId 游戏ID
     */
    queryMyGameDetail: function(playerId, gameId){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL,
            boardsKey = $.format(API.GET_LEADER_BOARDS.url, [gameId]),
            achieveKey = $.format(API.GET_PLAYER_ACHIEVE.url, [gameId, playerId] );


        var requestBody  = {
            msgID : MSG.QUERY_ME_PREV_DETAIL,
            params: {
                "GET": [
                    {
                        url: boardsKey
                    },
                    {
                        url: achieveKey
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/game_detail.json'
            });
        }

        //用户详情/用户关注状态
        var boards = this.getCache(boardsKey),
            myAchieves = this.getCache(achieveKey);

        if(boards && myAchieves){
            this.fire("mydetail", boards, myAchieves);
        }else{
            DAU.requestAPI(requestBody);
        }

    },

    /**
     * 预查询我的界面上游戏的成就和排行模式回调
     */
    queryMyGameDetailCallback: function(msg){
         //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_LEADER_BOARDS.pattern.test(url)){
                    obj.boards  = GET_RESPONSE[url].data;
                    this.putCache(url,  obj.boards);
                }else if(API.GET_PLAYER_ACHIEVE.pattern.test(url)){
                    obj.myAchieves = GET_RESPONSE[url].data;
                    this.putCache(url, obj.myAchieves);
                }
            }

            this.fire("mydetail", obj.boards, obj.myAchieves);
        }
    },


    /**
     * 更新玩家的信息
     * @param {String} 自定义通知事件名称
     */
    queryLocalPlayerDetail: function(eventName){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL;

        //请求更新本用户信息
        var requestBody  = {
            msgID : MSG.QUERY_REFRESH_PLAYER_DETAIL,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_DETAIL.url, [ window.sdk.player.id ] )
                    }
                ]
            },
            plugData: {
                eventName: ( eventName || "updatemydetail" /*默认*/ )
            }
        };
        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/new_playerdetail.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 更新当前玩家信息
     */
    refreshPlayerDetailCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),
            API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_DETAIL.pattern.test(url)){
                    //更新当前用户的数据
                    $.extend(window.sdk.player, GET_RESPONSE[url].data);

                    //通知刷新自定义事件
                    this.fire(this.getPlugParams(msg).eventName);
                }
            }
        }
    },


    /**
     * 查询玩家信息回调
     */
    queryPlayerDetailCallBack : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_DETAIL.pattern.test(url)){
                    obj.detail  = GET_RESPONSE[url].data;
                    this.putCacheByObj(url,  obj.detail);
                }else if(API.GET_FRIENDSSHIP.pattern.test(url)){
                    obj.ship = GET_RESPONSE[url].data;
                    this.putCacheByObj(url, obj.ship);
                }
            }
            this.fire("playerdetail", obj.detail, obj.ship);
        }
    },

    /**
     * 查询玩家好友列表
     * @param {Number} playerId 玩家Id
     * @param {Number} nextCursor 分页游标(可选字段)
     */
    queryPlayerFriends: function(playerId, nextCursor){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            optionObj = {};
            //判断是否存在分页参数
            if(nextCursor){
                optionObj.next_cursor = nextCursor;
            }

        var requestBody  = {
            msgID : MSG.QUERY_PLAYER_FRIENDS,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_FRIENDS.url, [playerId] ) + this.getOptionsString(optionObj, API.GET_PLAYER_FRIENDS.options)
                    }
                ]
            },
            plugData: {
                isMore: optionObj.hasOwnProperty('next_cursor')
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/friends.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /*
     * 查询玩家好友列表回调
     */
    queryPlayerFriendsCallback: function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_FRIENDS.pattern.test(url)){
                    this.fire("playerfriends",  GET_RESPONSE[url] , this.getPlugParams(msg).isMore);
                }
            }
        }
    },

    /**
     * 查询好友玩过的游戏信息(Player和他的好友)
     * @param {Number} playerId 玩家Id
     * @param {Number} nextCursor 分页游标(可选字段)
     */
    queryPlayedGames : function(playerId, nextCursor){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            optionObj = {};
            //判断是否存在分页参数
            if(nextCursor){
                optionObj.next_cursor = nextCursor;
            }

        var requestBody  = {
            msgID : MSG.QUERY_PLAYER_PLAYED_GAMES,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYED_GAMES.url, [playerId] ) + this.getOptionsString(optionObj, API.GET_PLAYED_GAMES.options)
                    }
                ]
            },
            plugData:{
                isMore: optionObj.hasOwnProperty('next_cursor')
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/played_games.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("playedgame", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询玩过的游戏回调
     */
    queryPlayedGamesCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYED_GAMES.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg),  GET_RESPONSE[url]);
                    this.fire("playedgame",  GET_RESPONSE[url] , this.getPlugParams(msg).isMore );
                }
            }
        }
    },

    /**
     * 查询玩家的粉丝列表
     * @param {Number} playerId 玩家Id
     * @param {Number} nextCursor 分页游标(可选字段)
     */
    queryPlayerFollowers : function(playerId, nextCursor){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            optionObj = {};
            //判断是否存在分页参数
            if(nextCursor){
                optionObj.next_cursor = nextCursor;
            }

        var requestBody  = {
            msgID : MSG.QUERY_PLAYER_FANS,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_FOLLOWERS.url, [playerId] ) + this.getOptionsString(optionObj, API.GET_PLAYER_FOLLOWERS.options)
                    }
                ]
            },
            plugData:{
                isMore: optionObj.hasOwnProperty('next_cursor')
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/followers.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("playerfollows", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询粉丝列表回调
     */
    queryPlayerFollowersCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_FOLLOWERS.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg),  GET_RESPONSE[url]);
                    this.fire("playerfollows",  GET_RESPONSE[url] , this.getPlugParams(msg).isMore);
                }
            }
        }

    },

    /**
     * 查询玩家在指定游戏的中的信息
     */
    queryPlayerRecords : function(playerId, gameId){
         var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
         var requestBody  = {
            msgID : MSG.QUERY_PLAYER_RECORDS,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_RECORDS.url, [playerId, gameId] )
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/playerrecord.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("playerrecord", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }

    },


    /**
     * 查询玩家在指定游戏的中的信息回调
     */
    queryPlayerRecordsCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_RECORDS.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg),  GET_RESPONSE[url]);
                    this.fire("playerrecord",  GET_RESPONSE[url]);
                }
            }
        }
    },

    /**
     * 上传头像状态结果响应
     */
    updateAvatarCallback: function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages;

        //上传头像成功
        if(result && result.success){
            DAU.showTipMsg(resName.TIP_SETTING_UPDATEAVATAR_SUCCESS);
            DAU.refreshAppInfo(); //通知SDk同步刷新数据

            this.queryLocalPlayerDetail('updateavatar');//通知UI头像更新
        }
    },

    /**
     * 更新昵称信息
     */
    upatePlayerNickName : function(nickname){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
            msgID : MSG.UPDATE_PLAYER_NAME,
            params: {
                "POST": [
                    {
                        url: API.POST_UPDATE_PROFILE.url,
                        data: {
                            "nickname" : nickname
                        }
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_player_ok.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 更新用户昵称信息
     */
    updatePlayerNameCallback : function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_UPDATE_PROFILE.pattern.test(url)){
                    //响应成功
                    //if(!POST_RESPONSE[url].err_detail){
                    var sendObj = this.getDefaultPostObj(msg);
                    //替换本地的用户昵称
                    $.extend(window.sdk.player,  {nickname : sendObj.nickname} );

                    this.updateUserInfo();

                    this.fire('updatenickname');

                }
            }
        }
    },

    /**
     * 个人记录信息更新，本地Player信息更新
     * @param {Number} SDK延迟更新毫秒数  默认为1
     */
    updateUserInfo:function(delay){
        //清除排行榜涉及相关缓存
        this.clearCacheByKey("/highscores/area_ranklist");
        this.clearCacheByKey("/highscores/all_ranklist");
        setTimeout(function(){
            DGC.ActionUtil.refreshAppInfo(); //通知SDk同步刷新数据
        }, delay || 1);
    },


    /**
     * 邀请好友（未绑定，直接绑定+邀请好友）
     */
    updateInviteFriends: function(snsType, account, password , isRelogin){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        //请求更新本用户信息
        var requestBody  = {
            msgID : MSG.UPDATE_INVITE_FRIENDS,
            params: {
                "POST": [
                    {
                        url: API.POST_SNS_ACTION.url,
                        data: {
                            "type": snsType,
                            "flag": 2,
                            "account": account,
                            "password": password,
                            "channel_id": window.sdk.channel_id,
                            "device_identifier": window.sdk.device_identifier
                        }
                    }
                ]
           },
           plugData:{
               relogin : isRelogin
           }
        }

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/check_sns_login.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 邀请好友回调
     */
    updateInviteFriendsCallback: function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result),
                userParams = this.getPlugParams(msg);
            for(var url in POST_RESPONSE){
                if(API.POST_SNS_ACTION.pattern.test(url)){
                    /*邀请方式*/
                    var type = this.getDefaultPostObj(msg).type;
                    //通知绑定并邀请好友成功
                    this.fire("invitefriend", type , POST_RESPONSE[url].data.sns_id ,userParams.relogin);
                }
            }
        }
    },

    /**
     * 邀请好友（已经绑定了，直接邀请好友）
     */
    updateInviteFriendsAlready: function(snsType){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        //请求更新本用户信息
        var requestBody  = {
            msgID : MSG.UPDATE_INVITE_FRIENDS_ALREADY,
            params: {
                "POST": [
                    {
                        url: API.POST_WEIBO.url,
                        data: {
                            "type": snsType
                        }
                    }
                ]
           }
        }

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/invite_player.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 邀请好友回调（已经绑定了，直接邀请好友）
     */
    updateInviteFriendsAlreadyCallback: function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_WEIBO.pattern.test(url)){
                    DAU.showTipMsg(resName.TIP_INVITEFRIENDS_INVITE_SUCCESS);
                }
            }
        }
    },

    /**
     * 根据条件搜索好友信息
     */
    queryMatchFriends : function(key){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
         var requestBody  = {
            msgID : MSG.QUERY_FRIENDS,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_SEARCH.url, [key] )
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/search_players.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 搜索好友回调
     */
    queryMatchFriendsCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_SEARCH.pattern.test(url)){
                    this.fire("searchfriends",  GET_RESPONSE[url].data);
                }
            }
        }
    },

    /**
     * 关注建立好友关系
     * @param {Number} playerId 与某玩家建立好友关系
     */
    updateCreateFriendsShip: function(playerId){
         var API = this.apiURL,
             DAU = DGC.ActionUtil,
             MSG = DGC.Service.Messages;

            //请求更新本用户信息
            var requestBody  = {
                msgID : MSG.UPDATE_CREATE_FRIENDSSHIP,
                params: {
                    "POST": [
                        {
                            url: API.POST_FRIENDSSHIP_CREATE.url,
                            data: {
                                "player_id": playerId
                            }
                        }
                    ]
                }
            };

            //Web Debug
            if(DEBUG.isWebModel()){
                $.extend(requestBody, {
                    version: '1.2.0',
                    mockUrl: 'person/create_friendship.json'
                });
            }

            DAU.requestAPI(requestBody);
    },

    /**
     * 建立好友关系回调
     */
    updateCreateFriendsShipCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            //覆盖原来的缓存
            var targetId = this.getDefaultPostObj(msg).player_id,
                cacheKey = $.format(API.GET_FRIENDSSHIP.url, [window.sdk.player.id, targetId]);
            this.putCache(cacheKey, { is_friend: true });
            this.fire("updatefriendsship", true , targetId);

            //DGC.ActionUtil.refreshAppInfo(); //通知SDk同步刷新数据
            //this.queryLocalPlayerDetail();
        }
    },

    /**
     * 取消关注好友关系
     * @param {Number} playerId 与某玩家取消好友关系
     */
    updateDestoryFriendsShip : function(playerId){
         var API = this.apiURL,
             DAU = DGC.ActionUtil,
             MSG = DGC.Service.Messages;

         //请求更新本用户信息
         var requestBody  = {
             msgID : MSG.UPDATE_DESTORY_FRIENDSSHIP,
             params: {
                "POST": [
                    {
                        url: API.POST_FRIENDSHIPS_DESTROY.url,
                        data: {
                            "player_id": playerId
                        }
                    }
                ]
            }
        }
        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/destory_friendship.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 取消关注回调
     */
    updateDestoryFriendsShipCallback : function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL;

        if(result && result.success){
             //覆盖原来的缓存
            var targetId = this.getDefaultPostObj(msg).player_id,
                cacheKey = $.format(API.GET_FRIENDSSHIP.url, [window.sdk.player.id, targetId]);
            this.putCache(cacheKey, { is_friend: false });
            this.fire("updatefriendsship", false , targetId);

            //DGC.ActionUtil.refreshAppInfo(); //通知SDk同步刷新数据
            //this.queryLocalPlayerDetail();
        }
    },

    /**
     * 切换SNS账号
     * @param {Number} snsType 第三方类型
     * @param {String} userName 用户名
     * @param {String} password 密码
     */
    snsAccountCheck: function(snsType,userName,password){
         var API = this.apiURL,
             DAU = DGC.ActionUtil,
             MSG = DGC.Service.Messages;
        //请求更新本用户信息
        var requestBody  = {
             msgID : MSG.UPDATE_CHECK_SNS_ACCOUNT,
             params: {
                "POST": [
                    {
                        url: API.POST_SNS_ACTION.url,
                        data: {
                            "type": snsType,
                            "flag":3, //check can login
                            "account": userName,
                            "password": password,
                            "channel_id": window.sdk.channel_id,
                            "device_identifier": window.sdk.device_identifier
                        }
                    }
                ]
            }
        }
        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/check_sns_login.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 切换SNS账号回调
     */
    snsAccountCheckCallback: function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_SNS_ACTION.pattern.test(url)){
                    var sendObj = this.getDefaultPostObj(msg),
                        snsId = POST_RESPONSE[url].data.sns_id; /*验证成功后的SNS ID*/
                        if(snsId){
                            switch(sendObj.type){
                                case 1/*新浪*/:
                                    DAU.switchSNSAccount(snsId, 2);
                                    break;
                                case 2 /*人人*/:
                                    DAU.switchSNSAccount(snsId, 1);
                                    break;
                            }
                        }
                }
            }
        }
    },

    /**
     * 切换使用乐逗账户
     */
    switchLeDouAccount: function(userName, password){
        //乐逗账号登录??????确认框
        // DGC.Common.confirm(
            // resName.TITLE_SWITCH_USER_SNS_LEDOU,
            // resName.TEXT_SWITCH_USER_LEDOU,
            // function(result){
                // if(result){
                    DGC.ActionUtil.switchLeDouAccount({
                        userName: userName,
                        password: password
                    });
                // }
        // });

    },

    /**
     * 绑定手机并设置密码
     */
    updateSetPass : function(mobileNumber,password){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
                msgID : MSG.UPDATE_SET_PASS,
                params: {
                    "POST": [
                             {
                                 url: API.POST_SET_PASS.url,
                                 data: {
                                     "type" : 1,
                                     "phone" : mobileNumber,
                                     "new_password" : password
                                 }
                             }
                         ]
                    }
            };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_set_pass_ok.json'
            });
        }

        DAU.requestAPI(requestBody);

    },

    /**
     * 绑定手机并设置密码 回调
     */
    updateSetPassCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_SET_PASS.pattern.test(url)){
                    var sendObj = this.getDefaultPostObj(msg);
                    DGC.ActionUtil.refreshAppInfo(); //通知SDK更新
                    $.extend(window.sdk.security, { phone:sendObj.phone });

                    DGC.ActionUtil.showTipMsg(resName.TIP_SAVE_SUCCESS,function(){
                        //回退上一个页面
                        DGC.Application.goBack();
                    });

                }
            }
        }
    },

    /**
     * 修改密码
     */
    updateModifyPass : function(params){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
                msgID : MSG.UPDATE_MODIFY_PASS,
                params: {
                    "POST": [
                         {
                             url: API.POST_SET_PASS.url,
                             data: $.extend( {
                                 "type" : 2
                             }, params)
                         }
                     ]
                }
            };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_modify_pass_ok.json'
            });
        }

        DAU.requestAPI(requestBody);

    },

    /**
     * 修改密码回调
     */
    updateModifyPassCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_SET_PASS.pattern.test(url)){
                    /*修改手机号*/
                    var phone = this.getDefaultPostObj(msg).phone;
                    if(!$.isEmpty(phone)){
                        $.extend(window.sdk.security, { phone : phone } );
                    }
                    //var
                    DGC.ActionUtil.showTipMsg(resName.TIP_SAVE_SUCCESS,function(){
                        //回退上一个页面
                        DGC.Application.goBack();
                    });

                }
            }
        }
    },

    /**
     * 体验反馈
     */
    queryFeedBack : function (feedarea){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
                msgID : MSG.QUERY_FEED_BACK,
                params: {
                    "POST": [
                             {
                                 url: API.POST_FEED_BACK.url,
                                 data: {
                                     "type" : "0" /*无类型*/,
                                     "email" : "" /*无Email*/,
                                     "desc" : feedarea,
                                     "player_id" : window.sdk.player.id,
                                     "game_id" : window.sdk.game.id,
                                     "sdk_version" : window.sdk.version
                                 }
                             }
                         ]
                    }
            };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/query_feed_back_ok.json'
            });
        }

        DAU.requestAPI(requestBody);

    },

    /**
     * 体验反馈回调
     */
    queryFeedBackCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_FEED_BACK.pattern.test(url)){
                    this.fire('feedback');
                }
            }
        }
    },

    /**
     * 切换新账号
     */
    updateCreateAccount : function(){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
            msgID : MSG.UPDATE_CREATE_ACCOUNT,
            params: {
                "POST": [
                     {
                         url: API.POST_ACCOUNT_CREATE.url,
                         data: {
                             "channel_id" : window.sdk.channel_id,
                             "device_identifier" : window.sdk.device_identifier
                         }
                     }
                 ]
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/switch_new_acount.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 切换新账号回调
     */
    updateCreateAccountCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_ACCOUNT_CREATE.pattern.test(url)){
                    this.fire("clearaccountsuccess");
                }
            }
        }

    },


    /**
     * 绑定指定第三方登录(人人,新浪)
     */
    updateBindSNS : function(snsType, username, password , isRelogin){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
            msgID : MSG.UPDATE_SNS_BIND,
            params: {
                "POST": [
                     {
                         url: API.POST_SNS_ACTION.url,
                         data: {
                             "type" : snsType,
                             "flag" : 1,
                             "account" : username,
                             "password" : password,
                             "channel_id": window.sdk.channel_id,
                             "device_identifier": window.sdk.device_identifier
                         }
                     }
                 ]
            },
            plugData:{
                relogin : isRelogin
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/check_sns_login.json'
            });
        }

        DAU.requestAPI(requestBody);
    },


    /**
     * 第三方绑定回调
     */
    updateBindSNSCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result),
                userParams = this.getPlugParams(msg);
            for(var url in POST_RESPONSE){
                if(API.POST_SNS_ACTION.pattern.test(url)){
                    var sendObj = this.getDefaultPostObj(msg),
                        data = POST_RESPONSE[url]['data'];
                    switch(sendObj.type){
                        case 1/*新浪*/:
                            $.extend(window.sdk, { sina: { id : data.sns_id, name: data.sns_name }});
                            this.fire("bindsinasuccess", data , userParams.relogin);
                            break;
                        case 2/*人人*/:
                            $.extend(window.sdk, { renren: { id : data.sns_id, name: data.sns_name }});
                            this.fire("bindrenrensuccess", data , userParams.relogin);
                            break;
                    }

                    DGC.ActionUtil.refreshAppInfo();
                }
            }
        }
    },

    /**
    * 取消绑定 1 => 新浪微博，2 => 人人，4 => 腾讯
    */
    updateUnbind : function(type){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
            msgID : MSG.UPDATE_UNBIND,
            params: {
                "POST": [
                     {
                         url: API.POST_UNBIND.url,
                         data: {
                             "type" : type
                         }
                     }
                 ]
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/unbind.json'
            });
        }

        DAU.requestAPI(requestBody);
    },


    /**
    * 取消绑定回调
    */
    updateUnbindCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_UNBIND.pattern.test(url)){
                    var sendObj = this.getDefaultPostObj(msg);
                    switch(sendObj.type){
                        case 1/*新浪*/:
                            delete window.sdk.sina;
                            this.fire("unbindsinasuccess");
                            break;
                        case 2/*人人*/:
                            delete window.sdk.renren;
                            this.fire('unbindrenrensuccess');
                            break;
                    }

                    DGC.ActionUtil.showTipMsg(resName.TIP_BIND_CANCEL_SUCCESS);
                }
            }
        }
    },

    /**
    * 获得成就发微博
    * @param {Number} type 1 => 新浪微博，2 => 人人，4 => 腾讯
    * @param {Boolean} status 要切换的状态
    */
    achivementSendWeibo : function(type, status){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;

        var postObj = { "type" : 3 };
        switch(type){
            case 1 /*新浪*/:
                $.extend(postObj, { "SINA_WEIBO": status });
                break;
            case 2 /*人人*/:
                $.extend(postObj, { "RENREN_WEIBO": status });
                break;
        }

        var requestBody  = {
                msgID : MSG.UPDATE_SEND_WEIBO,
                params: {
                    "POST": [
                         {
                             url: API.POST_SET_PASS.url,
                             data: postObj
                         }
                     ]
                },
                plugData: {
                    type: type,
                    status: status
                }
            };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_set_pass_ok.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
    * 获得成就发微博回调
    */
    achivementSendWeiboCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result),
                userParams = this.getPlugParams(msg);
            for(var url in POST_RESPONSE){
                if(API.POST_SET_PASS.pattern.test(url)){
                    //根据绑定类型更新数据
                    switch(userParams.type){
                        case 1/*新浪*/:
                            $.extend(window.sdk.security, {allow_achivement_send_weibo_sina: userParams.status});
                            this.fire("sendsinaachieve");
                            break;
                        case 2/*人人*/:
                            $.extend(window.sdk.security, { allow_achivement_send_weibo_renren: userParams.status});
                            this.fire("sendrenrenachieve");
                            break;
                    }

                    //通知Android刷新数据
                    DGC.ActionUtil.refreshAppInfo();
                }
            }
        }
    },

    /**
     * 查询邀请好友模板消息
     * @param {Number} type 1:短信 2:邮件
     */
    queryInviteFriendsMsg: function(type){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
            msgID : MSG.QUERY_INVITE_MSG,
            params: {
                "GET": [
                    {
                        url: $.format($.format(API.QUERY_INVITE_MSG.url, [type]))
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/invite_msg.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 邀请好友信息回调
     */
    queryInviteFriendsMsgCallback: function(msg){
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.QUERY_INVITE_MSG.pattern.test(url)){
                    var msg = GET_RESPONSE[url].data;
                    switch(msg.type){
                        case 1/*短信*/:
                            DGC.ActionUtil.inviteFriends(3, msg.invite_msg);
                            break;
                        case 2/*邮箱*/:
                            DGC.ActionUtil.inviteFriends(4,  msg.invite_msg, resName.TEXT_INVITEFRIENDS_MAIL_TITLE);
                            break;
                    }
                }
            }
        }
    },

    /**
     * 发送新浪微博
     * @param {String} msg 要发送的微博内容
     * @param {Boolean} returnAfter 发送完成后，是否返回游戏
     */
    sendSinaweibo: function( msg , returnAfter){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_SINA_WEIBO,
            params: {
                "POST": [
                    {
                        url: $.format(API.POST_SINA_WEIBO.url),
                        data: {
                            content : msg
                        }
                    }
                ]
            },
            plugData:{
                isReturn: returnAfter
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/sendweibo.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 发送新浪微博回调
     */
    sendSinaweiboCallback: function(msg){
        var result = this.processResponse(msg), API = this.apiURL;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
                userParams = this.getPlugParams(msg);
            for(var url in POST_RESPONSE){
                if(API.POST_SINA_WEIBO.pattern.test(url)){
                    DGC.ActionUtil.showTipMsg(resName.TIP_DEVELOPERWEIBO_SEND_SUCCESS,
                         //判断请求完成需要返回游戏
                        ( userParams.isReturn
                            ? function(){ DGC.ActionUtil.returnToGame(); }
                            : $.emptyFn )
                    );
                    break;
                }
            }
        }
    },

    /**
     * 同步Player
     * @param {Number} snsType 同步SNS类型
     * @param {Boolean} field 同步类型(昵称，头像，全部)
     */
    snsSycPlayer: function(snsType, field){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_SNS_SYNC,
            params: {
                "POST": [
                    {
                        url: $.format(API.POST_SNS_SYNC.url),
                        data: {
                            type : snsType,
                            field: field
                        }
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/sns_sync.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * SNS同步请求回调
     */
    snsSycPlayerCallback : function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            sendObj = this.getDefaultPostObj(msg),
            ATTR = DH.ATTR;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_SNS_SYNC.pattern.test(url)){
                    var msg = POST_RESPONSE[url].data;
                    //导入头像
                    $.extend(window.sdk.player,{ avatar_url : msg.avatar});

                    if(sendObj.field == ATTR.SYNC_TYPE.AVATAR){
                        this.fire('updateavatar');
                    }else{
                        switch(sendObj.type){
                            case ATTR.SYNC_SNS.SINA /*新浪微博*/:
                                $.extend(window.sdk.sina, msg);
                                this.fire('sycsina', true);
                                break;
                            case ATTR.SYNC_SNS.RENREN /*人人*/:
                                $.extend(window.sdk.renren, msg);
                                this.fire('sycrenren', true);
                                break;
                        }
                        //重新查询Player对象，刷新头像和昵称
                        this.queryLocalPlayerDetail();
                   }
                   //通知Android刷新数据
                   DGC.ActionUtil.refreshAppInfo();
                }
            }
        }else{
            //同步SNS信息
            if(!sendObj.avatarOnly){
                switch(sendObj.type){
                    case ATTR.SYNC_SNS.SINA /*新浪微博*/:
                        this.fire('sycsina', false);
                        break;
                    case ATTR.SYNC_SNS.RENREN /*人人*/:
                        this.fire('sycrenren', false);
                        break;
                }
            }
        }
    },

    /**
     * 查询TIPS成功
     */
    tipsReadyCallback : function(){
        var me = this;
        me.fire("tipsready");
    },


    /**
     * 修改新用户基本信息
     * @param {String} userName 用户昵称
     * @param {Number} gender 性别
     */
    modifyNewPlayerInfo: function(option){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_NEW_PLAYER_INFO,
            params: {
                "POST": [
                    {
                        url: API.POST_UPDATE_PROFILE.url,
                        data: option
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_player_ok.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 修改新用户基本信息回调
     */
    modifyNewPlayerInfoCallback : function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_UPDATE_PROFILE.pattern.test(url)){
                    var sendObj = this.getDefaultPostObj(msg);
                    //替换本地的用户昵称和性别
                    $.extend(window.sdk.player,  {nickname : sendObj.nickname, gender: sendObj.gender } );
                    this.fire("updateloginplayer")
                }
            }
        }
    },

    /**
     * 用户选择头像上传回调
     */
    showUpdateIconSelectCallback: function(msg){
        this.fire("selectavatarway", msg.data);
    },


    /**
     * 修改玩家性别
     * @param {Number} gender 性别
     */
    updatePlayerGender: function(gender){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_PLAYER_GENDER,
            params: {
                "POST": [
                    {
                        url: API.POST_UPDATE_PROFILE.url,
                        data: {
                            "gender" : gender
                        }
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_player_ok.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 修改玩家性别回调
     */
    updatePlayerGenderCallback: function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_UPDATE_PROFILE.pattern.test(url)){
                    var sendObj = this.getDefaultPostObj(msg);
                    //替换本地的用户昵称
                    $.extend(window.sdk.player,  {gender : sendObj.gender} );
                    this.fire("updategender");
                }
            }
        }
    },

    /**
     * 查询最新的活动
     * @param {Number} playerId 玩家Id
     * @param {Number} nextCursor 分页游标(可选字段)
     */
    queryLatestActivity : function(playerId, nextCursor){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            optionObj = {};
            //判断是否存在分页参数
            if(nextCursor){
                optionObj.next_cursor = nextCursor;
            }

        var requestBody  = {
            msgID : MSG.QUERY_LATEST_ACTIVITY,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_ACTIVITY.url, [playerId] ) + this.getOptionsString(optionObj, API.GET_PLAYER_ACTIVITY.options)
                    }
                ]
            },
            plugData:{
                isMore: optionObj.hasOwnProperty('next_cursor')
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/activity.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("latestactivity", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询最新活动列表回调
     */
    queryLatestActivityCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_ACTIVITY.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg),  GET_RESPONSE[url]);
                    this.fire("latestactivity",  GET_RESPONSE[url] , this.getPlugParams(msg).isMore);
                }
            }
        }

    },
    /**
     * 查询已围观的活动
     * @param {Number} playerId 玩家Id
     * @param {Number} nextCursor 分页游标(可选字段)
     */
    queryCircuseeActivity : function(playerId, nextCursor){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL,
            optionObj = {
                participance:1
            };
            //判断是否存在分页参数
            if(nextCursor){
                optionObj.next_cursor = nextCursor;
            }

        var requestBody  = {
            msgID : MSG.QUERY_CIRCUSEE_ACTIVITY,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PLAYER_ACTIVITY.url, [playerId] ) + this.getOptionsString(optionObj, API.GET_PLAYER_ACTIVITY.options)
                    }
                ]
            },
            plugData:{
                isMore: optionObj.hasOwnProperty('next_cursor')
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/activity.json'
            });
        }

        //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("circuseeactivity", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询已围观活动列表回调
     */
    queryCircuseeActivityCallback : function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_ACTIVITY.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg),  GET_RESPONSE[url]);
                    this.fire("circuseeactivity",  GET_RESPONSE[url] , this.getPlugParams(msg).isMore);
                }
            }
        }

    },

    //围观活动
    updateCircuseeActivity : function(activityId){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_CIRCUSEE_ACTIVITY,
            params: {
                "POST": [
                    {
                        url: API.POST_UPDATE_PLAYER_ACTIVITY.url,
                        data: {
                            "activity_id" : activityId
                        }
                    }
                ]
            }
        };
        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_activity.json'
            });
        }

        DAU.requestAPI(requestBody);

    },

    //围观活动回调
    updateCircuseeActivityCallback: function(msg){
        var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_UPDATE_PLAYER_ACTIVITY.pattern.test(url)){
                    //响应成功
                    var activity = POST_RESPONSE[url].data;
                    if(activity.participance){//围观成功
                        this.clearCacheByKey("/playeractivities");
                        this.fire("updatecircuseeactivity",  POST_RESPONSE[url]);
                    }
                }
            }
        }
    },

    //兑换码
    updatePromotionCode:function(code){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;
        var requestBody  = {
            msgID : MSG.UPDATE_PROMOTIONCODE,
            params: {
                "POST": [
                    {
                        url: API.POST_UPDATE_PROMOTIONCODE.url,
                        data: {
                            "code" : code
                        }
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_promotioncode.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    //兑换码回调
    updatePromotionCodeCallback : function(msg){
        var result = this.processResponse(msg,true),
            API = this.apiURL,
            DAU = DGC.ActionUtil;
        DGC.ActionUtil.log("updatePromotionCodeCallback:" + JSON.stringify(result));
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.POST_UPDATE_PROMOTIONCODE.pattern.test(url)){
                    //响应成功
                    DGC.ActionUtil.log("updatePromotionCodeCallback:" + JSON.stringify(POST_RESPONSE[url]));
                    this.fire("handlePromoteCode",  POST_RESPONSE[url]);
                }
            }
        }else{
            this.fire("handlePromoteCode",  result);
        }
    },

    queryLocalGameListStateCallback : function(msg){
        this.fire("localgamestate", msg);
    },

    /**
     * 查询SNS分享模板
     * @param {Number} type sns类型
     */
    querySNSShareContent : function(type){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.QUERY_SNS_SHARE_CONTENT,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_SNS_SHARE_TPL.url, [type])
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/sns_msg.json'
            });
        }

        DAU.requestAPI(requestBody);

    },

    /**
     * 查询SNS分享模板回调
     */
    querySNSShareContentCallback: function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),
            API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_SNS_SHARE_TPL.pattern.test(url)){
                    this.fire("snssharecontent",  GET_RESPONSE[url].data );
                }
            }
        }
    },

    /**
     * 分享内容至SNS中
     * @param {Number} type sns类型
     * @param {Number} content 分享内容
     */
    updateShareContentToSNS : function(type, content){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_SNS_MSG_SEND,
            params: {
                "POST": [
                    {
                        url: API.POST_SNS_SEND.url,
                        data: {
                            "type": type,
                            "content": content
                        }
                    }
                ]
            },
            plugData:{
                type: type
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/update_.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 分享内容至SNS中回调
     */
    updateShareContentToSNSCallback: function(msg){
         var result = this.processResponse(msg),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result),
                sendObj = this.getDefaultPostObj(msg);
            for(var url in POST_RESPONSE){
                if(API.POST_SNS_SEND.pattern.test(url)){
                    this.fire("snssharesuccess", sendObj.type , POST_RESPONSE[url].data );
                }
            }
        }
    }

});