/**
 * 支付数据模型模
 */
DGC.Model.Payment = $.inherits(DGC.Model,{

    id : 'model_payment',

    constructor : function(config){

        //声明自定义事件
        this.defineEvents(
            'playercoins', //支持两种参数分发：乐币和历史记录,乐币和是否支持乐币
            'chargehistory',
            'chargelist',
            'chargeresult',
            'chargegfan',
            'shopitems',
            'payresult',
            'ledoupay',
            'feedpay',
            'localpay',
            'ledoucountselect',

            //SDK 1.2
            'paymentdetail',
            'integralpay'
        );

        //API接口声明
        this.apiURL = {
            GET_COINS_ENABLE:{
                url: "/account/check_coin_payment?channel_id={0}",
                pattern: /\/account\/check_coin_payment\?channel_id=.{0,}/
            },
            GET_PLAYER_COINS:{
                url: '/playercoins/show',
                pattern:/\/playercoins\/show/
            },
            GET_PAYMENT_HISTORY:{
                url: '/payment/history?limit={0}',
                options : [
                    "next_cursor"
                ],
                pattern: /\/payment\/history\?limit=\d+(&next_cursor=\d+)?/
            },
            GET_PAYMENTPROFILE:{
                url : "/paymentprofile?game_id={0}&channel_id={1}&type={2}",
                pattern: /\/paymentprofile\?game_id=\d+&channel_id=.*&type=\d+/
            },
            GET_SHOP_ITEMS:{
                url : "/items",
                pattern: /\/items/
            },
            UPDATE_PAY_ORDER:{
                url: "/payments/create",
                pattern: /\/payments\/create/
            },
            GET_PAYMENTPROFILE_DETAIL:{
                url: "/paymentprofile/show?paymethod={0}",
                pattern: /\/paymentprofile\/show\?paymethod=\d+/
            }
        }

        DGC.Model.Payment.superclass.constructor.call(this,config);
    },

    /**
     * 初始化监听数据流
     */
    registryMessages : function(){
       var MSG  = DGC.Service.Messages;
       this.service.on(MSG.QUERY_PLAYER_COINS, this.queryPlayerCoinsCallback,this);
       //this.service.on(MSG.QUERY_PLAYER_COINS_SHOP,this.queryPlayerCoinsAndSupportCallback,this);
       this.service.on(MSG.QUERY_CHARGE_HISTORY, this.queryChargeHistoryCallback, this);
       this.service.on(MSG.QUERY_CHARGE_LIST, this.queryChargeListCallback, this);
       this.service.on(MSG.UPDATE_PAYMENT_CHARGE, this.chargeMoneyCallback,this);
       this.service.on(MSG.UPDATE_CHARGE_GFAN, this.chargeMoneyByGFanCallback , this);
       this.service.on(MSG.QUERY_PAY_PRODUCTINFO, this.queryBuyItemDetailCallback  ,this);
       this.service.on(MSG.QUERY_SHOP_ITEMS, this.queryShopItemsCallback, this);
       this.service.on(MSG.UPDATE_PAY_BY_LEDOU, this.payOrderByLeDouCallback, this);
       this.service.on(MSG.UPDATE_PAY_BY_FEED, this.payOrderByFeedCallback, this);
       this.service.on(MSG.UPDATE_PAY_BY_LOCAL, this.payOrderByLocalCallback, this);
       this.service.on(MSG.SHOW_BUY_ITEM_NUMS,this.ledouShopItemsSelectCallback, this);

       this.service.on(MSG.QUERY_INTEGRAL_INFO, this.integralInfoCallback, this);
       this.service.on(MSG.QUERY_PAYMENT_DETAIL, this.queryPaymentDetailCallback,this);
       this.service.on(MSG.UPDATE_PAY_BY_INTEGRAL, this.payOrderByIntegralCallback,this);
    },

    /**
     * 查询玩家余额信息(列表)
     * @param {Boolean} needRecord 是否查询最近交易记录
     * @param {Boolean} displayMask 禁止显示loading
     */
    queryPlayerCoins: function(needRecord,disableMask){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.QUERY_PLAYER_COINS,
            params: {
                "GET": [
                     {
                         url: API.GET_PLAYER_COINS.url,
                     }
                 ]
            }
        };

        //最近交易记录
        if(needRecord){
            //只需获取一条充值记录
            requestBody.params.GET.push({
                 url: $.format(API.GET_PAYMENT_HISTORY.url, [1] )
            });
        }

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/playercoins.json'
            });
        }

        DAU.requestAPI(requestBody, disableMask);
    },

   /**
    * 玩家余额信息回调
    */
    queryPlayerCoinsCallback : function(msg){
         //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_COINS.pattern.test(url)){
                    obj.playercoins  = GET_RESPONSE[url].data.coins;
                }else if(API.GET_PAYMENT_HISTORY.pattern.test(url)){
                    obj.recenthistory  = GET_RESPONSE[url].data;
                }
            }

            this.fire('playercoins', obj.playercoins, obj.recenthistory);
        }
    },

    /**
     * 查询玩家的余额和是否支持乐币(商城和购买道具)
     */
    queryPlayerCoinsAndSupport: function(disableMask){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;


        var requestBody  = {
            msgID : MSG.QUERY_PLAYER_COINS_SHOP,
            params: {
                "GET": [
                     /*乐币余额*/
                     {
                         url: API.GET_PLAYER_COINS.url,
                     }
                 ]
            }
        };

        /*是否查询允许乐币支付*/
        if(!window.sdk.hasOwnProperty("enable_coin_payment")){
            requestBody.params.GET.push({
                url: $.format($.format(API.GET_COINS_ENABLE.url,[window.sdk.channel_id]))
            });
        }

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'payment/nativepay.json'
            });
        }

        DAU.requestAPI(requestBody, disableMask);
    },

    /**
     * 商城玩家余额和是否支持乐币回调
     */
    queryPlayerCoinsAndSupportCallback: function(msg){
         //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            var obj = {};
            for(var url in GET_RESPONSE){
                if(API.GET_PLAYER_COINS.pattern.test(url)){
                    obj.playercoins  = GET_RESPONSE[url].data.coins;
                }else if(API.GET_COINS_ENABLE.pattern.test(url)){
                    //第一次查询后，不再向FEED查询
                    $.extend(window.sdk, { enable_coin_payment : GET_RESPONSE[url].data["enable_coin_payment"] })
                }
            }

            this.fire('playercoins', obj.playercoins, window.sdk.enable_coin_payment);
        }
    },

    /**
     * 查询充值记录
     * @param {Number} pageNum  每次加载显示条数
     * @param {Number} nextCursor 游标
     */
    queryChargeHistory: function(pageNum, nextCursor){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL,
            optionObj = {};
            //判断是否存在分页参数
            if(nextCursor){
                optionObj.next_cursor = nextCursor;
            }

        var requestBody  = {
            msgID : MSG.QUERY_CHARGE_HISTORY,
            params: {
                "GET": [
                     {
                         url: $.format(API.GET_PAYMENT_HISTORY.url, [pageNum] ) + this.getOptionsString(optionObj, API.GET_PAYMENT_HISTORY.options)
                     }
                 ]
            },
            plugData: {
                isMore: optionObj.hasOwnProperty('next_cursor')
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/chargehistory.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 查询充值记录回调
     */
    queryChargeHistoryCallback: function(msg){
        //统一处理msg,转换数据
        var result = this.processResponse(msg),API = this.apiURL;
        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PAYMENT_HISTORY.pattern.test(url)){
                    this.fire("chargehistory",  GET_RESPONSE[url], this.getPlugParams(msg).isMore);
                }
            }
        }
    },

    /**
     * 查询充值/支付列表
     * @param {Number} type 0:充值 1:支付
     */
    queryChargeList : function(type){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL, SDK = window.sdk;
        var requestBody  = {
            msgID : MSG.QUERY_CHARGE_LIST,
            params: {
                "GET": [
                    {
                        //没有参数
                        url: $.format(API.GET_PAYMENTPROFILE.url,[SDK.game.id, SDK.channel_id, type])
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'payment/payment.json'
            });
        }

        //如果有Cache，直接触发
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("chargelist",cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 支付列表回调
     */
    queryChargeListCallback : function(msg){
        var result = this.processResponse(msg), API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PAYMENTPROFILE.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg), GET_RESPONSE[url].data);
                    this.fire("chargelist", GET_RESPONSE[url].data);
                }
            }
        }
    },

    /**
     * 充值乐币
     * @param {chargeObj} 充值对象
     * paymethod：支付方式
     * quantity:  虚拟币的数量
     * card_no:易宝支付时卡号（易宝支付时必要）
     * card_pwd:易宝支付时密码（易宝支付时必要）
     */
    chargeMoneyByFeed: function(chargeDetail){
        //UPDATE_PAY_ORDER
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL, SDK = window.sdk;
        var requestBody  = {
            msgID : MSG.UPDATE_PAYMENT_CHARGE,
            params: {
                "POST": [
                    {
                        //没有参数
                        url: $.format(API.UPDATE_PAY_ORDER.url),
                        data: $.extend({
                            type: 1, /*充值*/
                            channel_id : window.sdk.channel_id
                        }, chargeDetail)
                    }
                ]
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/chargehistory.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 充值结果回调
     */
    chargeMoneyCallback : function(msg){
        var result = this.processResponse(msg, true),
            API = this.apiURL,
            DAU = DGC.ActionUtil;
            postParams = this.getDefaultPostObj(msg),
            paymethod = postParams.paymethod;
        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.UPDATE_PAY_ORDER.pattern.test(url)){
                    this.fire("chargeresult", paymethod, true, $.extend(POST_RESPONSE[url].data,{
                        card_no: postParams.card_no,
                        card_pwd: postParams.card_pwd
                    }));
                }
            }
        }else{
            this.fire("chargeresult", paymethod, false, msg.data);
        }
    },

    /**
     * 本地充值
     * @param {Number} money 充值对象
     */
    chargeMoneyByLocal: function(chargeObj){
        DGC.ActionUtil.payAccount({
            type: chargeObj.paymethod,
            money: chargeObj.recharge,
            quantity : chargeObj.quantity,
            cardValue : chargeObj.recharge * 10
        });
    },

    /**
     * 本地充值回调
     */
    chargeMoneyByGFanCallback: function(msg){
        this.fire("chargegfan", msg.success , msg.data );
    },

    /**
     * 查询乐逗商城道具列表
     */
    queryShopItems: function(){
        DGC.ActionUtil.queryProductList();
    },

    /**
     *查询道具列表回调
     */
    queryShopItemsCallback: function(msg){
        if(msg && msg.success){
            this.fire("shopitems", msg.data);
        }else{
            DGC.ActionUtil.showTipMsg(resName.TIP_NETWORK_DISCONNECT);
        }
    },

    /**
     * 查询购买道具详情
     */
    queryBuyItemDetail: function(field){
        DGC.ActionUtil.getProductInfo(field);
    },

    /**
     * 获得需要购买道具信息回调
     */
    queryBuyItemDetailCallback: function(msg){
        this.fire("payproduct", msg.data);
    },

    /**
     * 乐币支付具体某个订单
     * @param {Object} order 订单
     * @param {Object} item 道具信息(附加)
     */
    payOrderByLeDou: function(order , item ){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL, SDK = window.sdk;
        var requestBody  = {
            msgID : MSG.UPDATE_PAY_BY_LEDOU,
            params: {
                "POST": [
                    {
                        //没有参数
                        url: $.format(API.UPDATE_PAY_ORDER.url),
                        data: $.extend({
                            type: 0, /*乐币购买*/
                            channel_id : window.sdk.channel_id
                        }, order)
                    }
                ]
            },
            plugData: {
                item : item
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'payment/ledoupaysuccess.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 乐逗支付方式
     */
    payOrderByLeDouCallback: function(msg){
        var result = this.processResponse(msg, true/*不显示默认错误TIP*/),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.UPDATE_PAY_ORDER.pattern.test(url)){
                    this.fire("ledoupay", true, POST_RESPONSE[url].data);
                }
            }
        }else{
            this.fire("ledoupay", false, msg.data, this.getPlugParams(msg).item );
        }
    },

    /**
     * Feed API 进行支付购买道具
     * @param {Number} paymethod 支付方式
     * @param {Object} order 订单信息
     * @param {Object} item 道具信息(附加)
     */
    payOrderByFeed : function(paymethod, order, item){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages,API = this.apiURL, SDK = window.sdk;
        var requestBody  = {
            msgID : MSG.UPDATE_PAY_BY_FEED,
            params: {
                "POST": [
                    {
                        //没有参数
                        url: $.format(API.UPDATE_PAY_ORDER.url),
                        data: $.extend({
                            type: 3, /*支付购买*/
                            channel_id : window.sdk.channel_id,
                            paymethod : paymethod
                        }, order)
                    }
                ]
            },
            plugData: {
                item : item
            }

        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'person/chargehistory.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * Feed API支付回调
     */
    payOrderByFeedCallback : function(msg){
        var result = this.processResponse(msg, true),
            API = this.apiURL,
            DAU = DGC.ActionUtil,
            sendObj = this.getDefaultPostObj(msg);

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.UPDATE_PAY_ORDER.pattern.test(url)){
                    var detail = POST_RESPONSE[url].data;
                    //如果为易宝，则将相关账号密码用于页面记录返回
                    if(sendObj.paymethod >= 3 && sendObj.paymethod <= 5){
                        $.extend(detail, {
                            card_no: sendObj.card_no,
                            card_pwd: sendObj.card_pwd
                        });
                    }

                    this.fire("feedpay", true, detail );
                }
            }
        }else{
            this.fire("feedpay", false,
                 $.extend(msg.data, {type: sendObj.paymethod}) ,
                 this.getPlugParams(msg).item);
        }
    },

    /**
     * 本地进行支付购买道具
     * @param {Number} paymethod 支付方式
     * @param {Object} order 订单信息
     */
    payOrderByLocal : function(paymethod, order){
        DGC.ActionUtil.purchaseProduct(paymethod, order);
    },

    /**
     * 本地支付回调
     */
    payOrderByLocalCallback : function(msg){
        this.fire("localpay", msg.success, msg.data);
    },

    /**
     * 支付结果回调
     */
    payShopProductOrderCallback : function(msg){
        this.fire("payresult", result.success, msg.data);
    },

    /**
     * 乐逗商城 消费类商品购买回调
     */
    ledouShopItemsSelectCallback: function(msg){
        this.fire("ledoucountselect", msg.data);
    },

    /**
     * 积分墙信息
     */
    integralInfoCallback : function(msg){
        //存储全局变量
        $.extend(window.sdk, {integralWall: msg.data });
        this.queryPaymentDetail(msg.data.type);
    },

    /**
     * 积分购买道具
     * @param {Object} order 订单
     * @param {Object} item 道具信息(附加)
     */
    payOrderByIntegral : function(order, item){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.UPDATE_PAY_BY_INTEGRAL,
            params: {
                "POST": [
                    {
                        //没有参数
                        url: $.format(API.UPDATE_PAY_ORDER.url),
                        data: $.extend({
                            "type" : 6, /*积分购买*/
                            channel_id : window.sdk.channel_id
                        }, order)
                    }
                ]
            },
            plugData: {
                item : item
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'payment/integralpaysuccess.json'
            });
        }

        DAU.requestAPI(requestBody);
    },

    /**
     * 积分购买回调
     */
    payOrderByIntegralCallback: function(msg){
        var result = this.processResponse(msg, true/*不显示默认错误TIP*/),
            API = this.apiURL,
            DAU = DGC.ActionUtil;

        if(result && result.success){
            var POST_RESPONSE = this.getPostResponse(result);
            for(var url in POST_RESPONSE){
                if(API.UPDATE_PAY_ORDER.pattern.test(url)){
                    this.fire("integralpay", true, POST_RESPONSE[url].data);
                }
            }
        }else{
            this.fire("integralpay", false, msg.data, this.getPlugParams(msg).item );
        }
    },

    /**
     * 查询指定支付方式的汇率的汇率
     */
    queryPaymentDetail : function(type){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL;

        var requestBody  = {
            msgID : MSG.QUERY_PAYMENT_DETAIL,
            params: {
                "GET": [
                    {
                        //没有参数
                        url: $.format(API.GET_PAYMENTPROFILE_DETAIL.url,[type])
                    }
                ]
            }
        };

        //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'payment/paymentprofile_show.json'
            });
        }

        //如果有Cache，直接触发
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("paymentdetail",cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    /**
     * 查询指定支付方式的汇率回调
     */
    queryPaymentDetailCallback: function(msg){
        var result = this.processResponse(msg), API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result);
            for(var url in GET_RESPONSE){
                if(API.GET_PAYMENTPROFILE_DETAIL.pattern.test(url)){
                    this.putCacheByObj(this.getRequestKey(msg), GET_RESPONSE[url].data);
                    this.fire("paymentdetail", GET_RESPONSE[url].data);
                }
            }
        }
    },

    /**
     * 支付模块提示错误方法
     */
    showPayErrorDetail:function(errorDetail){
        var showTipMsg;
        switch(errorDetail.err_code){
            case -1:
                showTipMsg = errorDetail.err_detail;
                break;
            case 1:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_PRODUCT_WRONG;
                break;
            case 2:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_PRODUCT_AREADY_HAS;
                break;
            case 3:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_CROSS_RIGHT;
                break;
            case 4:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_NOT_EXPIRES;
                break;
            case 5:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_CREATE_ORDER_FAIL;
                break
            case 6:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_BY_LEDDOU_FAIL;
                break;
            case 7:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_LEDOU_NOT_ENOUGH;
                break;
            case 8:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_INVAIL_ORDER;
                break;
            case 9:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_NUM_NOT_MATCH_ORDER;
                break;
            case 12:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_HAS_NO_GOODS;
                break;
            case 13:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_PASS_NOT_NULL;
                break;
            case 14:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_PASS_WRONG;
                break;
            case 16:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_LEDOU_FORBIDDEN;
                break;
            case 17:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_ORDER_UPDATE_ERROR;
                break;
            //case 100:
            //	showTipMsg = resName.
            case 102:
            case 107:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_YIBAO_INVAIL_CARD;
                break;
            case 111:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_YIBAO_ORDER_EXIST;
                break;
            case 112:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_YIBAO_INVAIL_SIGN;
                break;
            case 113:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_YIBAO_COMMIT_FAIL;
                break;
            case 166:
                showTipMsg = resName.TIP_SERVER_ERROR_PAY_YIBAO_UNSPPORT_MONEY;
                break;
        }

        DGC.ActionUtil.showTipMsg(showTipMsg);
    }

});