/**
 * 交叉推广数据模型
 * @author Jerry.Zhang
 */
DGC.Model.PromotionBanner = $.inherits(DGC.Model,{

    id : 'model_promotionbanners',

    constructor : function(config){

        //声明自定义事件
        this.defineEvents(
            'lrblockbanners', //左右分块广告信息
            'promotionbanner' //查询交叉推广广告列表
        );

        //API接口声明
        this.apiURL = {
            //指定广告位的所有广告
            GET_PROMOTION_BANNER:{
                url: "/promotion/banners?bid={0}&channel={1}&game_id={2}",
                pattern : /\/promotion\/banners\?bid=.*&channel=.*&game_id=\d+/
            },
            /**
             * 收集广告的展示数
             */
            POST_PROMOTION_COUNT:{
                url: "/promotion/count"
            },
            /**
             * 统计广告点击信息
             */
            GET_PROMOTION_CLICK:{
                url : "/promotion/click?a={0}&b={1}&s={2}&c={3}&g={4}&p={5}",
                options : [
                    "u",
                    "pg",
                ],
                pattern : /\/promotion\/click\?a=.*&b=.*&s=\d+&c=\d+&g=\d+/
            }
        }

        DGC.Model.Game.superclass.constructor.call(this,config);
    },

    /**
     * 初始化监听数据流
     */
    registryMessages : function(){
       var MSG  = DGC.Service.Messages;
       this.service.on(MSG.QUERY_PROMOTION_BANNER, this.queryPromotionBannerCallback, this);
       this.service.on(MSG.QUERY_LOCAL_GAME_STATE, this.queryLocalGameListStateCallback, this);
    },


    /**
     * 取指定广告位的所有广告
     * @param {Array} keys 广告位标识
     */
    queryPromotionBanner: function(keys){
        var DAU = DGC.ActionUtil,
            MSG = DGC.Service.Messages,
            API = this.apiURL,
            optionObj = {},
            urls = [];

        //SDK1.3 解锁 PAD版暂时屏蔽广告
        if(window.sdk.is_pad){
            return false;
        }

        for(var i = 0 ; i < keys.length; i++) {
              urls.push({
                   url: $.format(API.GET_PROMOTION_BANNER.url, [ keys[i] , window.sdk.channel_id, window.sdk.game.id] )
              });
        };

        var requestBody  = {
            msgID : MSG.QUERY_PROMOTION_BANNER,
            params: {
                "GET": urls
            }
        };

         //Web Debug
        if(DEBUG.isWebModel()){
            $.extend(requestBody, {
                version: '1.2.0',
                mockUrl: 'promotionbanner/promotion_scroll.json'
            });
        }

         //Cache
        var cacheItem = this.getCacheByObj(requestBody);
        if(cacheItem){
            this.fire("promotionbanner", cacheItem);
        }else{
            DAU.requestAPI(requestBody);
        }
    },

    //取指定广告位的所有广告回调
    queryPromotionBannerCallback: function(msg){
        var result = this.processResponse(msg, true),
            API = this.apiURL;

        if(result && result.success){
            var GET_RESPONSE = this.getQueryReponse(result),
                banners = [];

            for(var url in GET_RESPONSE){
                banners.push(GET_RESPONSE[url].data);
            }

            if(DEBUG.isWebModel()){
                return false;
            }

            //存在广告则分发
            if(banners.length > 0) {
                this.fire("promotionbanner", banners);
            }
        }
    },
    /**
     * 统计广告点击信息
     * @param {string} aid 广告ID
     * @param {string} bid 广告位ID
     * @param {int} bid 广告位ID 对于广告为APK类型的统计，若需要下载值为：0，已下载的不管安装与否其值为：1
     */
    promotionBannerClick: function( aid, bid, status){
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;

        var requestBody  = {
            msgID : MSG.PROMOTION_BANNER_COUNT,
            params: {
                "GET": [
                    {
                        url: $.format(API.GET_PROMOTION_CLICK.url, [
                                aid,
                                bid,
                                status,
                                window.sdk.channel_id,
                                window.sdk.game.id,
                                window.sdk.player.id]
                        ),
                    }
                ]
            }
        };

        DAU.requestAPI(requestBody);

    },
    /**
     * 收集广告的展示数
     * @param {string} aid 广告ID
     * @param {string} bid 广告位ID
     */
    promotionBannerCount: function (aid, bid) {
        var DAU = DGC.ActionUtil, MSG = DGC.Service.Messages, API = this.apiURL;
        var requestBody  = {
            msgID : MSG.PROMOTION_BANNER_COUNT,
            params: {
                "POST": [
                    {
                        url: API.POST_PROMOTION_COUNT.url,
                        data: {
                            "aid" : aid,
                            "bid" : bid
                        }
                    }
                ]
            }
        };

        DAU.requestAPI(requestBody,true);
    },


    //游戏状态回调
    queryLocalGameListStateCallback : function(msg){
        this.fire("localgamestate", msg);
    }
});