/**
 * 分享游戏
 */
DGC.Dialog.ShareGame =  $.inherits(DGC.Dialog, {

    baseId: 'sharegame-dialog',

    renderTpl: '1.2.0/js/template/dialog/sharegame.html',

    //最大字符数
    contentLimit: 140,

    notBindCallback: $.emtpyFn,

    viewReady: function(){
        var DC = DGC.Common;

        this.viewTpl = {
            SHARE:"#sg-share-tpl",
            SEND:"#sg-send-tpl"
        }

        //判断是否用户是否绑定过
        if(DH.isAnySNSBound()){
            //查询是否存在优先分享行为
            this.playerSNSBoundReady(DC.getAppConfig(DC.localKey('shareway')));
        }else{
            //显示分享方式窗口
            this.showShareWays();
        }
    },

    /**
     * 查询用户优先行为通知
     * @param {Number} type 成功分享过
     */
    playerSNSBoundReady: function(type){
        var KEY = DH.ATTR.BIND_KEY,
            SHARE_WAY = DH.ATTR.SHARE_WAY;

        //直接显示发送窗口
        if(!$.isEmpty(type)){
            this.showSendPage(type);
        }else{
            //优先判断已绑定SNS SDK1.2： 新浪，人人，腾讯(无法判断)
            if(DH.isSNSBound(KEY.SINA)){
                this.showSendPage(SHARE_WAY.SINA);
                return false;
            }

            if(DH.isSNSBound(KEY.RENREN)){
                this.showSendPage(SHARE_WAY.RENREN);
                return false;
            }

            //显示分享方式
            this.showShareWays();
        }
    },

    /**
     * 显示指定的分享发送窗口
     * @param {String} type
     */
    showSendPage: function(type){
        var ATTR = DH.ATTR,
            iconClass;

        //先查询分享内容
        this.meModel.querySNSShareContent(type);

        switch(type){
            case ATTR.SHARE_WAY.SINA:
                iconClass = "sina";
                break;
            case ATTR.SHARE_WAY.RENREN:
                iconClass = "renren";
                break;
            case ATTR.SHARE_WAY.QQ:
                iconClass = "qq";
                break;
        }

        //显示内容
        var sendWinEl = $(this.renderByTpl(this.viewTpl.SEND, {
            iconClass: iconClass,
            name: window.sdk.player.nickname,
            snsType : type
        }));

        sendWinEl.find(".btn").bind(DGC.Common.E_TAP_DOWN, DGC.Common.buttonTapDownHandler)
            .bind(DGC.Common.E_TAP_UP, DGC.Common.buttonTapEndHandler);

        sendWinEl.find(".btn-ok").bind("tap", {context:this}, this.sendSNSMsg);

        //取消
        sendWinEl.find(".btn-cancel").bind("tap",{context:this},function(event){
            var context = event.data.context;

            //记录点：“默认分享方式”界面，点击  “取消”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_FRIENDS_INVITE_ACTION,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.INVITE_ACTION_CANCEL
                }
            );

            context.destory();
        });

        //返回页面
        sendWinEl.find(".btn-back").bind("tap", {context: this}, function(event){
            var context = event.data.context;

            //记录点：“默认分享方式”界面，点击  “其他方式”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_FRIENDS_INVITE_ACTION,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.INVITE_ACTION_OTHERS
                }
            );

            context.showShareWays();
        });

        this.el.find(".other-share-page").remove();
        this.el.append(sendWinEl);
    },

    /**
     * 显示默认模板内容
     */
    contentReady: function(content){
        this.el.find(".share-text").val(content.message);
    },

    /**
     * 发送分享微博成功
     */
    sendSNSSuccess: function(type, result){
        var ATTR = DH.ATTR,
            DAU = DGC.ActionUtil;
        switch(type){
            case ATTR.SHARE_WAY.QQ:
                //如果有redirect,则进入QQ微博页面
                if(result.redirect){
                    //打开页面,通过QQ授权认证
                    DAU.openWebView(result.redirect);
                    break;
                }
            default:
                DAU.showTipMsg(resName.TIP_SHAREGAME_SHARE_SUCCESS);
                break;
        }
        this.destory();
    },

    /**
     * 发送SNS内容
     */
    sendSNSMsg : function(event){
        var context = event.data.context,
            type = parseInt(context.el.find(".share-send-page").attr("data-key"), 10),
            textAreaEl = context.el.find(".share-text"),
            value = textAreaEl.val();

        //记录点：“默认分享方式”界面，点击  “发送”
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_ME_FRIENDS_INVITE_ACTION,
            {
                'user_id': window.sdk.player.id,
                'action_type': DGC.Event.Option.INVITE_ACTION_SEND
            }
        );

        if($.isEmpty(value)){
            DGC.ActionUtil.showTipMsg(resName.TIP_SHAREGAME_CONTENT_NOT_EMPTY);
            return false;
        }

        if(value > context.contentLimit){
            DGC.ActionUtil.showTipMsg($.format(resName.TIP_SHAREGAME_CONTENT_LIMIT,[context.contentLimit]));
            return false;
        }

        context.meModel.updateShareContentToSNS( type, value);
    },

    /**
     * 显示分享方式窗口
     */
    showShareWays: function(){
        var renderEl = $(this.renderByTpl(this.viewTpl.SHARE,{}));
        renderEl.find(".way-cell")
            .bind(DGC.Common.E_TAP_DOWN, DGC.Common.buttonTapDownHandler)
            .bind(DGC.Common.E_TAP_UP, DGC.Common.buttonTapEndHandler);

        //新浪
        renderEl.find("#sina-share-btn").bind("tap", { context : this }, function(event){
            var context = event.data.context,
                ATTR = DH.ATTR;

            //记录点：“选择发送到其他位置”界面，点击新浪微博
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_INVITE_FRIENDS,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.SHARE_GAME_CHANNEL_SINA
                }
            );

            if(DH.isSNSBound(ATTR.BIND_KEY.SINA)){
                context.showSendPage(ATTR.SHARE_WAY.SINA);
            }else{
                //关闭当前窗口，要求用户绑定
                context.destory();
                context.notBindCallback.call(context, ATTR.BIND_SNS.SINA);
            }
        });

        //人人
        renderEl.find("#renren-share-btn").bind("tap", { context : this }, function(event){
            var context = event.data.context,
                ATTR = DH.ATTR;

            //记录点：“选择发送到其他位置”界面，点击人人
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_INVITE_FRIENDS,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.SHARE_GAME_CHANNEL_RENREN
                }
            );

            if(DH.isSNSBound(ATTR.BIND_KEY.RENREN)){
                context.showSendPage(ATTR.SHARE_WAY.RENREN);
            }else{
                //关闭当前窗口，要求用户绑定
                context.destory();
                context.notBindCallback.call(context, ATTR.BIND_SNS.RENREN);
            }
        });
        //QQ
        renderEl.find("#qq-share-btn").bind("tap", { context : this }, function(event){
            var context = event.data.context,
                ATTR = DH.ATTR;

            //记录点：“选择发送到其他位置”界面，点击QQ
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_INVITE_FRIENDS,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.SHARE_GAME_CHANNEL_TECENT
                }
            );

            context.showSendPage(ATTR.SHARE_WAY.QQ);
        });

        //短信
        renderEl.find("#sns-share-btn").bind("tap", { context : this }, function(event){
            var context = event.data.context,
                ATTR = DH.ATTR;
            //记录点：“选择发送到其他位置”界面，点击短信
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_INVITE_FRIENDS,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.SHARE_GAME_CHANNEL_MESSAGE
                }
            );
            context.meModel.queryInviteFriendsMsg(ATTR.LOCAL_SHARE_TPL.MSG);
        });

        //电子邮件
        renderEl.find("#email-share-btn").bind("tap", { context : this }, function(event){
            var context = event.data.context,
                ATTR = DH.ATTR;

             //记录点：“选择发送到其他位置”界面，点击E-MAIL
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_INVITE_FRIENDS,
                {
                    'user_id': window.sdk.player.id,
                    'action_type': DGC.Event.Option.SHARE_GAME_CHANNEL_MAIL
                }
            );
            context.meModel.queryInviteFriendsMsg(ATTR.LOCAL_SHARE_TPL.EMAIL);
        });


        //取消
        renderEl.find(".btn-cancel").bind("tap",{context:this},function(event){
            var context = event.data.context;
            context.destory();
        });

        this.el.find(".share-send-page").remove();
        this.el.append(renderEl);
    }

});

/**
 * 分享相关枚举
 */
$.extend(DH.ATTR, {
    /*分享方式*/
    SHARE_WAY:{
        SINA : 1,
        RENREN : 2,
        QQ: 4,
        MSG: 5,
        EMAIL: 6
    },
    /*本地分享枚举 */
    LOCAL_SHARE_TPL:{
        MSG: 1,
        EMAIL:2
    }
});
