/**
 * 用户登录框
 */
DGC.Dialog.UserLogin = $.inherits(DGC.Dialog, {

    baseId : 'muti-login',

    renderTpl : '1.2.0/js/template/dialog/mutilogin.html',

    /**
     * 显示模式
     */
    showModel : 0,

    /**
     * 需要返回的视图
     */
    lastView: undefined,

    /**
     * 当前视图
     */
    currentView: undefined,


    viewReady : function() {
        var USER_LOGIN_DIALOG = DH.ATTR.USER_LOGIN_DIALOG;

        //初始化视图历史栈
        this.lastView = [];

        switch(this.showModel){
            case USER_LOGIN_DIALOG.LOGIN:
                this.bindNewPlayer();
                this.currentView = $("#new-player");
                break;
            case USER_LOGIN_DIALOG.SWITCH:
                //移除新用户登录窗口
                this.bindSwitchDialog();
                this.currentView = $("#ledou-login");
                break;
        }
        this.currentView.show();

        this.bindViewSwitch();
        this.bindLeDouLogin();
        this.bindSinaLogin();
        this.bindRenrenLogin();
    },

    onDestory : function() {
        //记录该窗口已经打开过
        window.sdk.logined = true;
        this.lastView = null;
        DGC.Dialog.UserLogin.superclass.onDestory.call(this);
    },

    /**
     * 显示指定View
     * @param {String} viewId DOM id
     */
    showView: function(viewId){
        var context = this;
        //Hacker 规避input焦点
        setTimeout(function() {
            //记录当前视图
            var lastV = context.currentView;
            context.lastView.push(lastV);
            lastV.hide();
            context.currentView = $("#"+ viewId);
            context.currentView.show();
        }, 200);
    },

    /**
     * 回显上一个视图
     */
    popView: function(){
        var context = this;
        //Hacker 规避input焦点
        setTimeout(function() {
            if(context.lastView.length > 0){
                context.currentView.hide();
                context.currentView = context.lastView.pop();
                context.currentView.show();
            }
        }, 200);
    },


    /**
     * 新用户登录
     */
    bindNewPlayer : function(){
        //设置默认登录账户
        this.el.find("input[name='new-username']").attr("placeholder", window.sdk.player.nickname);

        //性别
        this.el.find(".sex-wrap > div").bind("tap",{ context: this }, function(event){
            var me = $(this);
            if(me.hasClass('active')){
                return false;
            }

            me.siblings(".active").removeClass('active');
            me.addClass("active");

            //记录点：新用户提示登陆界面，更新性别
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_NEW_USER_UPDATE_SEX,
                {
                    'user_id':window.sdk.player.id,
                    'sex': me.hasClass('male') ?
                        DGC.Event.Option.SEX_MAN :
                        DGC.Event.Option.SEX_WOMAN
                }
            );
        });


        //已有乐逗账号登录
        $("#ledou-account").bind("tap", {context:this}, function(event){
            var context = event.data.context;

            //记录点：新用户登陆界面，已有SKYNET登录
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_NEW_USER_ACTION,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACTION_TYPE_USING_SKYNET
                }
            );

            context.showView("ledou-login");
        });

        //进入乐逗空间
        $("#ml-enter-sdk").bind("tap",{context:this},function(event){
            var context = event.data.context,
                nameEl = $("input[name='new-username']"),
                sexEl = $(".sex-wrap .active"),
                newName = nameEl.val(),
                gender;

            //记录点：新用户登陆界面，进入空间
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_NEW_USER_ACTION,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACTION_TYPE_SIGN_IN
                }
            );

            if(sexEl.hasClass('male')){
                gender = DH.ATTR.GENDER.MALE;
            }else if(sexEl.hasClass('female')){
                gender = DH.ATTR.GENDER.FEMALE;
            }

            var isNameDefault = ( $.isEmpty(newName) || newName == nameEl.attr("placeholder") ),
                isSexDefault = ( gender == window.sdk.player.gender );

            //没有输入新账号且没有修改性别，直接关闭窗口
            if( isNameDefault && isSexDefault  ){
                context.destory();
                return false;
            }

            //将修改的参数放入对象中
            var postObj = {};
            if(!isNameDefault){
                //记录点：新用户提示登陆界面，更新用户名
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_NEW_USER_UPDATE_USERNAME,
                    {
                        'user_id':window.sdk.player.id,
                    }
                );

                $.extend(postObj,{ "nickname" : newName });
            }
            if(!isSexDefault){
                $.extend(postObj,{ "gender": gender });
            }

            //发起修改用户信息请求
            context.meModel.modifyNewPlayerInfo(postObj);
        });
    },

    /**
     * 绑定切换账号
     */
    bindSwitchDialog: function(){
        var cancel = $("#ledou-login .return-btn");
        $("#new-player").remove();
        cancel.text(resName.BUTTON_USERLOGIN_DIALOG_CANCEL);
        cancel.removeClass('return-btn').addClass('cancel-btn');
        cancel.bind('tap', {context: this },function(event){
            event.data.context.destory();
        });
    },

    /**
     * 乐逗的登录Tab内部切换
     */
    bindViewSwitch : function() {
        //新浪登录
        $(".sina-login-icon").bind('tap',{ context:this } ,function(event) {
            var context = event.data.context;

            //记录点：新用户登陆界面，新浪登录
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_NEW_USER_ACTION,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACTION_TYPE_USING_SINA
                }
            );

            context.showView("sina-login");
        });

        //人人登录
        $(".renren-login-icon").bind('tap', { context:this },  function(event) {
            var context = event.data.context;

            //记录点：新用户登陆界面，人人登录
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_NEW_USER_ACTION,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACTION_TYPE_USING_RENREN
                }
            );

            context.showView("renren-login");
        });

        //返回按钮
        $(".return-btn").bind('tap', { context:this }, function(event) {
            var context = event.data.context;
            context.popView();
        });
    },

    /**
     * 乐逗账号登录
     */
    bindLeDouLogin : function() {
        //乐逗账号登录
        $("#ledou-login-btn").bind("tap", {context : this}, function(event) {
            var context = event.data.context,
                userName = $("input[name='ld-username']").val(),
                password = $("input[name='ld-password']").val(),
                DAU = DGC.ActionUtil;

            //记录点：新用户登陆界面，乐逗登录
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_SETTINGS_SWITCH_ACCOUNT_DETAIL,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACCOUNT_SKYNET
                }
            );

            //用户名不能为空
            if($.isEmpty(userName)) {
                DAU.showTipMsg(resName.TIP_ACCOUNT_NOT_NULL);
                return false;
            }

            //密码不能为空
            if($.isEmpty(password)) {
                DAU.showTipMsg(resName.TIP_PASSWORD_NOT_NULL);
                return false;
            }

            //请求切换账户
            context.meModel.switchLeDouAccount(userName, password);

            return false;
        });
    },

    /**
     * 新浪账户登录
     */
    bindSinaLogin : function() {
        $("#sina-login-btn").bind("tap",  {context : this}, function(event) {
            var context = event.data.context,
                userName = context.el.find("input[name='sina-username']").val(),
                password = context.el.find("input[name='sina-password']").val(),
                DAU = DGC.ActionUtil;


            //记录点：新用户登陆界面，新浪登录
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_SETTINGS_SWITCH_ACCOUNT_DETAIL,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACCOUNT_SINA
                }
            );

            //用户名不能为空
            if($.isEmpty(userName)) {
                DAU.showTipMsg(resName.TIP_ACCOUNT_NOT_NULL);
                return false;
            }

            //密码不能为空
            if($.isEmpty(password)) {
                DAU.showTipMsg(resName.TIP_PASSWORD_NOT_NULL);
                return false;
            }

            context.meModel.snsAccountCheck(1/*新浪*/, userName, password);

            return false;
        });
    },
    /**
     * 人人账户登录
     */
    bindRenrenLogin : function() {
        $("#renren-login-btn").bind("tap", {context : this}, function(event) {

            var context = event.data.context,
                userName = context.el.find("input[name='renren-username']").val(),
                password = context.el.find("input[name='renren-password']").val(),
                DAU = DGC.ActionUtil;

            //记录点：新用户登陆界面，人人登录
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_SETTINGS_SWITCH_ACCOUNT_DETAIL,
                {
                    'user_id':window.sdk.player.id,
                    'new_user_action_type':  DGC.Event.Option.ACCOUNT_RENREN
                }
            );

            //用户名不能为空
            if($.isEmpty(userName)) {
                DAU.showTipMsg(resName.TIP_ACCOUNT_NOT_NULL);
                return false;
            }

            //密码不能为空
            if($.isEmpty(password)) {
                DAU.showTipMsg(resName.TIP_PASSWORD_NOT_NULL);
                return false;
            }

            context.meModel.snsAccountCheck(2/*人人*/, userName, password);

            return false;
        });
    }
});