/**
 * 活动
 * @author Jerry.Zhang
 */
DGC.View.Activity = $.inherits(DGC.View, {

    baseId : 'activity-view',

    title : 'A_TITLE_ACTIVITY',

    renderTpl : '1.2.0/js/template/activity.html',

    defaultTab : 'latest-activity',

    currentTab : undefined,

    latestActivityCur : undefined,

    circuseeActivityCur : undefined,

    loadMoreTask : 0,

    //缓存内容
    cacheActivity: undefined,

    /**
     * 视图初始化函数
     */
    viewReady : function() {

        this.viewTpl = {
            PLAYERITEM : "#activity-item-tpl"
        };

        /**
         * 记录已渲染的子模块
         */
        this.subRendered = {
            "latestActivity" : false,
            "circuseeActivity" : false
        };

        //缓存活动内容
        this.cacheActivity = {};

        //存在新的粉丝Tips提示
        if(window.sdk.tips && window.sdk.tips.hasOwnProperty('new_activity')){
            this.setNewActivity();
        }

        //绑定切换Tab事件
        this.bindTabItems();

        //默认加载Tab
        $("#" + this.defaultTab).trigger('tap', { context : this });

        //监听scroll实现动态加载
        //$(window).bind("scroll", { context : this }, this.scrollLoadMore);

        //存储最近一次查看活动时间
        DGC.Common.setAppConfig(DGC.Common.localKey("activitytime"), DGC.Common.formatSeverTime(new Date()));
    },
    /**
     *  Tab导航绑定
     */
    bindTabItems : function() {
        var tabs = this.el.find('.common-tab-nav li');
        tabs.bind('tap', {
            context : this
        }, function(event) {
            var context = event.data.context, el = $(this), meModel = context.action.model['me'];

            if(context.currentTab) {
                //隐藏当期Tab Element
                $("#" + context.currentTab).removeClass('tab-active');
                //隐藏
                context.getContentEl(context.currentTab).hide();
            }
            //激活当前点击Tab
            el.addClass('tab-active');
            //显示对应的Tab Content内容
            context.getContentEl(el.attr("id")).show();
            context.currentTab = el.attr("id");

            switch(context.currentTab) {
                case "latest-activity":
                    //第一次查询先清空TIPS
                    if(window.sdk.tips && window.sdk.tips.hasOwnProperty('new_activity')){
                        context.clearNewActivity();
                    }
                    if(!context.subRendered.latestActivity) {
                        meModel.queryLatestActivity(window.sdk.player.id, context.latestActivityCur);
                    }
                    //记录页面访问次数
                    DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME_ACTIVITY);
                    break;
                case "circusee-activity":
                    if(!context.subRendered.circuseeActivity) {
                        meModel.queryCircuseeActivity(window.sdk.player.id, context.circuseeActivityCur);
                    }
                    //记录页面访问次数
                    DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME_ACTIVITY_FAVORITE);
                    break;
            }
        });
    },

    /**
     * 显示新活动数
     */
    setNewActivity: function(){
        //清空Fans的TIPS提示
        var tips = window.sdk.tips,
            totals = 0;

        for(var key in tips){
            totals = totals + tips[key];
        }

        //显示剩余TIPS
        DGC.ActionUtil.updateTabTip(DGC.Module.ATTRS.ME, totals - tips.new_activity);
    },

    /**
     * 清除活动数
     */
    clearNewActivity: function(){
        delete  window.sdk.tips.new_activity;
        //this.el.find("span.new-fans").text("");
    },

    /**
     * 获取contentEL对象
     * @param {String} id Tab导航元素的id 属性
     */
    getContentEl : function(id) {
        return $("#" + id + "-content");
    },


    /**
     * 获取需要延迟加载的图标信息
     */
    getDelayIcons : function(activities) {
        var delays = [];

        //delayIcons
        for(var i = 0; i < activities.length; i++) {
            var activity = activities[i];
            if(!$.isEmpty(activity.image)) {
                delays.push({
                    url : activity.image,
                    id : activity.id
                });
            }
        };
        return delays;
    },
    /**
     * 渲染最新活动列表
     */
    renderLatestActivity : function(activityInfo, isMore) {
        var activities = activityInfo.data,
            renderedLatestActivity = $("#latest-activity-content .list-item").size(),
            wrap = $("#latest-activity-content"),
            delayIcons = null,
            DC = DGC.Common;

        //返回列表为空
        if(activities.length == 0 && !isMore) {
            //没有加载过，则当前没有活动
            if(renderedLatestActivity == 0) {
                wrap.prepend(DGC.Common.getEmptyListItemHtml(resName.TEXT_LATEST_ACTIVITY_EMPTY));
            }
        } else {
            delayIcons = this.getDelayIcons(activities);

            for(var i = 0; i < activities.length; i++) {
                var activity = activities[i];
                $.extend(activity, {
                    time : DC.getFormatDate(DC.getDateFromTime(activity.created)),
                    hasDetail: !$.isEmpty(activity.detail)
                });

                //缓存详情
                if(activity.hasDetail){
                    this.cacheActivity[activity.id] =  activity.detail;
                }
            };
            var items = $(this.renderByTpl(this.viewTpl.PLAYERITEM, activities));
            items.bind(DGC.Common.E_TAP_UP, DGC.Common.listTapEndHandler).bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler).bind("tap", {
                context : this
            }, this.showActivityDetail);

            items.find(".check-in").bind('tap', {
                context : this
            }, this.circuseeActivity);
            //

            //渲染HTML
            wrap.append(items);

            //延迟加载图标
            if(delayIcons.length > 0) {
                this.loadImages(delayIcons, function(img, data) {
                    var item = $("#latest-activity-content div[data-key='" + data.id + "']");
                    item.find(".default-icon").replaceWith("<img src='" + img.src + "'/><div class='mask'></div>");
                });
            }

            //缓存最新活动下一页的游标
            this.latestActivityCur = activityInfo.next_cursor ? activityInfo.next_cursor : null;
        }

        this.subRendered.latestActivity = true;
    },
    /**
     * 渲染已围观的活动列表
     */
    renderCircuseeActivity : function(activityInfo, isMore) {
        var activities = activityInfo.data,
            renderedCircuseeActivity = $("#circusee-activity-content .list-item").size(),
            wrap = $("#circusee-activity-content"),
            delayIcons = null,
            DC = DGC.Common;

        DGC.ActionUtil.log("activity:" + JSON.stringify(activities));
        //返回activity数为0
        if(activities.length == 0 && !isMore) {
            //第一次渲染
            if(renderedCircuseeActivity == 0) {
                wrap.html(DGC.Common.getEmptyListItemHtml(resName.TEXT_CIRCUSEE_ACTIVITY_EMPTY));
            }
        } else {
            delayIcons = this.getDelayIcons(activities);

            for(var i = 0; i < activities.length; i++) {
                var activity = activities[i];
                $.extend(activity, {
                    time : DC.getFormatDate(DC.getDateFromTime(activity.created)),
                    hasDetail: !$.isEmpty(activity.detail)
                });

                //缓存详情
                if(activity.hasDetail && !this.cacheActivity[activity.id]){
                    this.cacheActivity[activity.id] =  activity.detail;
                }
            };

            var items = $(this.renderByTpl(this.viewTpl.PLAYERITEM, activities));
            items.bind(DGC.Common.E_TAP_UP, DGC.Common.listTapEndHandler).bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler).bind("tap", {
                context : this
            }, this.showActivityDetail);

            //渲染HTML
            wrap.append(items);

            //延迟加载图标
            if(delayIcons.length > 0) {
                this.loadImages(delayIcons, function(img, data) {
                    var item = $("#circusee-activity-content div[data-key='" + data.id + "']");
                    item.find(".default-icon").replaceWith("<img src='" + img.src + "'/><div class='mask'></div>");
                });
            }

            //缓存已围观活动下一页的游标
            this.circuseeActivityCur = activityInfo.next_cursor ? activityInfo.next_cursor : null;
        }

        this.subRendered.circuseeActivity = true;
    },
    /**
     * 动态加载更多数据
     */
    scrollLoadMore : function(event) {
        var context = event.data.context, meModel = context.action.model['me'], distance = Math.abs($(window).scrollTop() - ($(document).height() - $(window).height()));

        DGC.ActionUtil.log("page scroll:" + $(window).scrollTop());
        DGC.ActionUtil.log("loader point:" + ($(document).height() - $(window).height()));
        //滚到页面底端
        if(distance <= 10) {
            if(context.currentTab == "latest-activity" && context.latestActivityCur != null) {
                clearTimeout(context.loadMoreTask);
                context.loadMoreTask = setTimeout(function() {
                    meModel.queryLatestActivity(window.sdk.player.id, context.latestActivityCur);
                }, DGC.Common.DELAY_SCROLL_LOADER);
            } else if(context.currentTab == "circusee-activity" && context.circuseeActivityCur != null) {
                clearTimeout(context.loadMoreTask);
                context.loadMoreTask = setTimeout(function() {
                    meModel.queryCircuseeActivity(window.sdk.player.id, context.circuseeActivityCur);
                }, DGC.Common.DELAY_SCROLL_LOADER);
            }
        }
    },

    /**
     * 跳转活动详细
     */
    showActivityDetail : function(event) {
        var context = event.data.context,
            activity = $(this),
            id = activity.attr("data-key"),
            name = activity.attr('data-name'),
            detailHtml = context.cacheActivity[id];

        //无详情
        if($.isEmpty(detailHtml)){
            return false;
        }

        //“活动页面”界面，点击查看“具体的活动”
        DGC.ActionUtil.recordUserAction(DGC.Event.EventId.EVENT_ACTIVITY_VIEW, {
            'user_id' : window.sdk.player.id,
            'activity_id' : id,
            'activity_name': name
        });

        //回退恢复用户状态
        $.extend(context.initConfig, {
            defaultTab : context.currentTab
        });

        context.action.setView('ActivityDetail', {
            contextHtml : detailHtml
        });
    },

    //围观活动
    circuseeActivity : function(event) {
        var context = event.data.context,
            itemEl = $(this).parents(".list-item"),
            activity_id = itemEl.attr("data-key"),
            activity_name = itemEl.attr('data-name');

        //“活动页面”界面，围观“具体的活动”
        DGC.ActionUtil.recordUserAction(DGC.Event.EventId.EVENT_ACTIVITY_ADD_FAVORITE, {
            'user_id' : window.sdk.player.id,
            'activity_id' : activity_id,
            'activity_name': activity_name
        });

        context.action.model['me'].updateCircuseeActivity(activity_id);

        event.stopPropagation();
    },

    /**
     * 围观活动
     */
    updateCircuseeActivity : function(activityInfo) {
        var activity = activityInfo.data;
        //围观成功
        if(activity.participance) {
            $("#latest-activity-content div[data-key='" + activity.id + "']").find("a.check-in").replaceWith(" <a class=\"end-get\">" + resName.TEXT_ACTIVITY_CIRCUSEED + "</a>");
        }
    },
    /**
     * 视图销毁时，移除事件监听
     */
    onDestory : function() {
        $(window).unbind("scroll", this.scrollLoadMore);
    }
});
