/**
 * 排行榜分类视图
 */
DGC.View.BoardCategory =  $.inherits(DGC.View, {

    baseId:'boardcategory-view',

    /**
     * 别名
     */
    alias: 'BoardCategory',

    /**
     * 根视图
     */
    isSub: false,


    renderTpl: '1.2.0/js/template/boardcategory.html',

    game : undefined,

    player: undefined,

    boardList: undefined,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        /**
         * 子模块需要的数据HTML模板
         * @type
         */
        this.viewTpl = {
            BOARD:'#board-tpl'
        };

        var gameName = window.sdk.isOffline ? window.sdk.game_name : (this.game != null ? this.game.name : window.sdk.game.name);

        //游戏名称显示
        this.setTitle($.format(resName.A_TITLE_BOARD, [ gameName ] ));

        //this.queryGameBoard();
        //查询数据/获得模板/渲染HTML/绑定事件
        var me = this,
            model = me.action.model;

        //直接渲染
        if(this.boardList){
            this.renderBoardList();
        //查询排行列表
        }else{
            model['hs'].queryLeaderBoradList(window.sdk.game.id);
        }

        //离线显示重登陆按钮
        if(window.sdk.isOffline){
            this.bindReloginBtn();
        }else{
            //在线模式获取banner广告 SDK成就左,SDK成就右
            this.action.model["prombanner"].queryPromotionBanner(DGC.Ads.getBanners(this.alias));
        }

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_LEADERBOARD_INDEX);

    },

    /**
     * 离线重登录按钮绑定
     */
    bindReloginBtn : function(){
         $("#offline-relogin").bind(DGC.Common.E_TAP_DOWN,function(){$(this).addClass('active')})
            .bind(DGC.Common.E_TAP_UP,function(){$(this).removeClass('active')})
            .bind("tap", { context: this } , function(event){
                DGC.ActionUtil.offlineRelogin();
            });

         $("#bc-offline-tip").show();
    },

    renderBoardList: function(optionBoards){
        var me  = this,
            listWrap = $("#board-list");

        //存在排行列表参数
        if(optionBoards){
            this.boardList = optionBoards;
        }

        //防止排行榜为null
        this.boardList = this.boardList || [];

        //排行模式数
        $("#bc-board-num").html($.format(resName.TEXT_BOARDCATEGORY_TOTALS,[this.boardList.length]));

        if(this.boardList.length > 0 ){
            listWrap.html(this.renderByTpl(me.viewTpl.BOARD, this.boardList));
            listWrap.find('.list-item')
                    .bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler)
                    .bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler)
                    .bind('tap',{context : this} ,this.showBoardDetail);

           //延迟加载图片
           this.loadImages(this.getDelayIcons(this.boardList), function(img, data){
                var wrap = $(".list-item[data-board='"+ data.identifier +"']");
                wrap.find(".board-defaut-icon").replaceWith('<img src="' + img.src + '"/><div class="mask"></div>')
           });

        }else{
            listWrap.html(DGC.Common.getEmptyListItemHtml(resName.TEXT_DASHBOARD_EMPTY_MODEL));
        }
    },

    /**
     * 获取延迟加载图标
     */
    getDelayIcons : function(boards){
        var delays = [];

        //delayIcons
        for (var i = 0; i < boards.length; i++) {
            var board = boards[i];
            if(!$.isEmpty(board.icon_url)){
                delays.push({
                    url: board.icon_url,
                    identifier: board.identifier
                });
            }
        };

        return delays;
    },

    /**
     * 显示该排行榜的详细信息
     */
    showBoardDetail : function(event){
        var identifier = $(this).data("board"),
            context =  event.data.context,
            clickBoard;
        //找到点击Board对象
        for (var i = 0; i < context.boardList.length; i++) {
            clickBoard = context.boardList[i];
            if(clickBoard.identifier == identifier){
                break;
            }
        };

        //如果排行榜为离线状态，进入离线排行榜，否则进入在线排行榜
        if(window.sdk.isOffline){
            context.action.setView('OfflineBoard',{
                leaderBoard: clickBoard,
                boardList: context.boardList,
                isSub: true
            });
        }else{
            context.action.setView('Dashboard',{
                game: context.game,
                player: context.player,
                leaderBoard: clickBoard,
                isSub: true
            });
        }
    },

    /**
     * 预加载广告图片信息
     */
    loadAds: function(banners){
        var context = this,
            keys = [];

        //待加载的 Ads
        context.waitLoadAds = {};

        for(var i = 0; i < banners.length; i++){
            var banner = banners[i],
                selectAd = DGC.Ads.getBannerShowAd(banner.ads); //获得要渲染广告

            //需要请求的广告
            var requestAd = $.extend(selectAd,{
                "bid": banner["_id"], //广告位ID
                "url": selectAd.img_url //请求图片
            });

            //缓存广告信息
            context.waitLoadAds[requestAd.bid] = {
                status: false,
                data: requestAd
            }

            //FAKE对象
            keys.push(requestAd);
        }

        //预加载广告位图片
        context.loadImages(keys, function(img, data){
            context.waitLoadAds[data.bid].status = true; //广告位图片加载完毕
            //this.loadAds[pid].img = img; //缓存图片对象

            context.sycPageAds(); //同步检查所有广告位是否加载成功
        });
    },

    /**
     * 同步检查广告加载
     */
    sycPageAds: function(){
        for( var key in this.waitLoadAds){
            var ad = this.waitLoadAds[key];
            if(!ad.status){
                return false; //尚未完成加载
            }
        }

        //加载完毕,渲染全部广告
        this.renderPromotionBanner();
    },

    /**
     * 渲染页面广告
     */
    renderPromotionBanner: function(){
         var PAGE_BID = DGC.Ads.PAGES[this.alias],
             loadedAds = this.waitLoadAds,
             tplObj = {
                leftAd: loadedAds[PAGE_BID.LEFT].data, //左边广告
                rightAd: loadedAds[PAGE_BID.RIGHT].data, //右边广告
             },
             bannerModel = this.action.model['prombanner'];

        var renderBanner = $(this.renderByTpl(DGC.Ads.getSidesAdTpl(), tplObj));
        //点击触发
        renderBanner.find("a").bind("tap", {context : this}, function(event){
            var context = event.data.context;
                me = $(this),
                bid = me.parent(".ad-wrap").attr('data-key'),
                adObj = context.waitLoadAds[bid].data;
            switch(adObj.ad_type){
                case 1 /*APK*/:
                    DGC.ActionUtil.getGameState([adObj.package_name]);
                    context.cacheClickAd = adObj /*缓存点击广对象*/;
                    break;
                case 2 /*网页*/:
                    DGC.ActionUtil.openBrowser(adObj.ad_url);
                    break;
            }
        });
        this.el.prepend(renderBanner);

        //统计广告位中显示次数
        setTimeout(function(){
            bannerModel.promotionBannerCount(tplObj.leftAd.id, tplObj.leftAd.bid);
            bannerModel.promotionBannerCount(tplObj.rightAd.id, tplObj.rightAd.bid);
            renderBanner.fadeIn('slow');
        },0);

    },
    /**
     * 下载或启动游戏APK
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            bannerModel = this.action.model["prombanner"];

        if(this.cacheClickAd){
            if(status) {
                bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheClickAd.bid, 1/*运行*/ );//记录广告点击
                DGC.ActionUtil.startGame(this.cacheClickAd.bundle_id);//启动游戏
            } else {
               bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheClickAd.bid, 0 /*下载*/);//记录广告点击
               DGC.ActionUtil.download(this.cacheClickAd.ad_url);//下载游戏
            }
            this.cacheClickAd = null;
        }
    }

});
