/**
 * 充值提交页面
 */
DGC.View.ChargeCommit =  $.inherits(DGC.View, {

    baseId: 'charge-commit-view',

    title: 'A_TITLE_CHARGE_ACCOUNT',

    renderTpl:'1.2.0/js/template/chargecommit.html',

    payWay: undefined,

    //有且只有一种充值模式
    onlyPay: false,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        //缓存已经充值成功的账号
        this.chargedAccount = [];

        //电信/联通/移动卡号密码位数限制
        this.limitConifg = {
            //移动
            v3:{
                cardNumber: 17,
                password: 18
            },
            //联通
            v4:{
                cardNumber: 15,
                password: 19
            },
            //电信
            v5:{
                cardNumber: 19,
                password: 18
            }
        }

        //Top Bar 文本信息
        this.el.find(".charge-type-tip").html($.format(resName.TEXT_CHARGECOMMIT_PAYWAY,["<span>\""+ this.payWay.name +"\"</span>"]));

        //设置empty内容
        var cardField = this.el.find("input[name='cardNumber']"),
            passField = this.el.find("input[name='password']"),
            maxConfig = this.limitConifg['v'+this.payWay.identifier];

        //易宝需要卡号 /密码
        if(this.isNeedCardInfo(this.payWay.identifier)){
            cardField.attr("maxlength", maxConfig.cardNumber);
            passField.attr("maxlength", maxConfig.password);
            cardField.attr("placeholder",$.format(resName.TEXT_CHARGECOMMIT_CARD_NUM_TIP,[maxConfig.cardNumber]));
            passField.attr("placeholder",$.format(resName.TEXT_CHARGECOMMIT_CARD_PASS_TIP,[maxConfig.password]));
            cardField.keypress(DGC.Common.onlyAllowNumber);
            passField.keypress(DGC.Common.onlyAllowNumber);
        //其他支付，则隐藏卡号/密码表单
        }else{
            this.el.find(".field-wrap:gt(0)").hide();
        }

        //渲染支付列表
        this.renderPayValues();

        //充值按钮
        $("#cc-pay").bind(DGC.Common.E_TAP_DOWN,function(){$(this).addClass('active')})
            .bind(DGC.Common.E_TAP_UP,function(){$(this).removeClass('active')})
            .bind("tap", { context: this }, this.payActionHanlder);

        //帮助按钮
        $("#charge-help").bind(DGC.Common.E_TAP_DOWN,function(){$(this).addClass('active')})
            .bind(DGC.Common.E_TAP_UP,function(){$(this).removeClass('active')})
            .bind("tap", { context: this }, function(event){
                var context = event.data.context;

                //“具体某一渠道充值”界面，点击帮助
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_ME_PAYMENT_CHARGE_DETAIL_HELP,
                    {
                        'user_id': window.sdk.player.id,
                        'charge_channel': DGC.Event.Util.getPayEvent(context.payWay.identifier)
                    }
                );

                context.action.showDialog( "PayHelpDialog", { payWay:context.payWay },  function(name, params){
                    //弹出绑定的Dialog
                    new DGC.Dialog[name](params).show();
                }, context);
            });

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME_PAYMENT_DETAIL);
    },

    /**
     * 是否需要卡号/密码(易宝)
     * @param {Number} paymethod 充值方式枚举
     */
    isNeedCardInfo: function(paymethod){
        switch(paymethod){
             /*易宝移动，联通，电信*/
             case 3:
             case 4:
             case 5:
                return true;
                break;
        }

        return false;
    },

    /**
     * 自定义Back函数
     */
    backAction : function(){
        if(this.onlyPay){
            return 2 /*回退2层视图*/;
        }else{
            return true;
        }
    },

    /**
     * 渲染可选金额项
     */
    renderPayValues : function(){
        var selectValue = "{0}"+ resName.TEXT_MYPURSE_UNIT,
            options = this.payWay.list_values,
            optionLabels = [],
            selectEl = $("#cc-payvalues");

        //下拉选项框拼接结构
        for (var i = 0; i < options.length; i++) {
            optionLabels.push($.format("<option value={0}>",[ options[i] ]));
            optionLabels.push($.format(selectValue,[ options[i] ]));
            optionLabels.push("</option>");
        };

        var optionEls = optionLabels.join('')
        selectEl.append(optionEls);

        //下拉选项事件
        selectEl.bind("change", {context:this},function(event){
            var context = event.data.context,
                changeEl = $(this).children("option:selected"),
                labelOption = context.el.find(".select-text");
            labelOption.text(changeEl.text());
        });

        //默认选择项
        this.el.find(".select-text").text($.format(selectValue, [  options[0] ] ));
    },

    /**
     * 充值按钮
     */
    payActionHanlder : function(event){
        var context = event.data.context,
            DAU = DGC.ActionUtil,
            payModel = context.action.model['pay'],
            account = context.el.find("input[name='cardNumber']").val(),
            password = context.el.find("input[name='password']").val(),
            cardValue = parseFloat(context.el.find(".select-text").text()),
            money = Number($("#cc-payvalues option:selected").val());

        var chargeObj = {
            paymethod: context.payWay.identifier,
            recharge:  money,
            quantity: DGC.Common.currencyFormat( money / (context.payWay.rate * context.payWay.discount) , 2 ) /*小数点后2位*/ ,
        }

        //“具体某一渠道充值”界面，点击充值
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_ME_PAYMENT_CHARGE_DETAIL_CHARGE,
            {
                'user_id': window.sdk.player.id,
                'charge_channel': DGC.Event.Util.getPayEvent(chargeObj.paymethod)
            }
        );

        //易宝支付验证
        if(context.isNeedCardInfo(context.payWay.identifier) ){
            //卡号不能为空
            if($.isEmpty(account)){
                DAU.showTipMsg(resName.TIP_CHARGECOMMIT_ACCOUNT_NOT_NULL);
                return false;
            }

            //卡密不能为空
            if($.isEmpty(password)){
                DAU.showTipMsg(resName.TIP_PASSWORD_NOT_NULL);
                return false;
            }

            //验证卡密位数
            var cardVerify = context.limitConifg['v'+context.payWay.identifier];
            if(account.length  != cardVerify.cardNumber){
                DAU.showTipMsg($.format(resName.TIP_CHARGECOMMIT_INVAIL_CARDNUM, [ cardVerify.cardNumber ]));
                return false;
            }

            if(password.length != cardVerify.password){
                DAU.showTipMsg($.format(resName.TIP_CHARGECOMMIT_INVAIL_PASSWORD, [ cardVerify.password ]));
                return false;
            }

            if(context.isChargedAccount(account, password)){
                DAU.log(resName.TIP_CHARGE_PAY_COMMIT_USED_CARD);
                DAU.showTipMsg(resName.TIP_CHARGE_PAY_COMMIT_USED_CARD);
                return false;
            }

            $.extend(chargeObj,{
                card_no: account,
                card_pwd: password
            });

        }

        /**
         * 判断充值方式
         */
        switch(chargeObj.paymethod){
             /*易宝移动，联通，电信*/
             case 3:
             case 4:
             case 5:
             /*支付宝*/
             case 6:
                 payModel.chargeMoneyByFeed(chargeObj);
                 break;
             case 20: /*机锋*/
             case 21: /*盛付通*/
                 payModel.chargeMoneyByLocal(chargeObj);
                 break;
        }

    },

    /**
     * 是否为充值过的卡密
     * @params cardNo {String} 卡号
     * @params password {String} 密码
     */
    isChargedAccount: function(cardNo, password){
        for(var i = 0 ; i < this.chargedAccount.length; i++){
            var charged = this.chargedAccount[i];
            if(charged.card_no == cardNo && charged.card_pwd == password ){
                return true;
            }
        }

        return false;
    },

    /**
     * FEED API充值结果响应后进行结果操作
     * @param {Number} paymethod Feed API 支付方式
     * @param {Boolean} result 充值结果
     * @param {object} detail 充值方式以及提示
     */
    feedChargeResult: function(paymethod,result, detail){
        var DAU = DGC.ActionUtil;
        if(paymethod == 6 /*支付宝*/){
            //支付宝页面跳转
            if(result){
                //支付宝下单成功->打开新页面
                DAU.openWebView(detail.payment_url, true);
            }else{
                this.action.model['pay'].showPayErrorDetail(detail);
            }
        //易宝
        }else if(paymethod >= 3 && paymethod <= 5 ){
            if(result){
                //缓存已下单成功的卡密
                this.chargedAccount.push({
                    card_no: detail.card_no,
                    card_pwd: detail.card_pwd
                });

                DAU.showTipMsg($.format(resName.TIP_CHARGECOMMIT_YIBAO_SUCCESS, [detail.id]),function(){
                    //回退上一个页面
                    DGC.Application.goBack();
                });
            }else{
                this.action.model['pay'].showPayErrorDetail(detail);
            }

        }
    },

    /**
     * 本地充值(仅GFAN)显示结果
     */
    redirectChargeResult : function(result, detail){
        if(detail.type == 20 /*Gfan支付结果*/){
            this.action.setView("ChargeResult",{
                chargeResult: result,
                errorDetial: detail.errorDetail
            });
        }
    }

});
