/**
 * 排行榜视图
 */
DGC.View.Dashboard =  $.inherits(DGC.View, {

    baseId:'dashboard-view',

    /**
     * 别名
     */
    alias: 'Dashboard',

    /**
     * 排行榜不支持标题文字
     * @type Boolean
     */
    title : false,

    /**
     * 默认不显示Back按钮
     */
    isSub: false,

    renderTpl : "1.2.0/js/template/dashboard.html",

    /**
     * 默认加载显示视图
     * @type String
     */
    defaultTab : 'friendRank',

    /**
     * 当前Tab状态
     * @type
     */
    currentTab : undefined,

    leaderBoard: undefined,

    game: undefined,

    player: undefined,

    /**
     * 排行模式后退显示
     */
    boardsSub : false,

    /**
     * 视图显示模式
     * 0:SDK页面
     * 1:游戏开发者界面
     */
    model: 0,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        //预设置游戏名称
        this.setTitle($.format(resName.A_TITLE_BOARD, [( this.game ? this.game.name : window.sdk.game_name )] ));

        /**
         * 子模块需要的数据HTML模板
         * @type
         */
        this.viewTpl = {
            PLAYERTPL:"#my-postion-tpl",
            RANKTPL:'#db-rank-tpl',
            LOCALRANK:'#local-rank-tpl'
        };

        /**
         * 记录已渲染的子模块
         */
        this.subRendered = {
            "localRank": false,
            "friendRank": false,
            "areaRank":   false,
            "worldRank":  false
        };

        //绑定页面事件
        this.bindRankTabItems();

        //设置当前当前查询的游戏和玩家
        this.game = this.game || window.sdk.game;

        this.player = this.player || window.sdk.player;

        //设置玩家的title文字
        this.setPlayerTitle();

        //预绑定事件
        //this.preRegListItem(true);

        //绑定或隐藏邀请好友
        this.bindInviteFriendBtn();

        //隐藏/显示本地排行
        if(!(this.isMe() && this.game.id == window.sdk.game.id)){
            $("#localRank").hide();
            this.defaultTab = 'friendRank';
        }

        //查询指定排榜数据
        if(this.leaderBoard){
            this.triggerHighScore(this.leaderBoard);
        //查询排行榜列表，获得默认排行榜
        }else{
            this.action.model['hs'].queryLeaderBoradList(this.game.id);
        }
    },

    /*
     * 判断是否为用户“我”
     */
    isMe: function(){
        return this.player && ( this.player.id == window.sdk.player.id );
    },

    /**
     * 预注册/取消绑定列表事件
     */
    preRegListItem : function(bind){
        var option = bind ? "live" : "die",
            meFn = this.isMe() ? this.bindMyDetail : this.bindPlayerDetail,
            myItem = $(".my-postion .list-item"),
            rankItem = $(".rank-postion .list-item:not(.empty-item)");

        myItem[option](DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        myItem[option](DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        myItem[option]("tap", {context: this}, meFn);

        rankItem[option](DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        rankItem[option](DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        rankItem[option]("tap",{ context: this }, this.bindPlayerDetail);
    },

    /**
     * 设置玩家的排行标题
     */
    setPlayerTitle : function(){
        var rankTitles = this.el.find(".player-rank"),
            title;
        if(!this.isMe()){
            title = $.format(resName.TEXT_DASHBOARD_PLAYERPOSTION, [this.player.nickname] );
        }else{
            title = resName.TEXT_DASHBOARD_MYPOSTION;
        }
        rankTitles.text(title);
    },

    /**
     * 获得当前默认的排行模式,并请求默认排行模式的详细信息
     * @param {Array} boardList 当前游戏的排行列表
     */
    findDefaultBoard : function(boardList){
        //游戏没有排行模式
        if(boardList.length == 0){
            this.el.html("<div class=\"common-error-wrap center-layout\"><h1>" + resName.TEXT_DASHBOARD_EMPTY_MODEL+"</h1></div>");
            return false;
        //多种排行模式
        }else if(boardList.length > 1){
            this.action.setView("BoardCategory",{
                isSub : (this.boardsSub ? true : false),
                game  : this.game,
                player : this.player,
                boardList  : boardList
            }, false /*不重置视图*/, true /*不保存当前视图*/);
        //只有一种排行模式
        }else if(boardList.length == 1){
            this.leaderBoard = boardList[0];
            this.triggerHighScore(boardList[0]);
        }

    },

    /**
     * 查询默认高分榜的基本信息
     */
    triggerHighScore : function(board){

        //记录用户点击事件
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_LEADERBOARD_INDEX,
            {
                'game_id': window.sdk.game.id,
                'leaderboard_id': board.id
            }
        );

        //设置标题
        this.setTitle(board.title);
        this.el.find('.common-tab-wrap').removeClass('hidden'); //hacker
        //默认查询好友高分榜信息
        this.switchTabConent($("#"+this.defaultTab));

        //获取banner广告 SDK成就左,SDK成就右
        this.action.model["prombanner"].queryPromotionBanner(DGC.Ads.getBanners(this.alias));
    },


    /**
     * 获取需要延迟加载的图标信息
     */
    getDelayIcons : function(players){
        var delays = [];

        //delayIcons
        for (var i = 0; i < players.length; i++) {
            var player = players[i].player;
            if(!$.isEmpty(player.avatar_url)){
                delays.push({
                    url: player.avatar_url,
                    id: player.id
                });
            }
        };

        return delays;
    },

    /**
     * 本地排行渲染
     */
    renderLocalRank : function(localRanks){
        //本地排行
        var wrap = $("#localRank-content .rank-postion");
        if(localRanks.length == 0){
            wrap.html(DGC.Common.getEmptyListItemHtml(resName.TEXT_DASHBOARD_EMPTY_LIST));
        }else{
            //渲染Player的排名
            var renderHTML = this.renderByTpl(this.viewTpl.LOCALRANK, localRanks);
            wrap.append(renderHTML);
        }
        //标识已渲染
        this.subRendered.localRank = true;

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_LEADERBOARD_LOCAL);
    },

    /**
     * 好友排行渲染
     * @param {Object} playerRank 玩家排行信息
     * @param {Array} friendsRank 玩家好友的排行信息
     */
    renderFriendRank : function(playerRank, friendsRank){
        var delayIcons = null;

        //如果为我，则使用缓存对象
        if(playerRank.player.id == window.sdk.player.id){
            $.extend(playerRank.player, window.sdk.player);
        }

        //渲染Player的排名
        var renderMe = $(this.renderByTpl(this.viewTpl.PLAYERTPL, playerRank));
        renderMe.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        renderMe.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        renderMe.bind("tap", {context: this}, this.isMe() ? this.bindMyDetail : this.bindPlayerDetail);

        $("#friendRank-content .my-postion").append(renderMe);

        //好友排行
        var wrap = $("#friendRank-content .rank-postion"),
            renderItems;

        if(friendsRank.length == 0){
            wrap.html(DGC.Common.getEmptyListItemHtml(resName.TEXT_DASHBOARD_EMPTY_LIST));
        }else{
            delayIcons = this.getDelayIcons(friendsRank);

            //渲染Player的排名
            renderItems = $(this.renderByTpl(this.viewTpl.RANKTPL, friendsRank));
            renderItems.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
            renderItems.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
            renderItems.bind("tap", {context: this}, this.bindPlayerDetail);
            wrap.prepend(renderItems);

            //延迟加载图标
            if(delayIcons.length > 0 ){
                this.loadImages(delayIcons, function(img, data){
                    var item = $("#friendRank-content .rank-postion div[data-key='" + data.id + "']");
                    item.find(".default-player").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");
                });
            }
        }

        //标识已渲染
        this.subRendered.friendRank = true;

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_LEADERBOARD_FRIENDS);
    },

    /**
     * 区域排行渲染
     * @param {Object} playerRank 玩家排行信息
     * @param {Array} areasRank 玩家最近区域的排行信息
     */
    renderAreaRank : function(playerRank, areasRank){
        var delayIcons = null;

        //如果为我，则使用缓存对象
        if(playerRank.player.id == window.sdk.player.id){
            $.extend(playerRank.player, window.sdk.player);
        }

        //渲染Player的排名、
        var renderMe = $(this.renderByTpl(this.viewTpl.PLAYERTPL, playerRank));
        renderMe.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        renderMe.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        renderMe.bind("tap", {context: this}, this.isMe() ? this.bindMyDetail : this.bindPlayerDetail);

        $("#areaRank-content .my-postion").append(renderMe);

        //区域排行
        var wrap = $("#areaRank-content .rank-postion"),
            renderItems;

        if(areasRank.length == 0){
            wrap.html(DGC.Common.getEmptyListItemHtml(resName.TEXT_DASHBOARD_EMPTY_LIST));
        }else{
            delayIcons = this.getDelayIcons(areasRank);

            //渲染Player的排名
            renderItems = $(this.renderByTpl(this.viewTpl.RANKTPL, areasRank));
            renderItems.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
            renderItems.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
            renderItems.bind("tap", {context: this}, this.bindPlayerDetail);
            wrap.append(renderItems);

            //延迟加载图标
            if(delayIcons.length > 0 ){
                this.loadImages(delayIcons, function(img, data){
                    var item = $("#areaRank-content .rank-postion div[data-key='" + data.id + "']");
                    item.find(".default-player").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");;
                });
            }

        }

        this.subRendered.areaRank = true;

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_LEADERBOARD_NEARBY);

    },

    /**
     * 全球排行渲染
     * @param {Object} playerRank 玩家排行信息
     * @param {Array} worldRank 玩家最近全球排行信息
     */
    renderWorldRank : function(playerRank, worldRank){
        var delayIcons = null;

        //如果为我，则使用缓存对象
        if(playerRank.player.id == window.sdk.player.id){
            $.extend(playerRank.player, window.sdk.player);
        }

        //渲染Player的排名
        var renderMe = $(this.renderByTpl(this.viewTpl.PLAYERTPL, playerRank));
        renderMe.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        renderMe.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        renderMe.bind("tap", {context: this}, this.isMe() ? this.bindMyDetail : this.bindPlayerDetail);
        $("#worldRank-content .my-postion").append(renderMe);

        //全球排行
        var wrap = $("#worldRank-content .rank-postion"),
            renderItems;

        if(worldRank.length == 0){
            wrap.html(DGC.Common.getEmptyListItemHtml(resName.TEXT_DASHBOARD_EMPTY_LIST));
        }else{
            delayIcons = this.getDelayIcons(worldRank);

            //渲染Player的排名
            renderItems = $(this.renderByTpl(this.viewTpl.RANKTPL, worldRank));
            renderItems.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
            renderItems.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
            renderItems.bind("tap", {context: this}, this.bindPlayerDetail);
            wrap.append(renderItems);

            //延迟加载图标
            if(delayIcons.length > 0 ){
                this.loadImages(delayIcons, function(img, data){
                    var item = $("#worldRank-content .rank-postion div[data-key='" + data.id + "']");
                    item.find(".default-player").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");;
                });
            }

        }

        this.subRendered.worldRank = true;

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_LEADERBOARD_GLOBAL);

    },

    /**
     * Tab点击切换事件绑定
     */
    bindRankTabItems : function(){
        var tabs = this.el.find('.common-tab-nav li');
        tabs.bind('tap',{ context : this }, function(event){
            var context = event.data.context,
                el = $(this);
            context.switchTabConent(el);
        });
    },

    /**
     * 切换Tab内容业务逻辑
     */
    switchTabConent: function(el){
        var context = this,
            model  = context.action.model['hs'];

        if(context.currentTab){
            $("#"+context.currentTab).removeClass('tab-active');
            context.getContentEl(context.currentTab).hide();
        }

        el.addClass('tab-active');

        //显示对应的Tab Content内容
        context.getContentEl(el.attr('id')).show();
        context.currentTab = el.attr('id');

        //根据点击TAB发起请求
        switch(context.currentTab){
            case "localRank":
                //记录用户点击事件
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_LEADERBOARD_TYPE,
                    {
                        'game_id':window.sdk.game.id,
                        'type':DGC.Event.Option.LEADERBOARD_LOCAL
                    }
                );

                if(!context.subRendered.localRank){
                    model.queryOfflineRankList(context.leaderBoard.identifier);
                }
                break;
            case "friendRank":

            //记录用户点击事件
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_LEADERBOARD_TYPE,
                    {
                        'game_id':window.sdk.game.id,
                        'type':DGC.Event.Option.LEADERBOARD_FRIENDS
                    }
                );

                if(!context.subRendered.friendRank){
                    model.queryFriendRank(context.leaderBoard.id, context.player.id );
                }
                break;
            case "areaRank":

                //记录用户点击事件
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_LEADERBOARD_TYPE,
                    {
                        'game_id':window.sdk.game.id,
                        'type':DGC.Event.Option.LEADERBOARD_NEARBY
                    }
                );

                if(!context.subRendered.areaRank){
                     model.queryAreaRank(context.leaderBoard.id, context.player.id );
                }
                break;
            case "worldRank":

                //记录用户点击事件
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_LEADERBOARD_TYPE,
                    {
                        'game_id':window.sdk.game.id,
                        'type':DGC.Event.Option.LEADERBOARD_GLOBAL
                    }
                );

                if(!context.subRendered.worldRank){
                    model.queryWorldRank(context.leaderBoard.id, context.player.id );
                }
                break;
        }
    },

    /**
     * 获得Tab内容的元素
     */
    getContentEl : function(tabId){
        return $("#" + tabId + "-content");
    },

    bindMyDetail : function(event){
        var context = event.data.context;

        //记录用户点击事件
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_LEADERBOARD_VIEW_PLAYER,
            {
                'game_id':window.sdk.game.id,
                'user_id':window.sdk.player.id,
                'player_id':window.sdk.player.id,
                'is_myself':true
            }
        );

        //回退恢复用户状态
        $.extend(context.initConfig, {
            defaultTab: context.currentTab
        });

        context.action.setView('MyDetail',{
            isSub: true,
            game: context.game
        });
    },

    bindPlayerDetail  : function(event){
         var context = event.data.context,
             me = $(this),
             id = me.attr("data-key"),
             name = $.trim(me.find('h1.user-name').text());

        //记录用户点击事件
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_LEADERBOARD_VIEW_PLAYER,
            {
                'game_id': window.sdk.game.id,
                'user_id': window.sdk.player.id,
                'player_id': id,
                'is_myself':false
            }
        );

        //回退恢复用户状态
        $.extend(context.initConfig, {
            defaultTab: context.currentTab
        });

        //好友列表：我的排行榜,且点击的好友为自己
        if(context.player.id == window.sdk.player.id && context.player.id == id){
            context.action.setView('MyDetail',{
                isSub: true,
                game: context.game
            });
        //其他人或他的排行榜中点击我
        }else{
            context.action.setView("FriendsDetail",{
                playerId: id,
                title: name
            });
        }
    },

    /**
     * 绑定邀请好友按钮事件
     */
    bindInviteFriendBtn: function(){
        var button = $("#invite-btn");
        if(this.isMe()){
            button.bind(DGC.Common.E_TAP_DOWN,function(){
                $(this).addClass('active');
            });

            button.bind(DGC.Common.E_TAP_UP,function(){
                $(this).removeClass('active');
            });

            button.bind('tap',{context: this}, this.showInviteFriend);
        }else{
            button.parent(".common-list-btn-wrap").remove();
        }
    },

    /**
     * 分享按钮
     */
    showInviteFriend : function(event){
        var context = event.data.context;

        //记录用户点击事件
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_LEADERBOARD_INVITE_FRIENDS,
            {
                'game_id':window.sdk.game.id,
                'user_id':window.sdk.player.id
            }
        );

        //弹出分享窗口
        context.action.showDialog(
            "ShareGame",
            {
                meModel: context.action.model['me'],
                notBindCallback : $.bindFn(context.bindAccount, context) //没有sns绑定帐号执行
            },
            function(name, params){
                //弹出绑定的Dialog
                this.shareWin = new DGC.Dialog[name](params);
                this.shareWin.show();
            },
            context
        );
    },

     /**
     * 模板内容Ready
     */
    contentReadyProxy: function(content){
        if(this.shareWin){
            this.shareWin.contentReady(content);
        }
    },

    /**
     * 发送SNS成功
     */
    sendSNSSuccessProxy: function(type,result){
        if(this.shareWin){
            this.shareWin.sendSNSSuccess(type,result);
        }
    },

    /**
     * 视图销毁时，移除事件监听
     */
    onDestory : function(){
        this.preRegListItem(false);
        if(this.shareWin){
            this.shareWin.destory();
            this.shareWin = null;
        }
        if(this.renren){
            this.renren.destory();
            this.renren = null;
        }
        if(this.sina){
            this.sina.destory();
            this.sina = null;
        }
    },

    /**
     * 预加载广告图片信息
     */
    loadAds: function(banners){
        var context = this,
            keys = [];

        //待加载的 Ads
        context.waitLoadAds = {};

        for(var i = 0; i < banners.length; i++){
            var banner = banners[i],
                selectAd = DGC.Ads.getBannerShowAd(banner.ads); //获得要渲染广告

            //需要请求的广告
            var requestAd = $.extend(selectAd,{
                "bid": banner["_id"], //广告位ID
                "url": selectAd.img_url //请求图片
            });

            //缓存广告信息
            context.waitLoadAds[requestAd.bid] = {
                status: false,
                data: requestAd
            }

            //FAKE对象
            keys.push(requestAd);
        }

        //预加载广告位图片
        context.loadImages(keys, function(img, data){
            context.waitLoadAds[data.bid].status = true; //广告位图片加载完毕
            //this.loadAds[pid].img = img; //缓存图片对象

            context.sycPageAds(); //同步检查所有广告位是否加载成功
        });
    },

    /**
     * 同步检查广告加载
     */
    sycPageAds: function(){
        for( var key in this.waitLoadAds){
            var ad = this.waitLoadAds[key];
            if(!ad.status){
                return false; //尚未完成加载
            }
        }

        //加载完毕,渲染全部广告
        this.renderPromotionBanner();
    },

    /**
     * 渲染页面广告
     */
    renderPromotionBanner: function(){
         var PAGE_BID = DGC.Ads.PAGES[this.alias],
             loadedAds = this.waitLoadAds,
             tplObj = {
                leftAd: loadedAds[PAGE_BID.LEFT].data, //左边广告
                rightAd: loadedAds[PAGE_BID.RIGHT].data, //右边广告
             },
             bannerModel = this.action.model['prombanner'];


        var renderBanner = $(this.renderByTpl(DGC.Ads.getSidesAdTpl(), tplObj));
        //点击触发
        renderBanner.find("a").bind("tap", {context : this}, function(event){
            var context = event.data.context;
                me = $(this),
                bid = me.parent(".ad-wrap").attr('data-key'),
                adObj = context.waitLoadAds[bid].data;
            switch(adObj.ad_type){
                case 1 /*APK*/:
                    DGC.ActionUtil.getGameState([adObj.package_name]);
                    context.cacheClickAd = adObj /*缓存点击广对象*/;
                    break;
                case 2 /*网页*/:
                    DGC.ActionUtil.openBrowser(adObj.ad_url);
                    break;
            }
        });
        this.el.prepend(renderBanner);

        //统计广告位中显示次数
        setTimeout(function(){
            bannerModel.promotionBannerCount(tplObj.leftAd.id, tplObj.leftAd.bid);
            bannerModel.promotionBannerCount(tplObj.rightAd.id, tplObj.rightAd.bid);
            renderBanner.fadeIn('slow');
        },0);

    },
    /**
     * 下载或启动游戏APK
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            bannerModel = this.action.model["prombanner"];

        if(this.cacheClickAd){
            if(status) {
                bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheClickAd.bid, 1/*运行*/ );//记录广告点击
                DGC.ActionUtil.startGame(this.cacheClickAd.package_name);//启动游戏
            } else {
               bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheClickAd.bid, 0 /*下载*/);//记录广告点击
               DGC.ActionUtil.download(this.cacheClickAd.ad_url);//下载游戏
            }
            this.cacheClickAd = null;
        }
    },

    /**
     * 绑定sns帐号
     */
    bindAccount: function(type){
        var ATTR = DH.ATTR;
        DGC.ActionUtil.log("account type :" + type);
        if (type == ATTR.BIND_SNS.SINA){
            this.action.showDialog(
                    "SinaDialog",
                    {
                        meModel: this.action.model['me'],
                    },
                    function(name, params){
                        //弹出绑定的Dialog
                        this.sina = new DGC.Dialog[name](params);
                        this.sina.show();
                    },
                    this);
        } else if (type == ATTR.BIND_SNS.RENREN){
            this.action.showDialog(
                    "RenRenLoginDialog",
                    {
                        meModel: this.action.model['me'],
                    },
                    function(name, params){
                        //弹出绑定的Dialog
                        this.renren = new DGC.Dialog[name](params);
                        this.renren.show();
                    },
                    this);
        }

    }
});
