/**
 * 开发者点击购买进入支付
 * 注明：this.action.model['pay'].queryPlayerCoinsAndSupport();  待替换为queryCoins
 */
DGC.View.DeveloperPay =  $.inherits(DGC.View, {

    baseId: 'nativepay-view',

    /**
     * 页面无内容
     */
    isDeferRender: false,

    /**
     * 剩余乐币
     */
    playerCoins: undefined,

    /**
     * 是否支持乐币
     */
    enableCoins: undefined,

    /**
     * 道具信息
     */
    orderInfo: undefined,

    /**
     * SDK冗余字段
     */
    identify : undefined,

    viewReady: function(){
        DGC.ActionUtil.fullScreen(true);

        //显示窗口需要的数据源
        this.requestAPI = {
            orderReady: false //道具信息
        };


        //支持乐币支付，非离线模式则显示当前余额 ，不显示Loading
        if(window.sdk.channel.enable_coin_payment && !window.sdk.isOffline){
            $.extend(this.requestAPI, { coinsReady:false });
            this.action.model['pay'].queryPlayerCoins(false);
        }

        //非离线模式，查询积分信息
        if(!window.sdk.isOffline && DH.isSupportIntegral()){
            $.extend(this.requestAPI, { integralReady:false });
            DGC.ActionUtil.getIntegral();
        }

        this.action.model['pay'].queryBuyItemDetail(this.identify);
    },

    /**
     * 支付方式详情(暂时支持积分)
     */
    cachePaymentDetail: function(payment){
        //二次通知，则只缓存积分,不做页面操作
        if(this.cacheIntegral){
            this.cacheIntegral = payment;
            return false;
        }

        this.cacheIntegral = payment; //缓存当前积分支付详情
        $.extend(this.requestAPI, { integralReady: true });
        this.directToBuy();
    },

    /**
     * 保存用户剩余乐币数
     * @param {Number} coins 乐币数
     * @param {Boolean} enable 是否支持乐币
     */
    cachePlayerCoins: function(coins){
        //乐币数
        this.playerCoins = window.sdk.player.coins = coins;
        $.extend(this.requestAPI, { coinsReady:true });

        this.directToBuy();
    },

    /**
     * 记录需要支付的道具信息
     */
    recordPrudctInfo: function(productInfo){
        this.orderInfo = productInfo;
        $.extend(this.requestAPI, { orderReady: true });

        this.directToBuy();
    },

    /**
     * 判断所有请求是否都已经响应
     */
    isAPIReady : function(){
        for(var key in this.requestAPI){
            if(!this.requestAPI[key]){
                return false;
            }
        }
        return true;
    },

    /**
     * 判断根据乐币和道具信息支付方式
     */
    directToBuy: function(){
        //未加载完成，无需判断
        if(!this.isAPIReady()){
            return false;
        }

        var product = this.orderInfo.item.product,
            ownCount = this.orderInfo.item.itemcount,
            quantity = this.orderInfo.quantity || 1 /*默认开发者入口只能购买一个道具*/,
            DAU = DGC.ActionUtil,
            context = this;

        //防止开发者不给数量值
        $.extend(this.orderInfo, { "quantity": quantity } );

        //激活类/订阅类拥有后不能再购买,消费类判断max上限值
        switch(product.type){
            case 0 /*激活类*/:
            case 2 /*订阅类*/:
                if(ownCount > 0){
                    DAU.showTipMsg(resName.TIP_DEVELOPBUY_ADREADY_BUYED);
                    //提示已经拥有该道具
                    DAU.returnToGame();
                    return false;
                }
                break;
            case 1 /*消费类*/:
                //达到购买上限值
                /*
                if(product.maxperplayer != 0 && ownCount == product.maxperplayer){
                    DAU.showTipMsg(resName.TIP_DEVELOPBUY_ADREADY_BUYED_MAX);
                    DAU.returnToGame(); //返回游戏
                    return false;
                }*/
                break;
        }

        //弹出绑定的Dialog
        context.action.showDialog(
            "ShopDetail",
            {
                orderItem: this.orderInfo.item,
                callback : function(result, isIntegral) {
                    //用户点击确认后，下单
                    if(result){
                        if(isIntegral){
                            context.buyByIntegral(); //积分
                        }else{
                            //乐逗，第三方支付方式
                            context.buyAction();
                        }
                    }else{
                        //返回游戏
                        DAU.returnToGame();
                    }
                },
                integral: context.cacheIntegral, //积分
                integralAction: false, //积分不足，进入赚取积分页面，不关闭当前窗口
                parentView : context //依赖View 图片延时加载接口
            },
            function(name, params){
                var buyDialog = new DGC.Dialog[name](params);
                buyDialog.show();
            },
            context);
    },

     /**
     * 积分购买道具
     */
    buyByIntegral: function(){
        var product = this.orderInfo.item.product;
        this.action.model['pay'].payOrderByIntegral({
            product_id: product.id,
            quantity: this.orderInfo.quantity,
            paymethod : this.cacheIntegral.identifier
        }, this.orderInfo.item);
    },

    /**
     * 购买道具逻辑
     */
    buyAction: function(){
        var product = this.orderInfo.item.product;

        //道具列表
        if(window.sdk.isOffline){
            this.action.setView("OfflineCharge",{
                orderInfo: this.orderInfo
            }, false /*不重置视图*/, true /*不保存当前视图*/);
        }else {
            //启用乐币支付且乐币足够
            if(window.sdk.channel.enable_coin_payment && this.playerCoins >= (product.price * this.orderInfo.quantity)/*总价*/){
                this.action.model['pay'].payOrderByLeDou({
                    product_id: product.id,
                    quantity: this.orderInfo.quantity
                }, this.orderInfo.item);
            }else{
                //进入支付列表
                this.action.setView("ChargeAccount",{
                    chargeModel: 1 /*开发者界面进入支付列表*/,
                    orderInfo: this.orderInfo
                }, false /*不重置视图*/, true /*不保存当前视图*/);
            }
        }
    },

    /**
     * 通知SDK更新游戏道具信息
     * @param {Object} payResult 支付结果
     * @param {Object} detail 支付结果详情
     * @param {Object} failitem 支付失败的item对象
     * */
    showLedouPayResult : function(result, detail , failitem ){
        var DAU = DGC.ActionUtil;
        if(result){
            DAU.showTipMsg($.format(resName.TIP_LEDOUSHOP_LEDOU_BUY_SUCCESS,[detail.product.name, detail.amount]));
            //无论是否购买成功，都通知SDK
            DAU.notifySDKBuyResult( 0 /*乐币方式购买*/, result, detail);
        }else{
            this.action.model['pay'].showPayErrorDetail(detail);
            //通知SDK支付操作失败
            DAU.notifySDKBuyResult(0 /*乐币方式购买*/, result, failitem, detail.err_code);
        }

        //返回游戏
        DAU.returnToGame();
    },

    /**
     * 积分购买通知SDK更新游戏道具信息(同乐逗购买)
     */
    showIntegralPayResult : function(result, detail , failitem){
        var DAU = DGC.ActionUtil;
        if(result){
            DAU.showTipMsg($.format(resName.TIP_DEVELOPERPAY_INTEGRALPAY_SUCCESS,[detail.product.name, detail.discount_amount]));
            //无论是否购买成功，都通知SDK
            DAU.notifySDKBuyResult( 6 /*积分方式购买*/, result, detail);
        }else{
            this.action.model['pay'].showPayErrorDetail(detail);
            //通知SDK支付操作失败,需要将购买对象item传递给SDK
            DAU.notifySDKBuyResult( 6 /*积分方式购买*/, result, failitem, detail.err_code);
        }

        //返回游戏
        DAU.returnToGame();
    },


    /**
     * 当该页面请求超时，点击确认，直接返回游戏
     */
    returnToGameAction: function(){
        //返回游戏
        DGC.ActionUtil.returnToGame();
    }

});