/**
 * 好友的详情视图
 */
DGC.View.FriendsDetail =  $.inherits(DGC.View, {

    baseId : 'friendsDetail-view',

    /**
     * 标题文字
     * @type Boolean
     */
    title : false,

    /**
     * 视图静态模版
     * @type String
     */
    renderTpl : "1.2.0/js/template/friendsdetail.html",

    /**
     * 构造参数
     */
    playerId : undefined,


    player : undefined,

    /**
     * 玩家关注状态 true:建立 false:取消
     */
    isFriend : undefined,

    /**
     * 视图初始化函数
     */
    viewReady: function(){
        //查询玩家详细信息
        this.action.model['me'].queryPlayerDetail(this.playerId);

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_PLAYER_HOME);

    },

    /*
     * 设置界面上好友信息
     * @param player {Object} Player对象
     * @param friendsship {Object} 关系对象
     */
    renderPlayerDetail: function(player, friendsship){
        //缓存player信息
        this.player = player;

        //判断用户头像是否缺省头像
        var headerImg = $("#fd-player-icon");
        //自定义头像
        if(this.player.avatar_url != "" && this.player.avatar_url.length > 0 ){
            headerImg.attr({
                src:this.player.avatar_url
            });
        }else{
            //显示缺省头像
            headerImg.parent(".head-portrait").html('<div class="head-default"></div>');
        }

        $("#fd-name").text(this.player.nickname);
        $("#fd-level").text(this.player.level);
        $("#fd-coins").text(this.player.coins);
        $("#fd-friends-text").text($.format(resName.TEXT_DETAIL_FRIENDS_NUM,
                [this.player.total_friends]));
        $("#fd-playedgames").text($.format(resName.TEXT_ME_DETAIL_GAMES_NUM,
                [this.player.total_games]));

        //设置绑定菜单项
        this.bindDetailMemu();


        var btn = $("#fd-focus-btn");

        //如果TA的好友为玩家自己，则隐藏关注按钮
        if(window.sdk.player.id != this.player.id){
            //样式切换
            btn.bind(DGC.Common.E_TAP_DOWN,function(e){
                $(this).addClass('active');
            });
            btn.bind(DGC.Common.E_TAP_UP,function(e){
                $(this).removeClass('active');
            });
            btn.bind('tap', {context: this}, this.changeFriendsshipStatus);

            //设置关注状态
            this.updateFriendsship(friendsship.is_friend);

            //显示关注按钮
            btn.parent('.common-list-btn-wrap').removeClass('hidden');

            if(!$.isEmpty(this.player.last_game)){
                $("#fd-lastgame h1").text($.format(resName.TEXT_PLAYER_DETAIL_LASTGAME,[this.player.last_game]));
            }else{
                $("#fd-lastgame h1").text(resName.TEXT_PLAYER_DETAIL_LASTGAME_NONE);
            }
        }else{
            $("#fd-lastgame h1").text($.format(resName.TEXT_PLAYER_DETAIL_LASTGAME,[window.sdk.game_name]));
        }

    },


    /**
     * 绑定菜单事件
     */
    bindDetailMemu: function(){

        //除最后一行关注按钮
        var memuItems = this.el.find('.list-item:not(.list-item:last-child)'),
            CM = DGC.Common;
        memuItems.bind(DGC.Common.E_TAP_DOWN, CM.listTapDownHandler);
        memuItems.bind(DGC.Common.E_TAP_UP, CM.listTapEndHandler);

        //好友的好友列表
        $('#view-f2f').bind('tap',{context:this},function(event){
            var context = event.data.context;

            //“玩家主页”界面，点击 “TA 的好友”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_PLAYER_FRIENDS,
                {
                    'user_id':window.sdk.player.id,
                    'player_id':context.playerId
                }
            );

            context.action.setView('FriendsToFriends',{
                title : $.format(resName.A_TITLE_F2F_FRIENDS,[context.title]),
                playerId: context.player.id
            });
        });

        //好友玩过的游戏
        $('#view-friend-game').bind('tap',{context:this},function(event){
            var context = event.data.context;

            //“玩家主页”界面，点击 “TA 玩过的游戏”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_PLAYER_GAMES,
                {
                    'user_id':window.sdk.player.id,
                    'player_id':context.playerId
                }
            );

            context.action.setView('PlayedGames',{
                player: context.player
            });
        });
    },

    /**
     * 切换关注好友状态
     */
    changeFriendsshipStatus : function(event){
        var context = event.data.context;

        //“玩家主页”界面，点击 “关注TA”/“取消关注”
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_PLAYER_FOLLOW,
            {
                'user_id':window.sdk.player.id,
                'player_id':context.playerId,
                'action_type': (context.isFriend ?  DGC.Event.Option.UNFOLLOW : DGC.Event.Option.FOLLOW )
            }
        );

        fnName =  context.isFriend ? "updateDestoryFriendsShip" : "updateCreateFriendsShip";
        context.action.model['me'][fnName](context.player.id);
    },

    /**
     * 更新当前玩家状态
     */
    updateFriendsship: function(shipStatus){

        this.isFriend = shipStatus;

        var btn = $("#fd-focus-btn");
        if(this.isFriend){
            btn.text(resName.TEXT_ME_DETAIL_FOCUS_CANCEL);
            btn.removeClass('blue-btn').addClass('silver-btn');
        }else{
            btn.text(resName.TEXT_ME_DETAIL_FOCUS_FRIEND);
            btn.removeClass('silver-btn').addClass('blue-btn');
        }
    }

});
