/**
 * 用户玩过的游戏基本信息
 */
DGC.View.GameInfo =  $.inherits(DGC.View, {

    baseId: 'game-info-view',

    title: false,

    renderTpl:'1.2.0/js/template/gameinfo.html',

    player: undefined,

    gameId: undefined,

    /**
     * 视图初始化函数
     */
    viewReady: function(){
        //设置排行描述
        var descEl = $("#gi-board-desc");
        if(this.isMe()){
            descEl.text(resName.TEXT_GAMEINFO_BOARD_D);
        }else{
            descEl.text($.format(resName.TEXT_GAMEINFO_BOARD_D_FRIENDS,[ this.player.nickname ]));
        }

        this.action.model['me'].queryPlayerRecords(this.player.id, this.gameId);
        this.prevBindEvents(true);

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_GAME_HOME);

    },

    prevBindEvents: function(bindState){
        var method = bindState ? 'live' : 'die',
            boardEl = $("#gi-game-board"),
            achieveEl = $("#gi-game-achieve");
        boardEl[method](DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        boardEl[method](DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        boardEl[method]("tap", {context:this} , this.showGameBoard );

        achieveEl[method](DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        achieveEl[method](DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        achieveEl[method]("tap", {context:this} , this.showGameAchieve );
    },

    /*
     * 判断是否为用户“我”
     */
    isMe: function(){
        return this.player && ( this.player.id == window.sdk.player.id );
    },

    /**
     * 渲染玩家在游戏中的信息
     */
    renderRecordInfo : function(record){
        $("#gi-name").text(record.data.name);
        $("#gi-desc").text(record.data.description);
        $("#gi-achieve").text($.format(resName.TEXT_GAMEINFO_ACHIEVE_D, [record.achivement_count]));

        //缓存Game对象
        this.game = record.data;

        //游戏图标延迟加载
        if(!$.isEmpty(record.data.icon_url)){
            this.loadImages({url:record.data.icon_url},function(img,data){
                var imgWrap  = $(".game-title .icon-wrap .icon-70");
                imgWrap.find(".default-icon").replaceWith("<img src='"+ img.src + "'></img><div class='mask'></div>");
            });
        }

        //本机游戏，不查询相关状态
        if(window.sdk.package_name != record.data.bundle_id){
            DGC.ActionUtil.getGameState([record.data.bundle_id]);
        }
    },

    /**
     * 显示当前游戏的状态
     */
    showGameStatus : function(result){
        var status = result.data.states[0],
            btnEl = $("#game-status");

        btnEl.bind(DGC.Common.E_TAP_DOWN,function(){$(this).addClass('active')})
           .bind(DGC.Common.E_TAP_UP,function(){$(this).removeClass('active')});

        //游戏状态
        if(status){
            btnEl.text(resName.BUTTON_GAMEINFO_PLAY);
            btnEl.bind("tap", { context: this } ,function(event){
                var context = event.data.context;

                //某一款游戏主界面，点击玩游戏
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_GAME_HOME_PLAY,
                    {
                        'game_id': context.game.id,
                    }
                );

                //启动游戏
                DGC.ActionUtil.startGame(context.game.bundle_id);
            });
            btnEl.show();
        }else{
            //允许配置下载
            if(this.game.enable_download){
                btnEl.html("<a href='" + this.game.download_url + "'>" + resName.BUTTON_GAMEINFO_SETUP + "</a>");
                btnEl.bind("tap", { context: this } , function(event){
                    var context = event.data.context;

                    //某一款游戏主界面，点击下载安装游戏
                    DGC.ActionUtil.recordUserAction(
                        DGC.Event.EventId.EVENT_GAME_HOME_DOWNLOAD,
                        {
                            'game_id': context.game.id,
                        }
                    );

                });
                btnEl.show();
            }
        }

    },

     /**
     * 显示指定用户在某游戏中的排行信息
     */
    showGameBoard: function(event){
        var context = event.data.context;

        //记录点：某一款游戏主界面，点击排行榜
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_GAME_HOME_LEADERBOARD,
            {
                'game_id':context.gameId
            }
        );

        context.action.setView('Dashboard',{
            isSub: true,
            boardsSub: true,
            game : context.game,
            player : context.player
        });
    },

    /**
     * 显示指定用户在某游戏中的成就信息
     */
    showGameAchieve: function(event){
        var context  = event.data.context;

        //记录点：某一款游戏主界面，点击成就
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_GAME_HOME_ACHIEVEMENT,
            {
                'game_id':context.gameId
            }
        );

        context.action.setView('UserAchieve',{
            isSub: true,
            game : context.game,
            player : context.player
        });
    },

    onDestory: function(){
        this.prevBindEvents(false);
    }
});
