/**
 * 乐逗商城
 */
DGC.View.LeDouShop = $.inherits(DGC.View, {

    baseId : 'ledou-shop',

    /**
     * 根视图
     */
    isSub: false,

    title : 'A_TITLE_LEDOU_SHOP',

    renderTpl : '1.2.0/js/template/ledoushop.html',

    /**
     * 缓存道具列表
     */
    cacheItems : undefined,

    /**
     * 缓存当前积分详情信息
     */
    cacheIntegral : undefined,

    /**
     * 用户剩余乐币
     */
    playerCoins: undefined,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        this.viewTpl = {
            ITEM:"#ls-item-tpl",
            COINS:"#player-coins-tpl"
        }

        //隐藏Tab
        DGC.ActionUtil.hideBottomBar(false);

        //查询道具信息
        this.action.model['pay'].queryShopItems();

        //支持乐币支付，非离线模式则显示当前余额 ，不显示Loading
        if(window.sdk.channel.enable_coin_payment && !window.sdk.isOffline){
            this.action.model['pay'].queryPlayerCoins(false);
            this.coinsReady = false; //Lock
        }

        //非离线模式，查询积分信息
        if(!window.sdk.isOffline && DH.isSupportIntegral()){
            DGC.ActionUtil.getIntegral();
        }

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_MALL);
    },

    /**
     * 道具信息Ready
     */
    itemsReady : function(items){
        //缓存道具信息
        this.cacheItems = this.cacheItems || items;

        if(this.hasOwnProperty('coinsReady')){
            if(this.coinsReady){
                this.renderShopItems();
            }
        }else{
            this.renderShopItems();
        }
    },

    /**
     * 支付方式详情(暂时支持积分)
     */
    cachePaymentDetail: function(payment){
        //二次通知，则只缓存积分,不做页面操作
        if(this.cacheIntegral){
            this.cacheIntegral = payment;
            return false;
        }

        //显示按钮
        this.el.find('.getintegral-wrap').show();
        this.cacheIntegral = payment; //缓存当前积分支付详情

        this.el.find('#getintegral-btn').bind('tap', function(event) {

            //记录点：“乐逗商城”界面，点击“赚取积分”
            DGC.ActionUtil.recordUserAction(DGC.Event.EventId.EVENT_MALL_EARN_POINTS,{
                'user_id': (window.sdk.player ?  window.sdk.player.id : null ) ,
                'game_id': (window.sdk.game ?  window.sdk.game.id : null )
            });

            DGC.ActionUtil.showIntegralView(window.sdk.integralWall.type, false);
        });

    },

    /**
     * 渲染道具列表
     */
    renderShopItems: function(){
        var listWrap = this.el.find(".shop-list"),
            DC = DGC.Common,
            items = this.cacheItems;

        //不存在道具信息
        if(items.length == 0){
            listWrap.html(DC.getEmptyListItemHtml(resName.TEXT_LEDOUSHOP_NOT_HAS));
            return false;
        }

        //渲染列表
        for (var i = 0; i < items.length; i++) {
            var daoju = items[i];
            $.extend(daoju, { expiredateText: DC.getFormatDate( DC.getDateFromTime(daoju.expiredate), true) });
        };

        var itemsEls = $(this.renderByTpl(this.viewTpl.ITEM, items));


        //移除渲染字段
        for(i = 0; i < items.length ; i++ ){
            delete items[i].expiredateText;
        }

        //显示详细信息
        itemsEls.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        itemsEls.bind(DGC.Common.E_TAP_UP, DGC.Common.listTapEndHandler);
        itemsEls.bind('tap',{context : this }, this.buyItem);

        listWrap.append(itemsEls);

        //延迟加载
        this.loadImages(this.getDelayIcons(items),function(img, data){
            var imgWrap  = $(".list-item[data-key='"+ data.id +"']");
            imgWrap.find(".default-icon").replaceWith("<img src='"+ img.src + "'></img><div class='mask'></div>");
        });
    },


    /*
     * 获取需要延迟加载的图标信息
     */
    getDelayIcons : function(items){
        var delays = [];

        //delayIcons
        for (var i = 0; i < items.length; i++) {
            var item = items[i];
            if(!$.isEmpty(item.product.icon)){
                delays.push({
                    url: item.product.icon,
                    id: item.product.id
                });
            }
        };

        return delays;
    },


    /**
     * 渲染用户余额用户剩余乐币数
     * @param {Number} coins 乐币数
     */
    cachePlayerCoins: function(coins){
        //乐币数
        this.playerCoins = window.sdk.player.coins = coins;

        this.el.prepend($(this.renderByTpl(this.viewTpl.COINS, {
            name: window.sdk.player.nickname,
            avatar_url: window.sdk.player.avatar_url,
            coins: this.playerCoins
        })));

        this.coinsReady = true;

        //道具数据已经OK
        if(this.cacheItems){
            this.itemsReady();
        }
    },

    /**
     * 点击购买道具
     */
    buyItem: function(event){
        var context = event.data.context,
            key = $(this).attr("data-key"),
            findItem;

        //查找点击道具
        for (var i = 0; i < context.cacheItems.length; i++) {
           var findItem = context.cacheItems[i];
           if(findItem.product.id == key) break;
        };

         //“乐逗商城”界面，点击 任意道具“购买”
        DGC.ActionUtil.recordUserAction(DGC.Event.EventId.EVENT_MALL_PURCHASE,{
            'user_id': (window.sdk.player ?  window.sdk.player.id : null ) ,
            'game_id': (window.sdk.game ?  window.sdk.game.id : null ),
            'product_id': findItem.product.identifier
        });


        //确认购买窗口
        context.action.showDialog(
            "ShopDetail",
            {
                orderItem: findItem,
                disableAction : (findItem.itemcount > 0 && findItem.product.type != 1) /*非消费类仅支持购买一个*/,
                callback : function(result, isIntegral) {
                    //用户点击确认后，下单
                    if(result){
                        //积分购买
                        if(isIntegral){
                            context.buyItemsByIntegral(findItem, 1);
                        }else{
                            context.buyItemsAction(findItem, 1);
                        }
                    }
                },
                integral: context.cacheIntegral, //积分
                parentView : context //依赖View 图片延时加载接口
            },
            function(name, params){
                //弹出绑定的Dialog
                var buyDialog = new DGC.Dialog[name](params);
                buyDialog.show();
            },
            context);
    },

    /**
     * 积分购买道具
     * @param {Object} item 道具信息
     * @param {Number} number 购买数量
     */
    buyItemsByIntegral: function(item, number){
        this.action.model['pay'].payOrderByIntegral({
            product_id: item.product.id,
            quantity: number,
            paymethod : this.cacheIntegral.identifier
        }, item);
    },

    /**
     * 判断当前购买操作由乐币购买还是第三方支付
     * @param {Object} item 道具信息
     * @param {Number} number 购买数量
     */
    buyItemsAction: function(item , number){
        //离线模式只支持短代支付
        if(window.sdk.isOffline){
            this.action.setView("OfflineCharge", {
                orderInfo: {
                    "quantity": number,
                    "item": item
                }
            });
        }else{
            //启用乐币支付且乐币足够
            if(window.sdk.channel.enable_coin_payment && this.playerCoins >= (item.product.price * number)/*总价 道具单价*数量*/){
                this.action.model['pay'].payOrderByLeDou({
                        product_id: item.product.id,
                        quantity: number
                }, item);
            }else{
                //进入支付列表
                this.action.setView("ChargeAccount",{
                    chargeModel: 2 /*商城进入支付列表*/,
                    orderInfo: {
                        "quantity": number,
                        "item": item
                    }
                });
            }
        }
    },

    /**
     * 乐逗购买通知SDK更新游戏道具信息
     * @param {Object} payResult 支付结果
     * @param {Object} detail 支付结果详情
     * @param {Object} failitem 支付失败的item对象
     * */
    showLedouPayResult : function(result, detail , failitem ){
        var DAU = DGC.ActionUtil;
        if(result){
            DAU.showTipMsg($.format(resName.TIP_LEDOUSHOP_LEDOU_BUY_SUCCESS,[detail.product.name, detail.amount]));
            //无论是否购买成功，都通知SDK
            DAU.notifySDKBuyResult( 0 /*乐币方式购买*/, result, detail);
        }else{
            this.action.model['pay'].showPayErrorDetail(detail);
            //通知SDK支付操作失败,需要将购买对象item传递给SDK
            DAU.notifySDKBuyResult(0 /*乐币方式购买*/, result, failitem, detail.err_code);
        }

        //返回游戏
        DAU.returnToGame();
    },

    /**
     * 积分购买通知SDK更新游戏道具信息(同乐逗购买)
     */
    showIntegralPayResult : function(result, detail , failitem){
        var DAU = DGC.ActionUtil;
        if(result){
            DAU.showTipMsg($.format(resName.TIP_LEDOUSHOP_INTEGRALPAY_SUCCESS,[detail.product.name, detail.discount_amount]));
            //无论是否购买成功，都通知SDK
            DAU.notifySDKBuyResult( 6 /*积分方式购买*/, result, detail);
        }else{
            this.action.model['pay'].showPayErrorDetail(detail);
            //通知SDK支付操作失败,需要将购买对象item传递给SDK
            DAU.notifySDKBuyResult( 6 /*积分方式购买*/, result, failitem, detail.err_code);
        }

        //返回游戏
        DAU.returnToGame();
    },

    /**
     * 当该页面请求超时，点击确认，直接返回游戏
     */
    returnToGameAction: function(){
        //返回游戏
        DGC.ActionUtil.returnToGame();
    }

});