/**
 * 本地游戏信息
 */
DGC.View.LocalGames =  $.inherits(DGC.View, {

    baseId : 'localgames-view',


    /**
     * 别名
     */
    alias: 'LocalGames',

    /**
     * 根视图
     */
    isSub: false,

    /**
     * 标题文字
     * @type Boolean
     */
    title : 'A_TITLE_GAMES',

    /**
     * 视图静态模版
     * @type String
     */
    renderTpl : "1.2.0/js/template/localgames.html",

    /**
     * 数据存储
     * @type String
     */
    temData : null,


    adScrollTask: 0,

    /**
     * 视图初始化函数
     */
    viewReady: function(){
        this.viewTpl = {
            GAME:'#lg-game-tpl'
        }

        this.action.model['game'].queryLocalGameList();

        //SDK游戏广告
        this.action.model["prombanner"].queryPromotionBanner(DGC.Ads.getBanners(this.alias));

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_GAMES);

    },

    //渲染localgame页面
    findLocalGame : function(gameList){

        //过滤包名为空的数据
        for(var i= gameList.length - 1; i >= 0; i--){
            var game = gameList[i];
            if( game['bundle_id'] == null || game['bundle_id'] == ''){
                gameList.splice(i,1);
            }
        }

        this.temData = gameList;

        var params = new Array();
        for(var key in gameList){
            var game = gameList[key];
            params.push(game.bundle_id);
        }
        //获取本地游戏状态
        DGC.ActionUtil.getGameState(params);
    },

    //加上游戏状态一起渲染
    findLocalGameState : function(gameListState){
        //图标请求队列
        this.imgQueen = [];

        var gameList = this.temData;
        for(var key in gameList){
            var game = gameList[key];
            $.extend(game, {player_count_text: $.format(resName.TEXT_PLAYGAMES_PALYER_COUNT,[game.player_count])});
            $.extend(game, {state: gameListState.data.states[key]});
            var weizhi = game.icon_url.lastIndexOf("/");
            var url = game.icon_url.substr(0,weizhi);
            var png = game.icon_url.substr(weizhi);
            var grays_icon_url = url+"/grays"+png;
            $.extend(game,{grays_icon_url:grays_icon_url});
            if(gameListState.data.states[key]){
                var state_text = resName.TEXT_LOCALGAMES_PLAYGAME;
            }else{
                var state_text = resName.TEXT_LOCALGAMES_DOWNLOAD;
            }
            $.extend(game,{state_text:state_text});

            //加载游戏ICON
            if(game.hasOwnProperty("enable_download") && !game.enable_download && !game.state){
                var disable = false; /*disable禁止下载*/
                this.imgQueen.push({
                    id: game.id,
                    url: game.grays_icon_url
                });
            }else{
                var disable = true;  /*disable允许下载*/
                this.imgQueen.push({
                    id: game.id,
                    url: game.icon_url
                });
            }
            $.extend(game,{disable:disable});
        }

        //渲染Game
        var items = $(this.renderByTpl(this.viewTpl.GAME, gameList));
        items.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        items.bind(DGC.Common.E_TAP_UP, DGC.Common.listTapEndHandler);
        //玩游戏
        items.filter('.play').bind('tap',function(){

            var id = $(this).attr('data-id'),
                game_name = $(this).attr('data-game-name'),
                bundle_id = $(this).attr('data-name');

            //正在玩的游戏，不能启动
            if(window.sdk.package_name == bundle_id ){
                return false;
            }

            //记录用户点击事件、玩游戏
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_GAMES_PLAY,
                {
                    'game_id':window.sdk.game.id,
                    'user_id':window.sdk.player.id,
                    'target_game_id':id,
                    'target_game_name':game_name
                }
            );


            DGC.ActionUtil.startGame(bundle_id);
        });

        items.filter('.download').bind('tap',function(){

            var id = $(this).attr('data-id');
            var game_name = $(this).attr('data-game-name');
            var href = $(this).attr('href');

            //记录用户点击事件、下载游戏
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_GAMES_DOWNLOAD,
                {
                    'game_id':window.sdk.game.id,
                    'user_id':window.sdk.player.id,
                    'target_game_id':id,
                    'target_game_name':game_name,
                    'target_game_url':href
                }
            );

        });

        $(".total-games-bar").html($.format(resName.TITLE_LOCALGAMES_GAMES_TOATAL,[gameList.length]));
        $(".localgames-list").append(items);

        setTimeout($.bindFn(this.loaderGameIconDelay, this ), 500);
    },

    /**
     * 延迟加载游戏图标
     */
    loaderGameIconDelay: function(){
        //加载完成后，替换图标
        this.loadImages(this.imgQueen, function(img, data){
            var item = $("a[data-id='"+ data.id +"']");
            item.find(".default-game").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");
        });
    },

    /**
     * 视图销毁时，移除事件监听
     */
    onDestory : function(){
        if(this.adEl){
            this.adEl = null;
            //停止广告轮播
            clearTimeout(this.adScrollTask);
        }
    },

    /**
     * 预加载广告图片信息
     */
    loadAds: function(banners){
        var banner = banners[0], /*轮询只有一个广告位*/
            context = this,
            keys = [];

        //存在广告
        if(banner.ads.length > 0){
            context.cacheBanner = banner;
            //待加载标示
            context.waitLoadAds = {};

            //广告El Wrap
            context.adEl = $($.format(DGC.Ads.getScrollAdTpl(),[ resName.TEXT_AD_SCROLL_TITLE, banner._id]));
            context.el.prepend(context.adEl);

            for(var i = 0 ; i < banner.ads.length; i++){
                var ad = banner.ads[i];
                $.extend(ad, {
                    url: ad.img_url
                });

                //置标识位
                context.waitLoadAds[ad.img_url] = false;
            }

            //预加载广告位图片
            context.loadImages(context.cacheBanner.ads, function(img, data){
                var adCWrap = context.adEl.find(".ad-content"),
                    adNWrap = context.adEl.find(".ad-nav-items");

                adCWrap.append($.format(DGC.Ads.getScrollAdCTpl(),[ data.id,  data.ad_name, img.src ]));
                adNWrap.append($.format(DGC.Ads.getScrollAdNTpl(),[ data.id]));

                //置标识位
                context.waitLoadAds[data.img_url] = true;

                context.sycPageAds(); //同步检查所有广告位是否加载成功
            });
        }
    },

    /**
     * 同步预加载图片
     */
    sycPageAds : function(){
         for( var key in this.waitLoadAds){
            if(!this.waitLoadAds[key]){
                return false; //尚未完成加载
            }
        }

        delete this.waitLoadAds;
        //加载完毕,渲染全部广告
        this.renderPromotionBanner();
    },

    //渲染广告
    renderPromotionBanner: function(result){
        var adEl = this.adEl,
            context = this;

        //点击统计
        adEl.find(".ad-item").bind('tap', {context : this}, function(event){
            var context = event.data.context,
                me = $(this),
                id = me.attr('data-key'),
                ads = context.cacheBanner.ads,
                adObj;

                for(var i = 0 ; i < ads.length; i++){
                   adObj = ads[i];
                   //找到匹配的广告对象
                   if(adObj.id == id){
                       break;
                   }
                }
            switch(adObj.ad_type){
                case 1 /*APK*/:
                    DGC.ActionUtil.getGameState([adObj.package_name]);
                    context.cacheClickAd = adObj /*缓存点击广对象*/;
                    break;
                case 2 /*网页*/:
                    DGC.ActionUtil.openBrowser(adObj.ad_url);
                    break;
            }
        });

        //监听屏幕切换
        $(window).bind('orientationchange', { context:this } , this.adStatusListener);

        //切换广告状态
        this.switchAdStatus();
    },

    /**
     * 切换显示广告状态
     */
    switchAdStatus: function(){
        var orientation = window.orientation,
           context = this,
           adEl = this.adEl;

        switch(orientation) {
            case 0:
            case 180:  /*横屏*/
                adEl.show( 300,  function(){
                    //开始轮播
                    context.playAds();
                });
                break;
            case 90:
            case -90:  /*竖屏*/
                adEl.hide(function(){
                   context.stopPlayAds();
                });
                break;
        }
    },

    /**
     * 下载或启动游戏APK
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            bannerModel = this.action.model["prombanner"];

        if(this.cacheClickAd){
            if(status) {
                bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheBanner._id, 1/*运行*/ );//记录广告点击
                DGC.ActionUtil.startGame(this.cacheClickAd.bundle_id);//启动游戏
            } else {
               bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheBanner._id, 0 /*下载*/);//记录广告点击
               DGC.ActionUtil.download(this.cacheClickAd.ad_url);//下载游戏
            }
            this.cacheClickAd = null;
        }
    },

    /**
     * 开始播放广告
     */
    playAds: function(){
        var context = this,
            selfFn = arguments.callee,
            adEl = context.adEl,
            selectAd  = DGC.Ads.getBannerShowAd(context.cacheBanner.ads),
            lastAd = context.lastAd,
            afterShowFn = $.bindFn(context._setCurrentAd,context,[selectAd]);

        if(lastAd){
            if(lastAd == selectAd){
                this._setCurrentAd(selectAd); //如果取得相同广告，依然计入统计
                this.adScrollTask = setTimeout($.bindFn(selfFn, context), context.cacheBanner.duration * 1000);
                return false;
            }
            var afterHideFn = $.bindFn(context.adShow, context, [selectAd, afterShowFn]);
            context.adHide(lastAd, afterHideFn );
        }else{
            context.adShow(selectAd, afterShowFn);
        }

        //下次显示
        this.adScrollTask = setTimeout($.bindFn(selfFn, context), context.cacheBanner.duration * 1000);
   },

   /**
    * 停止播放广告
    */
   stopPlayAds: function(){
       var adEl = this.adEl;

       adEl.hide();

       //清除Play Action
       if(this.adScrollTask){
           clearTimeout(this.adScrollTask);
       }

       //清除当前显示广告
       if(this.lastAd){
            this.adHide(this.lastAd, $.emptyFn, true);
            this.lastAd = null;
       }
   },

   /**
    * 显示当前显示Ad
    */
   _setCurrentAd: function(ad){
       var context = this,
           bannerModel = this.action.model['prombanner'];

       context.lastAd = ad;

       //统计广告位中显示次数
       setTimeout(function(){
           bannerModel.promotionBannerCount(context.lastAd.id, context.cacheBanner._id);
       },0);
   },

   /**
    * 隐藏指定广告
    */
   adHide: function(ad, callback, immediate){
        var adEl = this.adEl;
        if(immediate){
            adEl.find(".ad-item[data-key='" + ad.id + "']").hide();
            adEl.find(".ad-nav-item[data-key='" + ad.id + "']").removeClass('active');
            callback.call(this);
        //上次显示渐出,完毕后载入
        }else{
            adEl.find(".ad-item[data-key='" + ad.id + "']").fadeOut(300,  function(){
                adEl.find(".ad-nav-item[data-key='" + ad.id + "']").removeClass('active');
                callback.call(this);
            });
        }
   },

   /**
    * 加载下一个显示广告
    */
   adShow: function(ad, callback){
       var adEl = this.adEl;
       adEl.find(".ad-item[data-key='" + ad.id + "']").fadeIn(300,  function(){
            adEl.find(".ad-nav-item[data-key='" + ad.id + "']").addClass('active');
            adEl.find(".ad-title").text(ad.ad_name);
            callback.call(this);
       });
   },

   /**
    * 监听广告横竖屏屏蔽
    */
   adStatusListener: function(event){
       var context = event.data.context;
       context.switchAdStatus();
   },

   /**
    * 销毁页面
    */
   onDestory: function(){
       $(window).unbind('orientationchange', this.adStatusListener);
       if(this.adScrollTask){
           clearTimeout(this.adScrollTask);
       }
   }
});