/**
 * "我"的详情视图
 */
DGC.View.MyDetail =  $.inherits(DGC.View, {

    baseId : 'my-detail-view',

    /**
     * 根视图
     */
    isSub: false,

    /**
     * 标题文字
     * @type Boolean
     */
    title : 'A_TITLE_ME_DETAIL',

    /**
     * 视图静态模版
     * @type String
     */
    renderTpl : "1.2.0/js/template/mydetail.html",

    player : undefined,

    game : undefined,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        /**
         * 数据模板
         * @type
         */
        this.viewTpl = {
            "path": false
        };

        //显示我的基本信息
        this.player = window.sdk.player;

        this.game = this.game || window.sdk.game;

        this.action.model['me'].queryMyGameDetail(this.player.id, this.game.id);

        //始终查询用户的剩余乐币
        this.action.model['pay'].queryPlayerCoins();

        this.setPlayerDetail();

        this.bindDetailItems();

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME);

        //判断是否为新用户
        if(window.sdk.player.is_new_comer && !window.sdk.logined){
            this.action.showDialog(
                "UserLogin",
                {
                    meModel: this.action.model['me'],
                    showModel : DH.ATTR.USER_LOGIN_DIALOG.LOGIN
                },
                function(name, params){
                    //弹出绑定的Dialog
                    this.loginWin = new DGC.Dialog[name](params);
                    this.loginWin.show();
                },
                this
            );
        }

    },

    /**
     * 设置界面上Player信息
     */
    setPlayerDetail: function(){
        //判断用户头像是否缺省头像
        var headerImg = $("#md-player-url"),
            genderClass = "";
        //自定义头像
        if(this.player.avatar_url != "" && this.player.avatar_url.length > 0 ){
            headerImg.attr({
                src: this.player.avatar_url
            });
        }else{
            //显示缺省头像
            headerImg.parent(".head-portrait").html('<div class="head-default"></div>');
        }

        $("#md-name").text(this.player.nickname);

        //当前性别
        switch(this.player.gender){
            case DH.ATTR.GENDER.MALE:
                genderClass = "male";
                break;
            case DH.ATTR.GENDER.FEMALE:
                genderClass = "female";
                break;
            case DH.ATTR.GENDER.SECRET:
                break;
        }
        if(!$.isEmpty(genderClass)){
            $("#md-sex").addClass(genderClass);
        }

        /*
                     不使用last_game,而使用sdk.gam_name
        if(!$.isEmpty(this.player.last_game)){
            $("#md-lastgame h1").text($.format(resName.TEXT_ME_DETAIL_LASTGAME,[this.player.last_game]));
        }else{
            $("#md-lastgame h1").text(resName.TEXT_PLAYER_DETAIL_LASTGAME_NONE);
        }*/
        $("#md-lastgame h1").text($.format(resName.TEXT_ME_DETAIL_LASTGAME, [window.sdk.game_name]));

        $("#md-level").text(this.player.level);

        $("#my-friends-text").text($.format(resName.TEXT_DETAIL_FRIENDS_NUM,
                [this.player.total_friends]));
        $("#my-playedgames").text($.format(resName.TEXT_ME_DETAIL_GAMES_NUM,
                [this.player.total_games]));

        //是否支持乐币支付
        if(window.sdk.channel.enable_coin_payment){
            var charge_btn = $("#charge-rmb-btn");

            charge_btn.bind('tap', {context: this} ,function(event) {

                //记录点：“我”界面，点击上面的 “充值乐币”
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_ME_CHARGE_COINS,
                    {
                        'game_id':window.sdk.game.id,
                        'user_id':window.sdk.player.id
                    }
                );

                var context = event.data.context;
                //进入支付列表
                context.action.setView("ChargeAccount",{
                    chargeModel: 0
                });

            });

            charge_btn.show();
        }

        //预先更新
        this.updateMyNewFriends();
    },

    /**
     * 更新当前新fans显示
     */
    updateMyNewFriends: function(){
        //更新TIP显示数据
        var tips = window.sdk.tips,
            friends_memu = $("#md-myfriends"),
            activity_memu =$("#activity-memu"),
            tpl = "<span class='new-tips-text'>{0}</span>",
            memuTpl = '<div class="new-tips"><h1>{0}</h1></div>';

        //新好友
        if(tips && tips.new_follwers){
            friends_memu.find(".content h1").append($.format(tpl,  [$.format(resName.TEXT_ME_DETAIL_NEWFANS,[tips.new_follwers])]));
            friends_memu.find(".detail").replaceWith($.format(memuTpl, [tips.new_follwers]));
        }

        //新活动
        if(tips && tips.new_activity){
            activity_memu.find(".content h1").append($.format(tpl,  [$.format("(您有{0}个新活动)",[tips.new_activity])]));
            activity_memu.find(".detail").replaceWith($.format(memuTpl, [tips.new_activity]));
        }
    },

    /**
     * 更新当前用户的信息(绑定->替换昵称和头像)
     */
    updatePlayerDetail: function(){
        //判断用户头像是否缺省头像
        var headerWrap = this.el.find(".head-portrait");
        //自定义头像
        if(!$.isEmpty(this.player.avatar_url)){
            headerWrap.html("<img src='" + this.player.avatar_url+ "'><div class='mask'></div>");
        }else{
            //显示缺省头像
            headerWrap.html('<div class="head-default"></div>');
        }

        $("#md-name").text(this.player.nickname);
    },

    /**
     * 显示玩家指定游戏中的排行榜和成就信息
     */
    showMyGameInfo: function(boards, achieves){
        var completeAchieve = 0;
        for (var i = 0; i < achieves.length; i++) {
          if(achieves[i].percentage == 1){
               completeAchieve++;
               continue;
          }
        };

        //导航按钮点击效果
        $(".common-user-info > div")
            .bind(DGC.Common.E_TAP_DOWN, function(){
                $(this).addClass('active');
            })
            .bind(DGC.Common.E_TAP_UP, function(){
                $(this).removeClass('active');
            });

        $("#md-achieves").text(completeAchieve + "/" + achieves.length);
        $("#md-boards").text(boards.length);

        //$("#md-friends").text(this.player.total_friends + this.player.total_followers);

        //成就
        $(".achievement-finished").bind("tap", {context:this}, function(event){

            //记录点：“我”界面，点击中间的 “成就”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_ACHIEVEMENT,
                {
                    'game_id':window.sdk.game.id
                }
            );

            var context = event.data.context;
            context.action.setView('UserAchieve',{
                isSub: true,
                game : context.game,
                player : context.player
            });
        });

        //排行榜
        $(".point-board").bind("tap", {context:this}, function(event){

            //记录点：“我”界面，点击中间的 “排行榜”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_LEADERBOARD,
                {
                    'game_id':window.sdk.game.id
                }
            );

            var context = event.data.context;
            context.action.setView('Dashboard',{
                isSub: true,
                boardsSub: true,
                game : context.game,
                player : context.player
            });
        });


        //我的好友
        //$(".gold-board").bind("tap", {context:this}, function(event){
            //var context = event.data.context;
            //context.action.setView('MyFriends',{
                //player: context.player
            //});
        //});

    },

    /**
     * 显示玩家的金币数是否支持我的钱包
     */
    showPlayerCoins: function(coins){
        //设置金币数
        $("#md-coins").text(coins);
        this.player.coins = coins;
        window.sdk.player.coins = coins;
    },

    /**
     * Plyaer操作列表事件绑定
     */
    bindDetailItems : function(){
        var items = this.el.find(".my-list .memu-item"),
            CM = DGC.Common;

        items.bind(DGC.Common.E_TAP_DOWN, CM.listTapDownHandler);
        items.bind(DGC.Common.E_TAP_UP, CM.listTapEndHandler);

        //点头像修改头像
        this.el.find(".head-portrait").bind('tap', {context:this},function(event){
            //记录点：“我”界面，点击头像进行 “头像设定”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_ICON_SETTINGS,
                {
                    'game_id':window.sdk.game.id,
                    'user_id':window.sdk.player.id
                }
            );
            DGC.ActionUtil.commonSelect(DGC.Service.Messages.SHOW_UPDATE_PLAYER_ICON_WAYS,DH.getUploadAvatarComboxData());
        });


        //进入我的好友
        $("#md-myfriends").bind('tap', { context:this },function(event){

            //记录点：“我”界面，点击 “我的好友”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_FRIENDS,
                {
                    'game_id':window.sdk.game.id,
                    'user_id':window.sdk.player.id
                }
            );

            var context = event.data.context,
                tips = window.sdk.tips,
                defaultParams = { player: context.player };

            //如果存在新好友，则直接进入fans列表
            if(tips && tips.new_follwers){
                $.extend(defaultParams,{
                    defaultTab: "mf-fans"
                });
            }
            context.action.setView('MyFriends', defaultParams);
        });

        //进入我玩过的游戏
        $("#query-mygames").bind('tap', { context:this }, function(event){

            //记录点：“我”界面，点击 “我玩过的游戏”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_GAMES,
                {
                    'game_id':window.sdk.game.id
                }
            );

            var context = event.data.context;
            context.action.setView('PlayedGames', {
                player: context.player
            });
        });

        //进入邀请好友
        //$("#invite-friends").bind('tap', {context:this},function(event){
            //var context = event.data.context;
            //context.action.setView('InviteFriends');
        //});

        //进入设定
        $("#setting-memu").bind('tap', {context:this},function(event){
            //记录点：“我”界面，点击 “设定”
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_SETTINGS,
                {
                    'user_id': window.sdk.player.id
                }
            );

            var context = event.data.context;
            context.action.setView('Setting');
        });

        //支持活动
        if(DH.isSupportActivities()){
            //进入活动
            var activityEl = $("#activity-memu");
            activityEl.addClass('list-item-highlight');
            activityEl.bind('tap', {context:this},function(event){
                //记录点：“我”界面，点击 “活动”
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_ME_ACTIVITY,
                    {
                        'user_id': window.sdk.player.id
                    }
                );
                var context = event.data.context;
                context.action.setView('Activity');
            });
            activityEl.show();
        }

        //支持兑换码
        if(DH.isSupportPromotion()){
            var promoteEl = $("#promotecode-memu");
             //进入兑换码
            promoteEl.bind('tap', {context:this},function(event){
                //记录点：“我”界面，点击 “兑换码”
                DGC.ActionUtil.recordUserAction(
                    DGC.Event.EventId.EVENT_ME_PROMOTECODE,
                    {
                        'user_id': window.sdk.player.id
                    }
                );
                var context = event.data.context;
                context.action.setView('PromoteCode');
            });
            promoteEl.show();
        }

    },

    /**
     * 新用户登录更新用户信息
     */
    updatePlayerInfo: function(){
        $("#md-name").text(window.sdk.player.nickname);
        //当前性别
        switch(window.sdk.player.gender){
            case DH.ATTR.GENDER.MALE:
                genderClass = "male";
                break;
            case DH.ATTR.GENDER.FEMALE:
                genderClass = "female";
                break;
        }
        $("#md-sex").removeClass('female male');
        $("#md-sex").addClass(genderClass);
        this.loginWin.destory();
    },

     /**
     * 已选择更新头像方式
     */
    avatarWaySelected : function(selectItem){
        var ATTR = DH.ATTR,
            DAU = DGC.ActionUtil;
        switch(selectItem.value){
            case ATTR.UPDATE_AVATAR.CAMERA:
            case ATTR.UPDATE_AVATAR.LOCAL:
                DAU.updateAvatar(parseInt(selectItem.value, 10));
                break;
            case ATTR.UPDATE_AVATAR.FAKE_SINA:
                //过期弹出窗口要求重绑定
                this.action.model['me'].snsSycPlayer(ATTR.SYNC_SNS.SINA, ATTR.SYNC_TYPE.AVATAR);
                break;
            case ATTR.UPDATE_AVATAR.FAKE_RENREN:
                //过期弹出窗口要求重绑定
                this.action.model['me'].snsSycPlayer(ATTR.SYNC_SNS.RENREN, ATTR.SYNC_TYPE.AVATAR);
                break;
        }
    },


    onDestory: function(){
         //销毁窗口
        if(this.loginWin){
            this.loginWin.destory();
        }
        this.loginWin = null;
    }

});