/**
 * 玩过的游戏视图
 */
DGC.View.PlayedGames =  $.inherits(DGC.View, {

    baseId : 'playedgames-view',

    /**
     * 别名
     */
    alias: 'PlayedGames',

    /**
     * 标题文字
     * @type Boolean
     */
    title : false,

    /**
     * 视图静态模版
     * @type String
     */
    renderTpl : "1.2.0/js/template/playedgames.html",

    player: undefined,

    nextPageCur:undefined,

    /**
     * 滚动延迟加载
     */
    loadMoreTask: 0,

    /**
     * 广告滚动Task
     */
    adScrollTask: 0,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        this.viewTpl = {
            LIST_ITEM:"#pg-list-tpl"
        };

        //加载完成后设置状态标题及内容
        var isMe = (window.sdk.player.nickname == this.player.nickname );

         //设置标题
        this.setTitle($.format(resName.A_TITLE_ME_PLAYEDGAMES,[ isMe ?
            resName.A_TITLE_ME_PLAYEDGAMES_ME: this.player.nickname ]));

        //设置玩过游戏的总数
        var text = $.format(resName.TEXT_PLAYGAMES_STATUS_TITLE,[ isMe ?
            resName.TEXT_PLAYGAMES_STATUS_ME: this.player.nickname , this.player.total_games]);

        //加载模板渲染内容
        $("#pg-gamesnum").text(text);

        //查询默认列表
        this.action.model['me'].queryPlayedGames(this.player.id);

        //预绑定
        this.prevBindGameDetial(true);

        //绑定页面滑动
        $(window).bind("scroll", { context: this }, this.scrollLoadMoreGames);

        /*
        this.el.find(".list-item").bind('tap', {context: this}, function(event) {
            var context = event.data.context;
            context.action.setView('GameInfo');
        });
        */
        //SDK我/玩家广告
        this.action.model["prombanner"].queryPromotionBanner(DGC.Ads.getBanners(this.alias));

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME_GAMES);

    },

    /**
     * 绑定或取消绑定游戏详细信息
     */
    prevBindGameDetial : function(bindStatus){
        var fn = bindStatus ? "live" : "die";
        var games = $("#pg-game-list .list-item:not(.empty-item)");
        games[fn](DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        games[fn](DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);
        games[fn]("tap", { context : this}, this.showGameDetail);
    },


    /**
     * 滚动时监听
     */
    scrollLoadMoreGames : function(event){
        var context = event.data.context;

        //滚到页面底端
        if(Math.abs($(window).scrollTop() -( $(document).height() - $(window).height())) <= 10){
            if(context.nextPageCur){
                clearTimeout(context.loadMoreTask);
                context.loadMoreTask = setTimeout(function(){
                    context.action.model['me'].queryPlayedGames(context.player.id, context.nextPageCur);
                }, DGC.Common.DELAY_SCROLL_LOADER);
            }
        }
    },

    /**
     * 渲染玩过的游戏列表
     * @param {Array<Object>} gamesInfo 游戏列表
     * @param {Boolean} isMore 是否为二次加载
     */
    renderPlayedGames : function(gamesInfo , isMore){
        var gameList = gamesInfo.data,
            delayIcons = [];

        if(gameList.length == 0 && !isMore ){
            $("#pg-game-list").html(DGC.Common.getEmptyListItemHtml(resName.TEXT_PLAYGAMES_EMPTY_GAMES));
        }else{
            for (var i = 0; i < gameList.length; i++) {
                var game = gameList[i];
                //添加文本字段
                game.player_count_text =  $.format(resName.TEXT_PLAYGAMES_PALYER_COUNT, [game.player_count]);

                //判断是否存在图标
                if(!$.isEmpty(game.icon_url)){
                    delayIcons.push({
                        url : game.icon_url,
                        id : game.id
                    });
                }
            }

            $("#pg-game-list").append(this.renderByTpl(this.viewTpl.LIST_ITEM, gameList));

            //延迟加载图标
            if(delayIcons.length > 0){
                this.loadImages(delayIcons, function(img, data){
                    var item = $("div[data-key='" + data.id + "']");
                    item.find(".default-game").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");;
                });
            }

        }

        //缓存下一页的游标
        this.nextPageCur = gamesInfo.next_cursor ?  gamesInfo.next_cursor : null;
    },

    showGameDetail : function(event){
        var context = event.data.context,
            me = $(this),
            id,
            name;
        id = me.attr("data-key");
        name = $.trim(me.find('h1').text());

        if(context.player.id == window.sdk.player.id){
            //记录点：“我玩过的游戏”界面，点击 某一款游戏
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_GAMES_VIEW,
                {
                    'game_id':window.sdk.game.id,
                    'target_game_id':id
                }
            );
        }else{
            //记录点：：“玩家-­‐>TA 玩过的游戏”界面，点击 具体某个游戏
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_PLAYER_GAMES_VIEW,
                {
                    'game_id':window.sdk.game.id,
                    'player_id':context.player.id,
                    'target_game_id':id
                }
            );
        }

        context.action.setView('GameInfo',{
            title : name,
            gameId : id,
            player : context.player
        });
    },

    /**
     * 视图销毁时，移除事件监听
     */
    onDestory : function(){
        $(window).unbind('orientationchange', this.adStatusListener);
        if(this.adEl){
            this.adEl = null;
            //停止广告轮播
            clearTimeout(this.adScrollTask);
        }

        this.prevBindGameDetial(false);
        $(window).unbind("scroll", this.scrollLoadMoreGames);
    },

    /**
     * 预加载广告图片信息
     */
    loadAds: function(banners){
        var banner = banners[0], /*轮询只有一个广告位*/
            context = this,
            keys = [];

        //存在广告
        if(banner.ads.length > 0){
            context.cacheBanner = banner;
            //待加载标示
            context.waitLoadAds = {};

            //广告El Wrap
            context.adEl = $($.format(DGC.Ads.getScrollAdTpl(),[resName.TEXT_AD_SCROLL_TITLE, banner._id]));
            context.el.prepend(context.adEl);

            for(var i = 0 ; i < banner.ads.length; i++){
                var ad = banner.ads[i];
                $.extend(ad, {
                    url: ad.img_url
                });

                //置标识位
                context.waitLoadAds[ad.img_url] = false;
            }

            //预加载广告位图片
            context.loadImages(context.cacheBanner.ads, function(img, data){
                var adCWrap = context.adEl.find(".ad-content"),
                    adNWrap = context.adEl.find(".ad-nav-items");

                adCWrap.append($.format(DGC.Ads.getScrollAdCTpl(),[ data.id,  data.ad_name, img.src ]));
                adNWrap.append($.format(DGC.Ads.getScrollAdNTpl(),[ data.id]));

                //置标识位
                context.waitLoadAds[data.img_url] = true;

                context.sycPageAds(); //同步检查所有广告位是否加载成功
            });
        }
    },

    /**
     * 同步预加载图片
     */
    sycPageAds : function(){
         for( var key in this.waitLoadAds){
            if(!this.waitLoadAds[key]){
                return false; //尚未完成加载
            }
        }

        delete this.waitLoadAds;
        //加载完毕,渲染全部广告
        this.renderPromotionBanner();
    },

    //渲染广告
    renderPromotionBanner: function(result){
        var adEl = this.adEl,
            context = this;

        //点击统计
        adEl.find(".ad-item").bind('tap', {context : this}, function(event){
            var context = event.data.context,
                me = $(this),
                id = me.attr('data-key'),
                ads = context.cacheBanner.ads,
                adObj;

                for(var i = 0 ; i < ads.length; i++){
                   adObj = ads[i];
                   //找到匹配的广告对象
                   if(adObj.id == id){
                       break;
                   }
                }
            switch(adObj.ad_type){
                case 1 /*APK*/:
                    DGC.ActionUtil.getGameState([adObj.package_name]);
                    context.cacheClickAd = adObj /*缓存点击广对象*/;
                    break;
                case 2 /*网页*/:
                    DGC.ActionUtil.openBrowser(adObj.ad_url);
                    break;
            }
        });

        //监听屏幕切换
        $(window).bind('orientationchange', { context:this } , this.adStatusListener);

        //切换广告状态
        this.switchAdStatus();
    },

    /**
     * 切换显示广告状态
     */
    switchAdStatus: function(){
        var orientation = window.orientation,
           context = this,
           adEl = this.adEl;

        switch(orientation) {
            case 0:
            case 180:  /*横屏*/
                adEl.show( 300,  function(){
                    //开始轮播
                    context.playAds();
                });
                break;
            case 90:
            case -90:  /*竖屏*/
                adEl.hide(function(){
                   context.stopPlayAds();
                });
                break;
        }
    },

    /**
     * 下载或启动游戏APK
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            bannerModel = this.action.model["prombanner"];

        if(this.cacheClickAd){
            if(status) {
                bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheBanner._id, 1/*运行*/ );//记录广告点击
                DGC.ActionUtil.startGame(this.cacheClickAd.bundle_id);//启动游戏
            } else {
               bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheBanner._id, 0 /*下载*/);//记录广告点击
               DGC.ActionUtil.download(this.cacheClickAd.ad_url);//下载游戏
            }
            this.cacheClickAd = null;
        }
    },

    /**
     * 开始播放广告
     */
    playAds: function(){
        var context = this,
            selfFn = arguments.callee,
            adEl = context.adEl,
            selectAd  = DGC.Ads.getBannerShowAd(context.cacheBanner.ads),
            lastAd = context.lastAd,
            afterShowFn = $.bindFn(context._setCurrentAd,context,[selectAd]);

        if(lastAd){
            if(lastAd == selectAd){
                this._setCurrentAd(selectAd); //如果取得相同广告，依然计入统计
                this.adScrollTask = setTimeout($.bindFn(selfFn, context), context.cacheBanner.duration * 1000);
                return false;
            }
            var afterHideFn = $.bindFn(context.adShow, context, [selectAd, afterShowFn]);
            context.adHide(lastAd, afterHideFn );
        }else{
            context.adShow(selectAd, afterShowFn);
        }

        //下次显示
        this.adScrollTask = setTimeout($.bindFn(selfFn, context), context.cacheBanner.duration * 1000);
   },

   /**
    * 停止播放广告
    */
   stopPlayAds: function(){
       var adEl = this.adEl;

       adEl.hide();

       //清除Play Action
       if(this.adScrollTask){
           clearTimeout(this.adScrollTask);
       }

       //清除当前显示广告
       if(this.lastAd){
            this.adHide(this.lastAd, $.emptyFn, true);
            this.lastAd = null;
       }
   },

   /**
    * 显示当前显示Ad
    */
   _setCurrentAd: function(ad){
       var context = this,
           bannerModel = this.action.model['prombanner'];

       context.lastAd = ad;

       //统计广告位中显示次数
       setTimeout(function(){
           bannerModel.promotionBannerCount(context.lastAd.id, context.cacheBanner._id);
       },0);
   },

   /**
    * 隐藏指定广告
    */
   adHide: function(ad, callback, immediate){
        var adEl = this.adEl;
        if(adEl){
            if(immediate){
                adEl.find(".ad-item[data-key='" + ad.id + "']").hide();
                adEl.find(".ad-nav-item[data-key='" + ad.id + "']").removeClass('active');
                callback.call(this);
            //上次显示渐出,完毕后载入
            }else{
                adEl.find(".ad-item[data-key='" + ad.id + "']").fadeOut(300,  function(){
                    adEl.find(".ad-nav-item[data-key='" + ad.id + "']").removeClass('active');
                    callback.call(this);
                });
            }
        }

   },

   /**
    * 加载下一个显示广告
    */
   adShow: function(ad, callback){
       var adEl = this.adEl;
       if(adEl){
           adEl.find(".ad-item[data-key='" + ad.id + "']").fadeIn(300,  function(){
                adEl.find(".ad-nav-item[data-key='" + ad.id + "']").addClass('active');
                adEl.find(".ad-title").text(ad.ad_name);
                callback.call(this);
           });
       }
   },

   /**
    * 监听广告横竖屏屏蔽
    */
   adStatusListener: function(event){
       var context = event.data.context;
       context.switchAdStatus();
   }

});
