/**
 * 兑换码
 * @author Jerry.Zhang
 */
DGC.View.PromoteCode = $.inherits(DGC.View, {

    baseId : 'promotecode-view',

    title : 'A_TITLE_PROMOTECODE',

    renderTpl : '1.2.0/js/template/promotecode.html',

    gameInfo : undefined,

    isPromoteSubmit: false,

    /**
     * 本地兑换KEY
     */
    promoteCodeKey : 'PROMOTE_CODE_ENTER_COUNT',

    //兑换码输入次数限制
    promoteCodeEnterLimit : 5,

    //兑换码输入限制的过期时间,单位毫秒数
    promoteCodeExpiredTime : 7200000,


    //上次请求的锁定数据
    lastPromoteData: undefined,


    /**
     * 视图初始化函数
     */
    viewReady : function() {
        //禁用状态还未合入
        this.el.find(".btn").bind(DGC.Common.E_TAP_DOWN, DGC.Common.buttonTapDownHandler)
            .bind(DGC.Common.E_TAP_UP, DGC.Common.buttonTapEndHandler);

        $("#promotecode").bind('keyup', { context : this}, function(event) {
            var promoteCode = $("#promotecode").val();
            var promoteCodeMinLength = 8;
            DGC.ActionUtil.log("promotecode:" + promoteCode);
            //兑换码最小长度
            if(promoteCode.length >= promoteCodeMinLength) {
                event.data.context.isPromoteSubmit = true;
                $("#promotecode-submit").removeClass("disable-btn");
                $("#promotecode-submit").addClass("green-btn");
            } else {
                event.data.context.isPromoteSubmit = false;
                $("#promotecode-submit").removeClass("green-btn");
                $("#promotecode-submit").addClass("disable-btn");
            }
        });

        $("#promotecode-submit").bind('tap', { context : this }, this.promote);

        $("#promotecode-help").bind('tap', { context : this}, function(event) {

            DGC.ActionUtil.recordUserAction(DGC.Event.EventId.EVENT_ME_PROMOTECODE_HELP, {
                'user_id' : window.sdk.player.id
            });

            var context = event.data.context;
            context.action.setView("PromoteCodeHelp");
        });

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME_PROMOTECODE);

    },
    //根据兑换码 发送请求到服务器
    promote : function(event) {//
        var context = event.data.context,
            promoteCode = $("#promotecode").val(),
            CM = DGC.Common,
            DAU = DGC.ActionUtil,
            pass = false,
            promoteCodeData = {},
            isGlobal = true;


        //记录点：“兑换码”界面，点击查看“兑换”
        DGC.ActionUtil.recordUserAction(DGC.Event.EventId.EVENT_PROMOTECODE_PROMOTE, {
             'user_id' : window.sdk.player.id,
        });

        if(DEBUG.isWebModel()){
            isGlobal = false;
        }

        if(context.isPromoteSubmit) {
            promoteCodeData = CM.getAppConfig(context.promoteCodeKey, isGlobal);
            //取数据
            var currTimestamp = new Date().getTime(),
                promoteCodeData = promoteCodeData || { 'count' : 0,  'timestamp' : currTimestamp };

            if(promoteCodeData.count == context.promoteCodeEnterLimit) {//判断两个小时内输入超过5次
                if((currTimestamp - promoteCodeData.timestamp) > context.promoteCodeExpiredTime) { //锁定超过2小时
                     CM.removeAppConfig(context.promoteCodeKey, isGlobal); //清空数据
                     //达到上限次数，超过2小时，清零兑换
                     context.action.model['me'].updatePromotionCode(promoteCode);
                }else{
                    DAU.showTipMsg(resName.TIP_PROMOTECODE_ENTER_MORE_THAN_FIVE);
                    return false;
                }
            //未达上次次数直接兑换
            }else{
                 context.lastPromoteData = promoteCodeData; //当期缓存次数
                 context.action.model['me'].updatePromotionCode(promoteCode);
            }
        }
    },
    //处理服务器响应结果
    handlePromoteCode : function(rs) {
        var DAU = DGC.ActionUtil,
            data = rs.data,
            CM = DGC.Common;

        if(!data.err_code) {//兑换成功
            //请求成功后，重置次数
            DGC.Common.removeAppConfig(this.promoteCodeKey, true);

            if(data.promotion_type) {//兑换码类型(1:乐币 2:道具 3:游戏)
                //var tipMsg = resName.TIP_PROMOTECODE_ACTION_SUCCESS+"\n";
                if(data.promotion_type == 1) {//乐币
                    DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_COIN_SUCCESS, [data.coins]), function() {
                        //回退上一个页面
                        DGC.Application.goBack();
                    });
                } else if(data.promotion_type == 2) {//道具
                    DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_PRODUCT_SUCCESS, [data.game.name, 1, data.product.name]), function() {
                        DAU.notifySDKBuyResult(100 /*兑换码方式*/, true, { product: data.product , quantity : 1 });//购买道具状态通知SDK
                        DGC.Application.goBack();//回退上一个页面
                    });
                } else if(data.promotion_type == 3) {//游戏

                }
            }
        } else {//兑换失败
            if(data.err_code == 3001) {//推广码不存在
                var lastPromote = this.lastPromoteData || { 'count' : 0,  'timestamp' : new Date().getTime() };
                lastPromote.count += 1;

                //不存在兑换码
                CM.setAppConfig(this.promoteCodeKey, lastPromote , true);
                DAU.showTipMsg(resName.TIP_PROMOTECODE_NOT_EXIST);
            } else if(data.err_code == 3002) {//游戏不匹配
                this.gameInfo = data.game;
                DGC.ActionUtil.getGameState([this.gameInfo.bundle_id]);
            } else if(data.err_code == 3003) {//推广码过期
                DAU.showTipMsg(resName.TIP_PROMOTECODE_EXPIRED);
            } else if(data.err_code == 3004) {//已拥有该道具
                DAU.showTipMsg(resName.TIP_PROMOTECODE_HAS_OWN);
            } else if(data.err_code == 3005){ //该兑换码已经被使用
                DAU.showTipMsg(resName.TIP_PROMOTECODE_USED);
            }
        }

        //清空上次请求的计数
        this.lastPromoteData = null;
    },
    /**
     * 显示当前游戏的状态
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            DAU = DGC.ActionUtil,
            game = this.gameInfo;
        DGC.ActionUtil.log("gameInfo:" + JSON.stringify(game));
        if(status) {
            DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_GAME_NOT_MATCH, [game.name]), function() {
                DGC.ActionUtil.log("game bundle_id:" + game.bundle_id);
                if(!DEBUG.isWebModel()){
                    DGC.ActionUtil.startGame(game.bundle_id);//启动游戏
                }
            });
        } else {
            DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_NEED_DOWNLOAD, [game.name]), function() {
                DGC.ActionUtil.log("game download url:" + game.download_url);
                if(!DEBUG.isWebModel()){
                    DGC.ActionUtil.download(game.download_url);//下载游戏
                }
            });
        }
    }
});

/**
 * 兑换码帮助
 */
DGC.Dialog.PromoteCodeHelp = $.inherits(DGC.Dialog, {

    baseId: 'promotecodehelp-dialog',

    renderTpl:'1.2.0/js/template/dialog/promotecodehelp.html',

    viewReady:function(){
         $("#confirm-btn").bind(DGC.Common.E_TAP_DOWN,function(){$(this).addClass('active')})
            .bind(DGC.Common.E_TAP_UP,function(){$(this).removeClass('active')})
            .bind("tap", { context: this }, function(event){
                var context = event.data.context;
                context.destory();
            }
        );
    }

});
