/**
 * 用户当前成就信息
 */
DGC.View.UserAchieve =  $.inherits(DGC.View, {

    baseId: 'user-achievement',

    /**
     * 别名
     */
    alias: 'UserAchieve',

    /**
     * 根视图
     */
    isSub: false,

    renderTpl:'1.2.0/js/template/userachieve.html',

    game: undefined,

    player: undefined,

    /**
     * 视图显示模式
     * 0:SDK页面
     * 1:游戏开发者界面
     */
    model: 0,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        this.viewTpl =  {
            "ACHIEVE" : "#ua-listitem-tpl"
        };

        //如果为离线模式，则查询本地成就
        if(window.sdk.isOffline){
            this.setTitle($.format(resName.A_TITLE_ACHIEVE , [window.sdk.game_name] ));
            this.action.model['achi'].queryOfflineGameAchieve();
            this.bindReloginBtn();
        }else{
            var gameName = (this.game != null ? this.game.name : window.sdk.game.name);
            this.setTitle($.format(resName.A_TITLE_ACHIEVE , [ gameName] ));
            //默认加载请求"我"的
            var gameId =  this.game ? this.game.id : window.sdk.game.id,
                playerId = this.player ? this.player.id : window.sdk.player.id;

            this.action.model["achi"].queryPlayerGameAchieve(gameId, playerId);

            //获取banner广告 SDK成就左,SDK成就右
            this.action.model["prombanner"].queryPromotionBanner(DGC.Ads.getBanners(this.alias));
        }

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ACHIEVEMENT);
    },


    /**
     * 离线重登录按钮绑定
     */
    bindReloginBtn : function(){
         $("#offline-relogin").bind(DGC.Common.E_TAP_DOWN,function(){$(this).addClass('active')})
            .bind(DGC.Common.E_TAP_UP,function(){$(this).removeClass('active')})
            .bind("tap", { context: this } , function(event){
                DGC.ActionUtil.offlineRelogin();
            });
         $("#ua-offline-tip").show();
    },

    /**
     * 渲染用户在游戏中获取的成就
     */
    renderAchieveList : function(list){
        var doneAchieve = 0 ,
            achieve,
            item,
            item_achieve,
            renderList = [],
            drawList =[];

        for (var i = 0; i < list.length; i++) {
           item = list[i], item_achieve = item.achievement;

           //统计完成的成就数
           if(item.percentage == 1){
               doneAchieve++;
           }

           //转换对象
           achieve = {
               id: item_achieve.id,
               title: item_achieve.title,
               icon: item_achieve.icon_url,
               desc: this.getDescText(item),
               percentText: this.getPercentText(item.percentage),
               percent: item.percentage
           }

           //存在图标，且需要绘制的成就图标
           if(!$.isEmpty(achieve.icon) && item.percentage > 0 && item.percentage < 1){
               drawList.push($.extend(achieve,{url : achieve.icon}));
           }

           renderList.push(achieve);
       }

       //渲染成就HTML结构
       var renderItems = $(this.renderByTpl(this.viewTpl.ACHIEVE, renderList));
       renderItems.bind(DGC.Common.E_TAP_DOWN,DGC.Common.listTapDownHandler);
       renderItems.bind(DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
       this.el.find(".achievement-list").html(renderItems);

       //设置标题
       $("#ua-achieve-done .achive-desc").text( (doneAchieve == 0 ? resName.TEXT_USERACHIEVE_NOT_GET_ACHIEVE
               : $.format(resName.TEXT_USERACHIEVE_GOT_ACHIEVE, [doneAchieve])  ));

       $("#ua-achieve-done .achive-num").text(doneAchieve + "/" +  list.length);

       //绘制进行中的成就
       this.renderProgressIcon(drawList);
    },

    /**
     * 绘制正在进行的成就图标
     */
    renderProgressIcon: function(achieves){
        var me = this;
        this.loadImages(achieves, function(img, data){
            var id = "icon-progress-"+ data.id,
                percent = data.percent;
            //加载图片完成后，绘制当期完成度
            me.drawPrecent(id, img, percent);
        });
    },

    /**
     * 获得成就描述信息
     */
    getDescText: function(item){
        var achieve = item.achievement,
            desc;

        //已完成成就，则直接显示获得后的信息
        if(item.percentage == 1){
            desc = achieve.earned_desc;
        }else{
            desc = (achieve.is_hidden ? resName.TEXT_USERACHIEVE_HIDDEN_NOT_GET :
                  achieve.pre_earned_desc );
        }

        //未完成状态
        return $.isEmpty(desc) ? "" : desc;
    },

    /**
     * 获取显示百分比的文字
     */
    getPercentText : function(percent){
        var text;
        switch(percent){
            case 0:
                text = resName.TEXT_USERACHIEVE_NOT_GET;
                break;
            case 1:
                text = $.format("<span class='get-achieve-text'>{0}</span>",[resName.TEXT_USERACHIEVE_GOT]);
                break;
            default:
                text = $.format(resName.TEXT_USERACHIEVE_PRECENT,[ parseInt(percent * 100, 10) ]);
                break;
        }
        return text;
    },

    /**
     * 根据完成度显示成就图标
     * @param {String} canvasID 画布ID
     * @param {Image}  img      已经加载图标完毕的image对象
     * @param {Number} percent  完成百分比,如:0.76
     */
    drawPrecent : function(canvasID , img,  percent){
        var canvas = document.getElementById(canvasID),
            ctx = canvas.getContext('2d'),
            cx = 35,
            cy = 35,
            cw = 70,
            ch = 70,
            radius  = 35,
            startAngle = 1.5 * Math.PI,
            endAngle = startAngle + ( percent * 360)  * Math.PI / 180 ;

        //设置画布大小
        canvas.width = cw;
        canvas.height = ch;
        //Android2.0/2.1分辨率缩放存在缩放BUG，图片将绘制到画布外
        //问题BUG:http://code.google.com/p/android/issues/detail?id=5141
        //解决方案参考：http://trac.osgeo.org/openlayers/changeset/11868
        var factor = /android 2.0|android 2.1/.test(navigator.userAgent.toLowerCase()) ?
                320 / window.screen.width : 1;
        ctx.drawImage(img, 0, 0, cw * factor, ch * factor ); //绘制成就图标
        this.drawSector(ctx, cx, cy, startAngle , endAngle , radius + 1, true); //逆时针绘画完成度
    },

    /**
     * 绘制扇形
     * @param {Canvas} ctx 画布Context
     * @param {Number} cx  中心坐标点x
     * @param {Number} cy  中心坐标点y
     * @param {Number} start_angle 开始弧度
     * @param {Number} end_angle   结束弧度
     * @param {Number} radius      半径
     * @param {Boolean} anticlockwise 顺/逆时针 false:顺时针  true:逆时针
     */
    drawSector : function(ctx ,cx, cy, start_angle, end_angle, radius, anticlockwise){
         start_angle = start_angle || 0;
         //开始绘制路径
         ctx.beginPath();
         //画出弧线
         ctx.arc(cx, cy, radius, start_angle, end_angle, anticlockwise);
         //画出结束半径
         ctx.lineTo(cx, cy);
         ctx.fillStyle = '#FFFFFF';
         ctx.fill();
    },

    /**
     * 预加载广告图片信息
     */
    loadAds: function(banners){
        var context = this,
            keys = [];

        //待加载的 Ads
        context.waitLoadAds = {};

        for(var i = 0; i < banners.length; i++){
            var banner = banners[i],
                selectAd = DGC.Ads.getBannerShowAd(banner.ads); //获得要渲染广告

            //需要请求的广告
            var requestAd = $.extend(selectAd,{
                "bid": banner["_id"], //广告位ID
                "url": selectAd.img_url //请求图片
            });

            //缓存广告信息
            context.waitLoadAds[requestAd.bid] = {
                status: false,
                data: requestAd
            }

            //FAKE对象
            keys.push(requestAd);
        }

        //预加载广告位图片
        context.loadImages(keys, function(img, data){
            context.waitLoadAds[data.bid].status = true; //广告位图片加载完毕
            //this.loadAds[pid].img = img; //缓存图片对象

            context.sycPageAds(); //同步检查所有广告位是否加载成功
        });
    },

    /**
     * 同步检查广告加载
     */
    sycPageAds: function(){
        for( var key in this.waitLoadAds){
            var ad = this.waitLoadAds[key];
            if(!ad.status){
                return false; //尚未完成加载
            }
        }

        //加载完毕,渲染全部广告
        this.renderPromotionBanner();
    },

    /**
     * 渲染页面广告
     */
    renderPromotionBanner: function(){
         var PAGE_BID = DGC.Ads.PAGES[this.alias],
             loadedAds = this.waitLoadAds,
             tplObj = {
                leftAd: loadedAds[PAGE_BID.LEFT].data, //左边广告
                rightAd: loadedAds[PAGE_BID.RIGHT].data, //右边广告
             },
             bannerModel = this.action.model['prombanner'];


        var renderBanner = $(this.renderByTpl(DGC.Ads.getSidesAdTpl(), tplObj));
        //点击触发
        renderBanner.find("a").bind("tap", {context : this}, function(event){
            var context = event.data.context;
                me = $(this),
                bid = me.parent(".ad-wrap").attr('data-key'),
                adObj = context.waitLoadAds[bid].data;
            switch(adObj.ad_type){
                case 1 /*APK*/:
                    DGC.ActionUtil.getGameState([adObj.package_name]);
                    context.cacheClickAd = adObj /*缓存点击广对象*/;
                    break;
                case 2 /*网页*/:
                    DGC.ActionUtil.openBrowser(adObj.ad_url);
                    break;
            }
        });
        this.el.prepend(renderBanner);
        renderBanner.fadeIn('slow');

        //统计广告位中显示次数
        setTimeout(function(){
            bannerModel.promotionBannerCount(tplObj.leftAd.id, tplObj.leftAd.bid);
            bannerModel.promotionBannerCount(tplObj.rightAd.id, tplObj.rightAd.bid);
        },0);

    },

    /**
     * 下载或启动游戏APK
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            bannerModel = this.action.model["prombanner"];

        if(this.cacheClickAd){
            if(status) {
                bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheClickAd.bid, 1/*运行*/ );//记录广告点击
                DGC.ActionUtil.startGame(this.cacheClickAd.bundle_id);//启动游戏
            } else {
               bannerModel.promotionBannerClick(this.cacheClickAd.id, this.cacheClickAd.bid, 0 /*下载*/);//记录广告点击
               DGC.ActionUtil.download(this.cacheClickAd.ad_url);//下载游戏
            }
            this.cacheClickAd = null;
        }
    }

});
