/**
 * APP加载模块
 */
(function(w){

    var config = w.version_config;

    w.Loader = {

        INDEX_FILE: "/version-config.js",

        /**
         * 语种目录
         */
        LANG_PATH: "locale/",

        /**
         * 语种字符串配置文件路径
         * @type
         */
        LANGUAGES : {
            "en_US":'en-us.js',
            "zh_CN":'zh-cn.js',
            "zh_TW":'zh-tw.js'
        },


        /**
         * 判断一个对象是否为String类型
         */
        isString : function(obj){
            return !!(obj === '' || (obj && obj.charCodeAt && obj.substr));
        },

        /**
         * 获得当前设备信息
         */
        requestDeviceInfo: function(){
            if ("NativeInterface" in window) {
                //异步请求设备/版本信息
                NativeInterface.action(JSON.stringify({
                    actionName: 'getNativeInitInfo',
                    callback: 'Loader.versionReady'
                }));
            }
        },

        /**
         * 根据APP信息加载版本所需文件
         * @param {Object} config
         */
        versionReady : function(params){
            //储存初始化信息
            window.sdk = params.result;

            //设置基线版本值
            this.BASE_VERSION_NUM = this.getVersionNum( window.sdk.base_version );

            /**
             * 加载App文件
             */
            function loadAppFiles(){
                //动态加载JS文件
                $LAB
                .setOptions({ AlwaysPreserveOrder : true })
                .script(QueenConfig.js) //配置JS列表
                .script(Loader.LANG_PATH) //加载语种文件
                .wait(function(){
                    DGC.App.loadReady();
                });

                //动态加载CSS文件
                w.loadCss(QueenConfig.css); //配置CSS列表
            }

            //版本配置加载文件
            var versionPath = window.sdk.version + this.INDEX_FILE;
                //生成语种目录
                Loader.LANG_PATH = window.sdk.version + '/' + Loader.LANG_PATH + Loader.LANGUAGES[window.sdk.language];

            //终端模式 SDCard/ROM版本
            if(!DEBUG.isWebModel() && !this.isRomVersion(window.sdk.version)){
                versionPath = window.sdk.rootpath + versionPath;
                Loader.LANG_PATH = window.sdk.rootpath + Loader.LANG_PATH;
            }

            //先加载版本配置文件
            $LAB.script(versionPath).wait(function(){

                //非ROM版本，则预处理加载文件路径
                if(!Loader.isRomVersion(window.sdk.version)){
                    Loader.updateVersionPath();
                }

                //获得文件列表后，动态加载模块文件
                $LAB
                .script(QueenConfig.core).wait(function(){ //加载核心库
                    if (typeof window.jQuery === "undefined"){
                        // first load failed, load local fallback, then dependencies
                        console.log("jQuery loader fail! reload");
                        $LAB.script(QueenConfig.core).wait(loadAppFiles);
                    }else {
                        // first load was a success, proceed to loading dependencies.
                        loadAppFiles();
                    }
                });

            });
        },

        /**
         * 处理配置文件路径
         */
        updateVersionPath: function(){
            var QC = window.QueenConfig,
                viewCfg,
                dialogCfg;

            //核心文件
            QC.core = this.replaceFilesPath(QC.core);

            //框架js,css
            QC.js = this.replaceFilesPath(QC.js);
            QC.css = this.replaceFilesPath(QC.css);

            //视图配置
            for(var viewName in QC.viewConfig){
                viewCfg = QC.viewConfig[viewName];
                if(viewCfg.js){
                    viewCfg.js = this.replaceFilesPath(viewCfg.js);
                }
                if(viewCfg.css){
                    viewCfg.css = this.replaceFilesPath(viewCfg.css);
                }
            }

            //窗口配置
            for(var dialogName in QC.dialogConfig){
                dialogCfg = QC.dialogConfig[dialogName];
                if(dialogCfg.js){
                    dialogCfg.js = this.replaceFilesPath(dialogCfg.js);
                }
                if(dialogCfg.css){
                    dialogCfg.css = this.replaceFilesPath(dialogCfg.css);
                }
            }
        },

        /**
         * 替换文件路径
         * @param {String||Array} 文件路径String或包含路径Array
         */
        replaceFilesPath : function(files){
            var i, file;
            if(this.isString(files)){
                return this.isBaseFile(files) ? files : (window.sdk.rootpath + files);
            }else{
                for (i = 0; i < files.length; i++) {
                    file = files[i];
                    if(!this.isBaseFile(file)){
                        files[i] = window.sdk.rootpath + file;
                    }
                };
                return files;
            }
        },

        /**
         * 获得当前版本的大小值
         * @param {String} verStr 版本字符串如："1.0.1"
         */
        getVersionNum: function(verStr){
            var verNums = verStr.split(".");
            return parseInt(verNums[0], 10) * 100 + parseInt(verNums[1], 10) * 10 + parseInt(verNums[2], 10);
        },

        /**
         * 判断版本是否属于ROM发布版本
         * @param {String} version 版本号
         */
        isRomVersion: function(version){
            return this.getVersionNum(version) <= this.BASE_VERSION_NUM;
        },

        /**
         * 判断要加载的文件是否为基线版本文件
         * @param {String} path 加载文件路径
         */
        isBaseFile: function(path){
            //获得当前文件版本
            var fileVersion = path.match(/\d+\.\d+\.\d+/)[0];
            return this.isRomVersion(fileVersion);
        }
   }

   //请求设备版本信息
   w.Loader.requestDeviceInfo();

}(window));